/*******************************************************************************
* File Name: ProgramControl.h
* Version 2.0
*
* Description:
*  This file provides constants and parameter values for the CapSense CSD
*  component.
*
* Note:
*
********************************************************************************
* Copyright 2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_CAPSENSE_CSD_ProgramControl_H)
#define CY_CAPSENSE_CSD_ProgramControl_H

#include "cytypes.h"
#include "cyfitter.h"
#include "core_cm0_psoc4.h"
#include "CyLib.h"

#include "ProgramControl_IP.h"

#include "ProgramControl_SenseClk.h"
#include "ProgramControl_SampleClk.h"

/* Constants set by Customizer */
#define ProgramControl_TOTAL_SENSOR_COUNT            (4u)
#define ProgramControl_TOTAL_SCANSLOT_COUNT          (4u)
#define ProgramControl_TOTAL_IMMUNITY_NUM            (4u)
#define ProgramControl_IS_STREET_FIGHTER             (0u)

/* Define Sensors */
#define ProgramControl_SENSOR_BACKWARD__BTN    (0u)
#define ProgramControl_SENSOR_FORWARD__BTN    (1u)
#define ProgramControl_SENSOR_MINUS__BTN    (2u)
#define ProgramControl_SENSOR_PLUS__BTN    (3u)
/* AMux Cmod, Comparator and Idac Channels definitions */
#define ProgramControl_AMuxCH_CMOD_CHANNEL          (0u)
#define ProgramControl_AMuxCH_CMP_VP_CHANNEL        (1u)
#define ProgramControl_AMuxCH_IDAC_CHANNEL          (2u)


#define ProgramControl_TOTAL_SENSOR_MASK (((ProgramControl_TOTAL_SENSOR_COUNT - 1u) / 8u) + 1u)	

/* Interrupt handler */
CY_ISR_PROTO(ProgramControl_ISR);

/* ISR Number and Priority to work with CyLib functions */
#define ProgramControl_ISR_NUMBER        (ProgramControl_ISR__INTC_NUMBER)
#define ProgramControl_ISR_PRIORITY      (ProgramControl_ISR__INTC_PRIOR_NUM)

/***************************************
*   Condition compilation parameters
***************************************/

#define ProgramControl_CONNECT_INACTIVE_SNS       (0u)
#define ProgramControl_IS_COMPLEX_SCANSLOTS       (0u)

#define ProgramControl_IDAC_CNT                   (2u)
#define ProgramControl_IDAC1_POLARITY             (0u)
#define ProgramControl_IDAC1_RANGE_VALUE          (0u)
#define ProgramControl_IDAC2_RANGE_VALUE          (0u)

#define ProgramControl_MULTIPLE_FREQUENCY_SET     (1u)
#define ProgramControl_FILTER_ENABLE			    (0u)
#define ProgramControl_PRS_OPTIONS                (0u)

#define ProgramControl_WATER_PROOF                (0u)

#define ProgramControl_TUNING_METHOD              (2u)
#define ProgramControl_TUNER_API_GENERATE         (0u)

#define ProgramControl_CSHL_API_GENERATE          (1u)

#define ProgramControl_CMOD_PREGARGE_OPTION       (1u)
#define ProgramControl_CSH_TANK_PREGARGE_OPTION   (1u)
#define ProgramControl_IS_SHIELD_ENABLE           (0u)
#define ProgramControl_CSH_TANK_ENABLE            (0u)

#define ProgramControl_SHIELD_DELAY               (0u)
#define ProgramControl_AUTOCALIBRATION_ENABLE		(0u)

#define ProgramControl_IS_OVERSAMPLING_EN         (1u)

#define ProgramControl_CSD_4B_PWM_MODE			(0u)
#define ProgramControl_CSD_4B_PWM_COUNT			(0u)

/**************************************
*    Enumerated Types and Parameters
**************************************/

/* Current source definitions */
#define ProgramControl__IDAC_SOURCE 0
#define ProgramControl__IDAC_SINK 1

#define ProgramControl__IDAC_4X 0
#define ProgramControl__IDAC_8X 1

#define ProgramControl__PRS_NONE 0
#define ProgramControl__PRS_8BITS 1
#define ProgramControl__PRS_12BITS 2
#define ProgramControl__PRS_AUTO 3

/* Connection of inactive sensors definitions */
#define ProgramControl__GROUND 0
#define ProgramControl__HIZ_ANALOG 1
#define ProgramControl__SHIELD 2

/* Precharge options definitions */
#define ProgramControl__CAPPRIOBUF 0
#define ProgramControl__CAPPRVREF 1

/* Method of tunning */
#define ProgramControl__TUNING_NONE 0
#define ProgramControl__TUNING_MANUAL 1
#define ProgramControl__TUNING_AUTO 2

/* Dead band PWM modulator options */
#define ProgramControl__PWM_OFF 0
#define ProgramControl__PWM_HIGH 2
#define ProgramControl__PWM_LOW 3


#define ProgramControl_DELAY_EXTRACYCLES_NUM			(9u)
#define ProgramControl_GLITCH_ELIMINATION_TIMEOUT		(5u)
#define ProgramControl_GLITCH_ELIMINATION_CYCLES_CALC	(ProgramControl_GLITCH_ELIMINATION_TIMEOUT * CYDEV_BCLK__SYSCLK__MHZ)

#if(ProgramControl_GLITCH_ELIMINATION_CYCLES_CALC >= ProgramControl_DELAY_EXTRACYCLES_NUM)
	#define ProgramControl_GLITCH_ELIMINATION_CYCLES (ProgramControl_GLITCH_ELIMINATION_CYCLES_CALC -\
													    ProgramControl_DELAY_EXTRACYCLES_NUM)
#else
	#define ProgramControl_GLITCH_ELIMINATION_CYCLES (ProgramControl_GLITCH_ELIMINATION_CYCLES_CALC)
#endif /* (ProgramControl_GLITCH_ELIMINATION_CYCLES_CALC >= ProgramControl_DELAY_EXTRACYCLES_NUM) */

#define ProgramControl_INITIAL_CLK_DIVIDER			(CYDEV_BCLK__HFCLK__KHZ / CYDEV_BCLK__SYSCLK__KHZ)


/* Structure to save registers before going to sleep */
typedef struct
{
    uint8 enableState;
} ProgramControl_BACKUP_STRUCT;


/***************************************
*        Function Prototypes
***************************************/

void ProgramControl_Init(void);
void ProgramControl_CsdHwBlockInit(void);
void ProgramControl_Enable(void);
void ProgramControl_Start(void);
void ProgramControl_Stop(void);
void ProgramControl_SaveConfig(void);
void ProgramControl_Sleep(void);
void ProgramControl_RestoreConfig(void);
void ProgramControl_Wakeup(void);
uint32 ProgramControl_IsBusy(void);
void ProgramControl_ScanSensor(uint32 sensor);
void ProgramControl_ScanWidget(uint32 widget);
void ProgramControl_ScanEnabledWidgets(void);
uint16 ProgramControl_ReadSensorRaw(uint32 sensor);
void ProgramControl_WriteSensorRaw(uint32 sensor, uint16 value);
void ProgramControl_ClearSensors(void);
void ProgramControl_SetShieldDelay(uint32 delay);
uint32 ProgramControl_ReadCurrentScanningSensor(void);

uint32 ProgramControl_GetScanResolution(uint32 widget);
uint32 ProgramControl_GetSenseClkDivider(uint32 sensor);
uint32 ProgramControl_GetModulatorClkDivider(uint32 sensor);
uint32 ProgramControl_GetModulationIDAC(uint32 sensor);
uint32 ProgramControl_GetCompensationIDAC(uint32 sensor);
uint32 ProgramControl_GetIDACRange(void);

#if (ProgramControl_TUNING_METHOD != ProgramControl__TUNING_NONE)
	void ProgramControl_SetScanResolution(uint32 widget, uint32 resolution);
    void ProgramControl_SetSenseClkDivider(uint32 sensor, uint32 senseClk);
	void ProgramControl_SetModulatorClkDivider(uint32 sensor, uint32 modulatorClk);
	void ProgramControl_SetModulationIDAC(uint32 sensor, uint32 modIdacValue);
	void ProgramControl_SetCompensationIDAC(uint32 sensor, uint32 compIdacValue);
	void ProgramControl_SetIDACRange(uint32 iDacRange);
#endif /* (ProgramControl_TUNING_METHOD != ProgramControl__TUNING_NONE) */


void ProgramControl_SetDriveModeAllPins(uint32 driveMode);
void ProgramControl_RestoreDriveModeAllPins(void);
void ProgramControl_SetUnscannedSensorState(uint32 sensor, uint32 sensorState);

/***************************************
*           API Constants
***************************************/

/* PWM Resolution */
#define ProgramControl_CNT_MSB_RESOLUTION_8_BITS  (0x00u)
#define ProgramControl_CNT_MSB_RESOLUTION_9_BITS  (0x01u)
#define ProgramControl_CNT_MSB_RESOLUTION_10_BITS (0x03u)
#define ProgramControl_CNT_MSB_RESOLUTION_11_BITS (0x07u)
#define ProgramControl_CNT_MSB_RESOLUTION_12_BITS (0x0Fu)
#define ProgramControl_CNT_MSB_RESOLUTION_13_BITS (0x1Fu)
#define ProgramControl_CNT_MSB_RESOLUTION_14_BITS (0x3Fu)
#define ProgramControl_CNT_MSB_RESOLUTION_15_BITS (0x7Fu)
#define ProgramControl_CNT_MSB_RESOLUTION_16_BITS (0xFFu)

#define ProgramControl_ONE_CYCLE					(0x00010000Lu)

#define ProgramControl_WINDOW_APPEND          	(0xFFFF0000Lu)
#define ProgramControl_RESOLUTION_6_BITS      	(0x003F0000Lu)
#define ProgramControl_RESOLUTION_7_BITS      	(0x007F0000Lu)
#define ProgramControl_RESOLUTION_8_BITS          (0x00FF0000Lu)
#define ProgramControl_RESOLUTION_9_BITS          (0x01FF0000Lu)
#define ProgramControl_RESOLUTION_10_BITS         (0x03FF0000Lu)
#define ProgramControl_RESOLUTION_11_BITS         (0x07FF0000Lu)
#define ProgramControl_RESOLUTION_12_BITS         (0x0FFF0000Lu)
#define ProgramControl_RESOLUTION_13_BITS         (0x1FFF0000Lu)
#define ProgramControl_RESOLUTION_14_BITS         (0x3FFF0000Lu)
#define ProgramControl_RESOLUTION_15_BITS         (0x7FFF0000Lu)
#define ProgramControl_RESOLUTION_16_BITS         (0xFFFF0000Lu)

#define ProgramControl_RESOLUTION_OFFSET  	(16u)
#define ProgramControl_MSB_RESOLUTION_OFFSET  (24u)

/* Software Status Register Bit Masks */
#define ProgramControl_SW_STS_BUSY                (0x01u)
/* Software Control Register Bit Masks */
#define ProgramControl_SW_CTRL_SINGLE_SCAN        (0x80u)

/* Software Control Register Bit Masks for scanning one widget */
#define ProgramControl_SW_CTRL_WIDGET_SCAN        (0x40u)

/* Flag for complex scan slot */
#define ProgramControl_COMPLEX_SS_FLAG            (0x80u)

/* Flag for scanning is complete */
#define ProgramControl_NOT_SENSOR                 (0xFFFFFFFFLu)

/* Number of bits for each pin in PC register. */
#define ProgramControl_PC_PIN_CFG_SIZE		    (0x03u)

/* Number of bits for each pin in HSIOM register. */
#define ProgramControl_HSIOM_PIN_CFG_SIZE	        (0x04u)

/***************************************
*             Registers
***************************************/

#define ProgramControl_CSD_ID_REG             (*(reg32 *)  ProgramControl_CSD_FFB__CSD_ID)
#define ProgramControl_CSD_ID_PTR             ( (reg32 *)  ProgramControl_CSD_FFB__CSD_ID)

#define ProgramControl_CSD_CFG_REG            (*(reg32 *)  ProgramControl_CSD_FFB__CSD_CONFIG)
#define ProgramControl_CSD_CFG_PTR            ( (reg32 *)  ProgramControl_CSD_FFB__CSD_CONFIG)

#define ProgramControl_CSD_IDAC_REG           (*(reg32 *)  ProgramControl_IDAC1_cy_psoc4_idac__CSD_IDAC)
#define ProgramControl_CSD_IDAC_PTR           ( (reg32 *)  ProgramControl_IDAC1_cy_psoc4_idac__CSD_IDAC)

#define ProgramControl_CSD_CNT_REG            (*(reg32 *) ProgramControl_CSD_FFB__CSD_COUNTER)
#define ProgramControl_CSD_CNT_PTR            ( (reg32 *) ProgramControl_CSD_FFB__CSD_COUNTER)

#define ProgramControl_CSD_STAT_REG           (*(reg32 *) ProgramControl_CSD_FFB__CSD_STATUS)
#define ProgramControl_CSD_STAT_PTR           ( (reg32 *) ProgramControl_CSD_FFB__CSD_STATUS)

#define ProgramControl_CSD_INTR_REG           (*(reg32 *) ProgramControl_CSD_FFB__CSD_INTR)
#define ProgramControl_CSD_INTR_PTR           ( (reg32 *) ProgramControl_CSD_FFB__CSD_INTR)

#define ProgramControl_CSD_INTR_SET_REG       (*(reg32 *) ProgramControl_CSD_FFB__CSD_INTR_SET)
#define ProgramControl_CSD_INTR_SET_PTR       ( (reg32 *) ProgramControl_CSD_FFB__CSD_INTR_SET)

#define ProgramControl_CSD_4B_PWM_REG         (*(reg32 *) ProgramControl_CSD_FFB__CSD_PWM)
#define ProgramControl_CSD_4B_PWM_PTR         ( (reg32 *) ProgramControl_CSD_FFB__CSD_PWM)

#define ProgramControl_CSD_TRIM1_REG          (*(reg32 *) CYREG_CSD_TRIM1)
#define ProgramControl_CSD_TRIM1_PTR          ( (reg32 *) CYREG_CSD_TRIM1)

#define ProgramControl_CSD_TRIM2_REG          (*(reg32 *) CYREG_CSD_TRIM2)
#define ProgramControl_CSD_TRIM2_PTR          ( (reg32 *) CYREG_CSD_TRIM2)

#define ProgramControl_SFLASH_CSD_TRIM1_REG   (*(reg8 *) CYREG_SFLASH_CSD_TRIM1_CSD)
#define ProgramControl_SFLASH_CSD_TRIM1_PTR   ( (reg8 *) CYREG_SFLASH_CSD_TRIM1_CSD)

#define ProgramControl_SFLASH_CSD_TRIM2_REG   (*(reg8 *) CYREG_SFLASH_CSD_TRIM2_CSD)
#define ProgramControl_SFLASH_CSD_TRIM2_PTR   ( (reg8 *) CYREG_SFLASH_CSD_TRIM2_CSD)


/* Port function select */
#define ProgramControl_PORT_SEL0_REG          (*(reg32 *) CYREG_HSIOM_PORT_SEL0 )
#define ProgramControl_PORT_SEL0_PTR          ( (reg32 *) CYREG_HSIOM_PORT_SEL0 )

#define ProgramControl_PORT_SEL1_REG          (*(reg32 *) CYREG_HSIOM_PORT_SEL1 )
#define ProgramControl_PORT_SEL1_PTR          ( (reg32 *) CYREG_HSIOM_PORT_SEL1 )

#define ProgramControl_PORT_SEL2_REG          (*(reg32 *) CYREG_HSIOM_PORT_SEL2 )
#define ProgramControl_PORT_SEL2_PTR          ( (reg32 *) CYREG_HSIOM_PORT_SEL2 )

#define ProgramControl_PORT_SEL3_REG          (*(reg32 *) CYREG_HSIOM_PORT_SEL3 )
#define ProgramControl_PORT_SEL3_PTR          ( (reg32 *) CYREG_HSIOM_PORT_SEL3 )

#define ProgramControl_PORT_SEL4_REG          (*(reg32 *) CYREG_HSIOM_PORT_SEL4 )
#define ProgramControl_PORT_SEL4_PTR          ( (reg32 *) CYREG_HSIOM_PORT_SEL4 )

#if (0u == ProgramControl_IS_M0S8IOSS_BLOCK)
	
	/* Port DR and PC registers */
	#define ProgramControl_PORT0_DR_REG           (*(reg32 *) CYREG_PRT0_DR )
	#define ProgramControl_PORT0_DR_PTR           ( (reg32 *) CYREG_PRT0_DR )

	#define ProgramControl_PORT1_DR_REG           (*(reg32 *) CYREG_PRT1_DR )
	#define ProgramControl_PORT1_DR_PTR           ( (reg32 *) CYREG_PRT1_DR )

	#define ProgramControl_PORT2_DR_REG           (*(reg32 *) CYREG_PRT2_DR )
	#define ProgramControl_PORT2_DR_PTR           ( (reg32 *) CYREG_PRT2_DR )

	#define ProgramControl_PORT3_DR_REG           (*(reg32 *) CYREG_PRT3_DR )
	#define ProgramControl_PORT3_DR_PTR           ( (reg32 *) CYREG_PRT3_DR )

	#define ProgramControl_PORT4_DR_REG           (*(reg32 *) CYREG_PRT4_DR )
	#define ProgramControl_PORT4_DR_PTR           ( (reg32 *) CYREG_PRT4_DR )

	/* Port DR and PC registers */
	#define ProgramControl_PORT0_PC_REG           (*(reg32 *) CYREG_PRT0_PC )
	#define ProgramControl_PORT0_PC_PTR           ( (reg32 *) CYREG_PRT0_PC )

	#define ProgramControl_PORT1_PC_REG           (*(reg32 *) CYREG_PRT1_PC )
	#define ProgramControl_PORT1_PC_PTR           ( (reg32 *) CYREG_PRT1_PC )

	#define ProgramControl_PORT2_PC_REG           (*(reg32 *) CYREG_PRT2_PC )
	#define ProgramControl_PORT2_PC_PTR           ( (reg32 *) CYREG_PRT2_PC )

	#define ProgramControl_PORT3_PC_REG           (*(reg32 *) CYREG_PRT3_PC )
	#define ProgramControl_PORT3_PC_PTR           ( (reg32 *) CYREG_PRT3_PC )

	#define ProgramControl_PORT4_PC_REG           (*(reg32 *) CYREG_PRT4_PC )
	#define ProgramControl_PORT4_PC_PTR           ( (reg32 *) CYREG_PRT4_PC )
	
    #define ProgramControl_CMOD_CONNECTION_REG        (ProgramControl_PORT_SEL4_REG)
    #define ProgramControl_CMOD_PORT_PC_REG           (ProgramControl_PORT4_PC_REG)
    #define ProgramControl_CMOD_PORT_DR_REG           (ProgramControl_PORT4_DR_REG)
	
	#define ProgramControl_CTANK_CONNECTION_REG        (ProgramControl_PORT_SEL4_REG)
    #define ProgramControl_CTANK_PORT_PC_REG           (ProgramControl_PORT4_PC_REG)
    #define ProgramControl_CTANK_PORT_DR_REG           (ProgramControl_PORT4_DR_REG)
#else
		
	/* Port DR and PC registers */
	#define ProgramControl_PORT0_DR_REG           (*(reg32 *) CYREG_GPIO_PRT0_DR )
	#define ProgramControl_PORT0_DR_PTR           ( (reg32 *) CYREG_GPIO_PRT0_DR )

	#define ProgramControl_PORT1_DR_REG           (*(reg32 *) CYREG_GPIO_PRT1_DR )
	#define ProgramControl_PORT1_DR_PTR           ( (reg32 *) CYREG_GPIO_PRT1_DR )

	#define ProgramControl_PORT2_DR_REG           (*(reg32 *) CYREG_GPIO_PRT2_DR )
	#define ProgramControl_PORT2_DR_PTR           ( (reg32 *) CYREG_GPIO_PRT2_DR )

	#define ProgramControl_PORT3_DR_REG           (*(reg32 *) CYREG_GPIO_PRT3_DR )
	#define ProgramControl_PORT3_DR_PTR           ( (reg32 *) CYREG_GPIO_PRT3_DR )

	#define ProgramControl_PORT4_DR_REG           (*(reg32 *) CYREG_GPIO_PRT4_DR )
	#define ProgramControl_PORT4_DR_PTR           ( (reg32 *) CYREG_GPIO_PRT4_DR )

	/* Port DR and PC registers */
	#define ProgramControl_PORT0_PC_REG           (*(reg32 *) CYREG_GPIO_PRT0_PC )
	#define ProgramControl_PORT0_PC_PTR           ( (reg32 *) CYREG_GPIO_PRT0_PC )

	#define ProgramControl_PORT1_PC_REG           (*(reg32 *) CYREG_GPIO_PRT1_PC )
	#define ProgramControl_PORT1_PC_PTR           ( (reg32 *) CYREG_GPIO_PRT1_PC )

	#define ProgramControl_PORT2_PC_REG           (*(reg32 *) CYREG_GPIO_PRT2_PC )
	#define ProgramControl_PORT2_PC_PTR           ( (reg32 *) CYREG_GPIO_PRT2_PC )

	#define ProgramControl_PORT3_PC_REG           (*(reg32 *) CYREG_GPIO_PRT3_PC )
	#define ProgramControl_PORT3_PC_PTR           ( (reg32 *) CYREG_GPIO_PRT3_PC )

	#define ProgramControl_PORT4_PC_REG           (*(reg32 *) CYREG_GPIO_PRT4_PC )
	#define ProgramControl_PORT4_PC_PTR           ( (reg32 *) CYREG_GPIO_PRT4_PC )
	
    #define ProgramControl_CMOD_CONNECTION_REG        (ProgramControl_PORT_SEL0_REG)
    #define ProgramControl_CMOD_PORT_PC_REG           (ProgramControl_PORT0_PC_REG)
    #define ProgramControl_CMOD_PORT_DR_REG           (ProgramControl_PORT0_DR_REG)
	
	#define ProgramControl_CTANK_CONNECTION_REG        (ProgramControl_PORT_SEL0_REG)
    #define ProgramControl_CTANK_PORT_PC_REG           (ProgramControl_PORT0_PC_REG)
    #define ProgramControl_CTANK_PORT_DR_REG           (ProgramControl_PORT0_DR_REG)
#endif /* (0u == ProgramControl_IS_M0S8IOSS_BLOCK) */



/***************************************
*       Register Constants
***************************************/

/* Port configuration defines */
#define ProgramControl_CSD_HSIOM_MASK             (0x0000000FLu)
#define ProgramControl_CSD_SENSE_PORT_MODE        (0x00000004Lu)
#define ProgramControl_CSD_SHIELD_PORT_MODE       (0x00000005Lu)

#define ProgramControl_CSD_PIN_MODE_MASK          (0x00000007Lu)
#define ProgramControl_CSD_PIN_DRIVE_MASK         (0x00000001Lu)


#if (0u == ProgramControl_M0S8CSD_BLOCK_VER)
	#define ProgramControl_CSD_CMOD_CONNECTION_MASK   (0x00000F00Lu)
	#define ProgramControl_CSD_CMOD_TO_AMUXBUS_A      (0x00000600Lu)
	#define ProgramControl_CSD_CMOD_TO_AMUXBUS_B      (0x00000700Lu)
	
	#define ProgramControl_CSD_CTANK_CONNECTION_MASK  (0x0000F000Lu)
	#define ProgramControl_CSD_CTANK_TO_AMUXBUS_A     (0x00006000Lu)
	#define ProgramControl_CSD_CTANK_TO_AMUXBUS_B     (0x00007000Lu)
	
	#define  ProgramControl_CSD_CMOD_PC_MASK          (0x000001C0Lu)
	#define  ProgramControl_CSD_CTANK_PC_MASK         (0x00000E00Lu)

	#define  ProgramControl_CMOD_PC_STRONG_MODE       (0x00000180Lu)
	#define  ProgramControl_CMOD_PC_HIGH_Z_MODE       (0x00000000Lu)

	#define  ProgramControl_CTANK_PC_STRONG_MODE      (0x00000C00Lu)
	#define  ProgramControl_CTANK_PC_HIGH_Z_MODE      (0x00000000Lu)

	#define  ProgramControl_CMOD_DR_VSSIO 			(0x00000004Lu)
	#define  ProgramControl_CMOD_DR_VDDIO				(0x00000000Lu)
	#define  ProgramControl_CMOD_DR_MASK				(0x00000004Lu)

	#define  ProgramControl_CTANK_DR_VSSIO 			(0x00000008Lu)
	#define  ProgramControl_CTANK_DR_VDDIO			(0x00000000Lu)
	#define  ProgramControl_CTANK_DR_MASK 			(0x00000008Lu)
#else
	#define ProgramControl_CSD_CMOD_CONNECTION_MASK   (0x000F0000Lu)
	#define ProgramControl_CSD_CMOD_TO_AMUXBUS_A      (0x00060000Lu)
	#define ProgramControl_CSD_CMOD_TO_AMUXBUS_B      (0x00070000Lu)
	
	#define ProgramControl_CSD_CTANK_CONNECTION_MASK  (0x00000F00Lu)
	#define ProgramControl_CSD_CTANK_TO_AMUXBUS_A     (0x00000600Lu)
	#define ProgramControl_CSD_CTANK_TO_AMUXBUS_B     (0x00000700Lu)
	
	#define  ProgramControl_CSD_CMOD_PC_MASK          (0x00007000Lu)
	#define  ProgramControl_CSD_CTANK_PC_MASK         (0x000001C0Lu)

	#define  ProgramControl_CMOD_PC_STRONG_MODE       (0x00006000Lu)
	#define  ProgramControl_CMOD_PC_HIGH_Z_MODE       (0x00000000Lu)

	#define  ProgramControl_CTANK_PC_STRONG_MODE      (0x00000180Lu)
	#define  ProgramControl_CTANK_PC_HIGH_Z_MODE      (0x00000000Lu)

	#define  ProgramControl_CMOD_DR_VSSIO 			(0x00000010Lu)
	#define  ProgramControl_CMOD_DR_VDDIO				(0x00000000Lu)
	#define  ProgramControl_CMOD_DR_MASK				(0x00000010Lu)

	#define  ProgramControl_CTANK_DR_VSSIO 			(0x00000004Lu)
	#define  ProgramControl_CTANK_DR_VDDIO			(0x00000000Lu)
	#define  ProgramControl_CTANK_DR_MASK 			(0x00000004Lu)
#endif  /* (0u == ProgramControl_M0S8CSD_BLOCK_VER) */


#define  ProgramControl_CMOD_PIN_NUMBER			(ProgramControl_Cmod__0__SHIFT)
#define  ProgramControl_CMOD_PRT_NUMBER			(ProgramControl_Cmod__0__PORT)

#if(0u != ProgramControl_CSH_TANK_ENABLE)
	#define  ProgramControl_CTANK_PIN_NUMBER			(ProgramControl_Csh_tank__0__SHIFT)
	#define  ProgramControl_CTANK_PRT_NUMBER			(ProgramControl_Csh_tank__0__PORT)
#endif /* (0u != ProgramControl_CSH_TANK_ENABLE) */	


/* ID register fields position */
#define ProgramControl_CSD_ID_ID__POS              (0x00u)
#define ProgramControl_CSD_ID_REV__POS             (0x10u)

#define ProgramControl_CSD_ID_ID                   (0xFFLu << ProgramControl_CSD_ID_ID__POS)
#define ProgramControl_CSD_ID_REV                  (0xFFLu << ProgramControl_CSD_ID_REV__POS)


/* CSD_CONFIG register fields position */
#define ProgramControl_CSD_CFG_DSI_SAMPLE_EN_POS  (0x00u)
#define ProgramControl_CSD_CFG_SAMPLE_SYNC_POS    (0x01u)
#define	ProgramControl_CSD_CFG_FILTER_EN_POS		(0x03u)
#define ProgramControl_CSD_CFG_PRS_CLEAR_POS      (0x05u)
#define ProgramControl_CSD_CFG_PRS_SELECT_POS     (0x06u)
#define ProgramControl_CSD_CFG_PRS_12_8_POS       (0x07u)
#define ProgramControl_CSD_CFG_DSI_SENSE_EN_POS   (0x08u)
#define ProgramControl_CSD_CFG_SHIELD_DELAY_POS   (0x09u)
#define ProgramControl_CSD_CFG_SENSE_COMP_BW_POS  (0x0Bu)
#define ProgramControl_CSD_CFG_SENSE_EN_POS       (0x0Cu)
#define ProgramControl_CSD_CFG_REFBUF_EN_POS      (0x0Du)
#define ProgramControl_CSD_CFG_CHARGE_IO_POS      (0x0Eu)
#define ProgramControl_CSD_CFG_COMP_PIN_POS       (0x0Fu)
#define ProgramControl_CSD_CFG_POLARITY_POS       (0x10u)
#define ProgramControl_CSD_CFG_MUTUAL_CAP_POS     (0x12u)
#define ProgramControl_CSD_CFG_SENSE_COMP_EN_POS  (0x13u)
#define ProgramControl_CSD_CFG_REFBUF_OUTSEL_POS  (0x15u)
#define ProgramControl_CSD_CFG_SENSE_INSEL_POS    (0x16u)
#define ProgramControl_CSD_REFBUF_DRV_POS			(0x17u)
#define ProgramControl_CSD_CFG_DDFTSEL_POS		(0x1Au)
#define ProgramControl_CSD_CFG_ADFTEN_POS         (0x1Du)
#define ProgramControl_CSD_CFG_DDFTCOMP_POS       (0x1Eu)
#define ProgramControl_CSD_CFG_ENABLE_POS         (0x1Fu)


/* CSD_STATUS register fields position */
#define ProgramControl_CSD_STAT_CSD_CHARGE_POS    (0x00u)
#define ProgramControl_CSD_STAT_CSD_SENSE_POS     (0x01u)
#define ProgramControl_CSD_STAT_COMP_OUT_POS      (0x02u)
#define ProgramControl_CSD_STAT_SAMPLE_POS        (0x03u)


/* CSD_IDAC control register fields position */
#define ProgramControl_CSD_IDAC1_MODE_MASK_POS		(0x08u)
#define ProgramControl_CSD_IDAC1_MODE_FIXED_POS		(0x08u)
#define ProgramControl_CSD_IDAC1_MODE_VARIABLE_POS	(0x08u)
#define ProgramControl_CSD_IDAC1_MODE_DSI_POS			(0x08u)
#define ProgramControl_CSD_IDAC1_RANGE_8X_POS			(0x0Au)
#define ProgramControl_CSD_IDAC1_DATA_MASK_POS		(0x00u)

#define ProgramControl_CSD_IDAC2_MODE_MASK_POS		(0x18u)
#define ProgramControl_CSD_IDAC2_MODE_FIXED_POS		(0x18u)
#define ProgramControl_CSD_IDAC2_MODE_VARIABLE_POS	(0x18u)
#define ProgramControl_CSD_IDAC2_MODE_DSI_POS			(0x18u)
#define ProgramControl_CSD_IDAC2_RANGE_8X_POS			(0x1Au)
#define ProgramControl_CSD_IDAC2_DATA_MASK_POS		(0x10u)


/* CSD_COUNTER register fields position */
#define ProgramControl_CSD_CNT_COUNTER_POS        (0x00u)
#define ProgramControl_CSD_CNT_PERIOD_POS         (0x10u)


/* CSD_CONFIRG register definitions */
#define ProgramControl_CSD_CFG_DSI_SAMPLE_EN       (0x01Lu << ProgramControl_CSD_CFG_DSI_SAMPLE_EN_POS)
#define ProgramControl_CSD_CFG_SAMPLE_SYNC         (0x01Lu << ProgramControl_CSD_CFG_SAMPLE_SYNC_POS)
#define	ProgramControl_CSD_CFG_FILTER_EN			 (0x01Lu << ProgramControl_CSD_CFG_FILTER_EN_POS)
#define ProgramControl_CSD_CFG_PRS_CLEAR           (0x01Lu << ProgramControl_CSD_CFG_PRS_CLEAR_POS)
#define ProgramControl_CSD_CFG_PRS_SELECT          (0x01Lu << ProgramControl_CSD_CFG_PRS_SELECT_POS)
#define ProgramControl_CSD_CFG_PRS_12_8            (0x01Lu << ProgramControl_CSD_CFG_PRS_12_8_POS)
#define ProgramControl_CSD_CFG_DSI_SENSE_EN        (0x01Lu << ProgramControl_CSD_CFG_DSI_SENSE_EN_POS)
#define ProgramControl_CSD_CFG_SHIELD_DELAY_MASK   (0x03Lu << ProgramControl_CSD_CFG_SHIELD_DELAY_POS)
#define ProgramControl_CSD_CFG_SENSE_COMP_BW       (0x01Lu << ProgramControl_CSD_CFG_SENSE_COMP_BW_POS)
#define ProgramControl_CSD_CFG_SENSE_EN            (0x01Lu << ProgramControl_CSD_CFG_SENSE_EN_POS)
#define ProgramControl_CSD_CFG_REFBUF_EN           (0x01Lu << ProgramControl_CSD_CFG_REFBUF_EN_POS)
#define ProgramControl_CSD_CFG_CHARGE_IO           (0x01Lu << ProgramControl_CSD_CFG_CHARGE_IO_POS)
#define ProgramControl_CSD_CFG_COMP_PIN_CH2   	 (0x01Lu << ProgramControl_CSD_CFG_COMP_PIN_POS)
#define ProgramControl_CSD_CFG_POLARITY_VDDIO      (0x01Lu << ProgramControl_CSD_CFG_POLARITY_POS)
#define ProgramControl_CSD_CFG_MUTUAL_CAP          (0x01Lu << ProgramControl_CSD_CFG_MUTUAL_CAP_POS)
#define ProgramControl_CSD_CFG_SENSE_COMP_EN       (0x01Lu << ProgramControl_CSD_CFG_SENSE_COMP_EN_POS)
#define ProgramControl_CSD_CFG_REFBUF_OUTSEL       (0x01Lu << ProgramControl_CSD_CFG_REFBUF_OUTSEL_POS)
#define ProgramControl_CSD_CFG_SENSE_INSEL         (0x01Lu << ProgramControl_CSD_CFG_SENSE_INSEL_POS)
#define ProgramControl_CSD_REFBUF_DRV_MASK		 (0x03Lu << ProgramControl_CSD_REFBUF_DRV_POS)
#define ProgramControl_CSD_REFBUF_DRV_LOW			 (0x01Lu << ProgramControl_CSD_REFBUF_DRV_POS)
#define ProgramControl_CSD_REFBUF_DRV_MEDIUM		 (0x02Lu << ProgramControl_CSD_REFBUF_DRV_POS)
#define ProgramControl_CSD_REFBUF_DRV_HIGH		 (0x03Lu << ProgramControl_CSD_REFBUF_DRV_POS)
#define ProgramControl_CSD_CFG_DDFTSEL_MASK        (0x07Lu << ProgramControl_CSD_CFG_DDFTSEL_POS)
#define ProgramControl_CSD_CFG_ADFTEN              (0x01Lu << ProgramControl_CSD_CFG_ADFTEN_POS)
#define ProgramControl_CSD_CFG_DDFTCOMP_MASK       (0x03Lu << ProgramControl_CSD_CFG_DDFTCOMP_POS)
#define ProgramControl_CSD_CFG_DDFTCOMP_REFCOMP    (0x01Lu << ProgramControl_CSD_CFG_DDFTCOMP_POS)
#define ProgramControl_CSD_CFG_DDFTCOMP_SENSECOMP  (0x02Lu << ProgramControl_CSD_CFG_DDFTCOMP_POS)
#define ProgramControl_CSD_CFG_ENABLE              (0x01Lu << ProgramControl_CSD_CFG_ENABLE_POS)


/* CSD_STATUS register definitions */
#define ProgramControl_CSD_STAT_CSD_CHARGE         (0x01Lu << ProgramControl_CSD_STAT_CSD_CHARGE_POS)
#define ProgramControl_CSD_STAT_CSD_SENSE          (0x01Lu << ProgramControl_CSD_STAT_CSD_SENSE_POS)
#define ProgramControl_CSD_STAT_COMP_OUT           (0x01Lu << ProgramControl_CSD_STAT_COMP_OUT_POS)
#define ProgramControl_CSD_STAT_SAMPLE             (0x01Lu << ProgramControl_CSD_STAT_SAMPLE_POS)

/* CSD_IDAC control register definitions */
#define ProgramControl_CSD_IDAC1_MODE_MASK          (0x03Lu << ProgramControl_CSD_IDAC1_MODE_MASK_POS)
#define ProgramControl_CSD_IDAC1_MODE_FIXED         (0x01Lu << ProgramControl_CSD_IDAC1_MODE_FIXED_POS)
#define ProgramControl_CSD_IDAC1_MODE_VARIABLE      (0x02Lu << ProgramControl_CSD_IDAC1_MODE_VARIABLE_POS)
#define ProgramControl_CSD_IDAC1_MODE_DSI           (0x03Lu << ProgramControl_CSD_IDAC1_MODE_DSI_POS)
#define ProgramControl_CSD_IDAC1_RANGE_8X           (0x01Lu << ProgramControl_CSD_IDAC1_RANGE_8X_POS)
#define ProgramControl_CSD_IDAC1_DATA_MASK          (0xFFLu << ProgramControl_CSD_IDAC1_DATA_MASK_POS)

#define ProgramControl_CSD_IDAC2_MODE_MASK          (0x03Lu << ProgramControl_CSD_IDAC2_MODE_MASK_POS)
#define ProgramControl_CSD_IDAC2_MODE_FIXED         (0x01Lu << ProgramControl_CSD_IDAC2_MODE_FIXED_POS)
#define ProgramControl_CSD_IDAC2_MODE_VARIABLE      (0x02Lu << ProgramControl_CSD_IDAC2_MODE_VARIABLE_POS)
#define ProgramControl_CSD_IDAC2_MODE_DSI           (0x03Lu << ProgramControl_CSD_IDAC2_MODE_DSI_POS)
#define ProgramControl_CSD_IDAC2_RANGE_8X           (0x01Lu << ProgramControl_CSD_IDAC2_RANGE_8X_POS)
#define ProgramControl_CSD_IDAC2_DATA_MASK          (0x7FLu << ProgramControl_CSD_IDAC2_DATA_MASK_POS)

#define ProgramControl_CSD_IDAC2_DATA_OFFSET        (16u)

#define ProgramControl_CSD_IDAC1_TRIM_MASK          (0xFFFFFFF0u)
#define ProgramControl_CSD_IDAC2_TRIM_MASK          (0xFFFFFF0Fu)

#define ProgramControl_CSFLASH_TRIM_IDAC1_MASK      (0x0Fu)
#define ProgramControl_CSFLASH_TRIM_IDAC2_MASK      (0xF0)

#define ProgramControl_CSD_4B_PWM_MODE_OFFSET		  (4u)
#define ProgramControl_CSD_4B_PWM_MODE_DEFAULT      (ProgramControl_CSD_4B_PWM_MODE << ProgramControl_CSD_4B_PWM_MODE_OFFSET)

#define ProgramControl_CSD_4B_PWM_COUNT_MASK		  (0x0000000Fu)
#define ProgramControl_CSD_4B_PWM_MODE_MASK		  (0x00000030u)


#define ProgramControl_CSD_IDAC_PRECHARGE_CONFIG	  (ProgramControl_CSD_IDAC1_MODE_FIXED |\
													   ProgramControl_PRECHARGE_IDAC1_VAL)

/* CSD_COUNTER register definitions */
#define ProgramControl_CSD_CNT_COUNTER             (0xFFLu << ProgramControl_CSD_CNT_COUNTER_POS )
#define ProgramControl_CSD_CNT_PERIOD              (0xFFLu << ProgramControl_CSD_CNT_PERIOD_POS)


#define ProgramControl_CSD_PRS_8_BIT                (0x00000000u)
#define ProgramControl_CSD_PRS_12_BIT               (ProgramControl_CSD_CFG_PRS_12_8)
#define	ProgramControl_PRS_MODE_MASK				  (ProgramControl_CSD_CFG_PRS_12_8)

/***************************************
*    Initial Parameter Constants
***************************************/

#if (0u != ProgramControl_FILTER_ENABLE)
    #define ProgramControl_DEFAULT_FILTER_STATE    (ProgramControl_CSD_CFG_FILTER_EN)
	
#else
	#define ProgramControl_DEFAULT_FILTER_STATE	 (0u)
	
#endif /* (ProgramControl_PRS_OPTIONS == ProgramControl_PRS_8BITS) */

#define	ProgramControl_DEFAULT_CSD_4B_PWM_CONFIG 	 (ProgramControl_CSD_4B_PWM_MODE_DEFAULT | ProgramControl_CSD_4B_PWM_COUNT)

/* Set PRS */
#if (ProgramControl_PRS_OPTIONS == ProgramControl__PRS_8BITS)
    #define ProgramControl_DEFAULT_MODULATION_MODE    ProgramControl_CSD_CFG_PRS_SELECT

#elif (ProgramControl_PRS_OPTIONS == ProgramControl__PRS_12BITS)
    #define ProgramControl_DEFAULT_MODULATION_MODE	ProgramControl_CSD_CFG_PRS_12_8 |\
														ProgramControl_CSD_CFG_PRS_SELECT
#else
	#define ProgramControl_DEFAULT_MODULATION_MODE	(0u)
#endif /* (ProgramControl_PRS_OPTIONS == ProgramControl_PRS_8BITS) */

/* Set IDAC ranges */
#if (ProgramControl_IDAC1_RANGE_VALUE == ProgramControl__IDAC_8X)
    #define ProgramControl_DEFAULT_IDAC1_RANGE    ProgramControl_CSD_IDAC1_RANGE_8X
    #define ProgramControl_DEFAULT_IDAC2_RANGE    ProgramControl_CSD_IDAC2_RANGE_8X
#else
    #define ProgramControl_DEFAULT_IDAC1_RANGE    (0u)
    #define ProgramControl_DEFAULT_IDAC2_RANGE    (0u)
#endif /* (ProgramControl_IDAC1_RANGE_VALUE == ProgramControl_IDAC_RANGE_8X) */

/* Set IDAC polarity */
#if(ProgramControl_IDAC1_POLARITY == ProgramControl__IDAC_SINK)

    #define ProgramControl_DEFAULT_IDAC_POLARITY	 ProgramControl_CSD_CFG_POLARITY_VDDIO
	#define ProgramControl_CMOD_DR_CONFIG			 ProgramControl_CMOD_DR_VDDIO	
	#define ProgramControl_CTANK_DR_CONFIG	     ProgramControl_CTANK_DR_VDDIO
#else

    #define ProgramControl_DEFAULT_IDAC_POLARITY	 (0u)
	#define ProgramControl_CMOD_DR_CONFIG			 ProgramControl_CMOD_DR_VSSIO	
	#define ProgramControl_CTANK_DR_CONFIG	     ProgramControl_CTANK_DR_VSSIO 
#endif /* (ProgramControl_IDAC_OPTIONS == ProgramControl_IDAC_SINK) */

#define ProgramControl_SNS_GROUND_CONNECT       (6u)
#define ProgramControl_SNS_HIZANALOG_CONNECT    (0u)

/* Inactive sensors connection configuration */
#if (ProgramControl_CONNECT_INACTIVE_SNS == ProgramControl__GROUND)
    #define ProgramControl_CSD_INACTIVE_CONNECT       (ProgramControl_SNS_GROUND_CONNECT)
#else
    #define ProgramControl_CSD_INACTIVE_CONNECT       (ProgramControl_SNS_HIZANALOG_CONNECT)
#endif /* ProgramControl_CONNECT_INACTIVE_SNS == ProgramControl__GROUND */

#if(ProgramControl_IS_SHIELD_ENABLE)
    #define ProgramControl_SHIELD_PORT_NUMBER ProgramControl_Shield__PORT
    #define ProgramControl_SHIELD_PIN_NUMBER  ProgramControl_Shield__SHIFT
#endif /* (ProgramControl_IS_SHIELD_ENABLE) */

/* Defining default CSD configuration according to settings in customizer. */
#define ProgramControl_DEFAULT_CSD_CONFIG             (ProgramControl_DEFAULT_FILTER_STATE |\
														 ProgramControl_DEFAULT_MODULATION_MODE |\
                                                         ProgramControl_CSD_CFG_SENSE_COMP_BW |\
                                                         ProgramControl_DEFAULT_IDAC_POLARITY |\
                                                         ProgramControl_CSD_CFG_REFBUF_OUTSEL |\
                                                         ProgramControl_CSD_REFBUF_DRV_HIGH)

#define ProgramControl_CSD_CONFIG_MASK				(ProgramControl_CSD_CFG_FILTER_EN |\
														 ProgramControl_CSD_CFG_PRS_SELECT |\
														 ProgramControl_CSD_CFG_PRS_12_8 |\
														 ProgramControl_CSD_CFG_SENSE_COMP_BW |\
														 ProgramControl_CSD_CFG_REFBUF_EN |\
														 ProgramControl_CSD_CFG_REFBUF_OUTSEL |\
														 ProgramControl_CSD_CFG_POLARITY_VDDIO |\
														 ProgramControl_CSD_CFG_REFBUF_OUTSEL  |\
														 ProgramControl_CSD_REFBUF_DRV_MASK) 


/* Defining the default IDACs configuration according to settings in customizer. */
#if (ProgramControl_IDAC_CNT == 1u)
	#define ProgramControl_DEFAULT_CSD_IDAC_CONFIG        (ProgramControl_CSD_IDAC1_MODE_VARIABLE |\
	                                                         ProgramControl_DEFAULT_IDAC1_RANGE)
#else
	#define ProgramControl_DEFAULT_CSD_IDAC_CONFIG        (ProgramControl_CSD_IDAC1_MODE_VARIABLE |\
	                                                         ProgramControl_CSD_IDAC2_MODE_FIXED |\
	                                                         ProgramControl_DEFAULT_IDAC1_RANGE |\
	                                                         ProgramControl_DEFAULT_IDAC2_RANGE)
#endif /* (ProgramControl_IDAC_CNT == 1u) */

/* Defining mask intended for clearing bits related to pre-charging options. */
#define ProgramControl_PRECHARGE_CONFIG_MASK			(ProgramControl_CSD_CFG_REFBUF_EN |\
														 ProgramControl_CSD_CFG_CHARGE_IO |\
														 ProgramControl_CSD_CFG_COMP_PIN_CH2  |\
														 ProgramControl_CSD_CFG_REFBUF_OUTSEL)

/* Cmod precharge mode configuration */
#if(ProgramControl_CMOD_PREGARGE_OPTION == ProgramControl__CAPPRVREF)

	#define ProgramControl_CMOD_PRECHARGE_CONFIG 		(ProgramControl_CSD_CFG_REFBUF_EN |\
														 ProgramControl_CSD_CFG_COMP_PIN_CH2)
														 
#else

	#define ProgramControl_CMOD_PRECHARGE_CONFIG 		(ProgramControl_CSD_CFG_REFBUF_OUTSEL |\
														 ProgramControl_CSD_CFG_REFBUF_EN |\
														 ProgramControl_CSD_CFG_CHARGE_IO)
														 
#endif /* (ProgramControl_CMOD_PREGARGE_OPTION == ProgramControl__CAPPRVREF) */


/* Ctank precharge mode configuration */
#if(ProgramControl_CSH_TANK_PREGARGE_OPTION == ProgramControl__CAPPRVREF)
		
	#if(0u != ProgramControl_IS_SHIELD_ENABLE)
		#define  ProgramControl_CTANK_PRECHARGE_CONFIG	(ProgramControl_CSD_CFG_REFBUF_EN |\
															 ProgramControl_CSD_CFG_PRS_CLEAR |\
															 ProgramControl_CSD_CFG_REFBUF_OUTSEL)
	#else
		#define  ProgramControl_CTANK_PRECHARGE_CONFIG	(ProgramControl_CSD_CFG_REFBUF_OUTSEL |\
															 ProgramControl_CSD_CFG_PRS_CLEAR)
	#endif /* (0u != ProgramControl_IS_SHIELD_ENABLE) */
	
#else

	#define  ProgramControl_CTANK_PRECHARGE_CONFIG	(ProgramControl_CSD_CFG_REFBUF_OUTSEL |\
														 ProgramControl_CSD_CFG_REFBUF_EN |\
														 ProgramControl_CSD_CFG_CHARGE_IO |\
														 ProgramControl_CSD_CFG_PRS_CLEAR |\
														 ProgramControl_CSD_CFG_COMP_PIN_CH2)
#endif /* (ProgramControl_CSH_TANK_PREGARGE_OPTION == ProgramControl__CAPPRIOBUF) */

/* SmartSense functions */
#if (ProgramControl_TUNING_METHOD == ProgramControl__TUNING_AUTO)
    extern uint8 ProgramControl_lowLevelTuningDone;
    extern void ProgramControl_AutoTune(void);
#endif /* (ProgramControl_TUNING_METHOD == ProgramControl__TUNING_AUTO) */

extern uint16 ProgramControl_sensorRaw[ProgramControl_TOTAL_SENSOR_COUNT];

#define ProgramControl_MAX_UINT_8					(0xFFu)
#define ProgramControl_MAX_UINT_16				(0xFFFFu)
#define ProgramControl_MAX_UINT_32				(0xFFFFFFFFLu)

/***************************************************
*    Obsolete Names (will be removed in future)
***************************************************/
#define  ProgramControl_PrescalersTuningDone         ProgramControl_prescalersTuningDone
#define  ProgramControl_SensorRaw	                   ProgramControl_sensorRaw
#define  ProgramControl_PRSResolutionTbl             ProgramControl_prsResolutionTbl
#define  ProgramControl_SensorEnableMask             ProgramControl_sensorEnableMask
#define  ProgramControl_Clk1DividerVal               ProgramControl_senseClkDividerVal
#define  ProgramControl_Clk2DividerVal               ProgramControl_sampleClkDividerVal
#define  ProgramControl_PrtSelTbl                    ProgramControl_prtSelTbl
#define  ProgramControl_PrtCfgTbl                    ProgramControl_prtCfgTbl
#define  ProgramControl_PrtDRTbl                     ProgramControl_prtDRTbl
#define  ProgramControl_idac1Settings				   ProgramControl_modulationIDAC	
#define  ProgramControl_idac2Settings                ProgramControl_compensationIDAC

#endif /* CY_CAPSENSE_CSD_ProgramControl_H */


 /* [] END OF FILE */
