/*******************************************************************************
* File Name: ProgramControl_CSHL.h
* Version 2.0
*
* Description:
*  This file provides constants and parameter values for the High Level APIs
*  for CapSense CSD component.
*
* Note:
*
********************************************************************************
* Copyright 2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_CAPSENSE_CSD_CSHL_ProgramControl_H)
#define CY_CAPSENSE_CSD_CSHL_ProgramControl_H

#include "ProgramControl.h"


/***************************************
*   Condition compilation parameters
***************************************/

#define ProgramControl_SIGNAL_SIZE                    (8u)
#define ProgramControl_AUTO_RESET                     (0u)
#define ProgramControl_RAW_FILTER_MASK                (8u)

/* Signal size definition */
#define ProgramControl_SIGNAL_SIZE_UINT8              (8u)
#define ProgramControl_SIGNAL_SIZE_UINT16             (16u)

/* Auto reset definition */
#define ProgramControl_AUTO_RESET_DISABLE             (0u)
#define ProgramControl_AUTO_RESET_ENABLE              (1u)

/* Mask for RAW and POS filters */
#define ProgramControl_MEDIAN_FILTER                  (0x01u)
#define ProgramControl_AVERAGING_FILTER               (0x02u)
#define ProgramControl_IIR2_FILTER                    (0x04u)
#define ProgramControl_IIR4_FILTER                    (0x08u)
#define ProgramControl_JITTER_FILTER                  (0x10u)
#define ProgramControl_IIR8_FILTER                    (0x20u)
#define ProgramControl_IIR16_FILTER                   (0x40u)
                                                        

/***************************************
*           API Constants
***************************************/

/* Widgets constants definition */
#define ProgramControl_BACKWARD__BTN        (0u)
#define ProgramControl_FORWARD__BTN        (1u)
#define ProgramControl_MINUS__BTN        (2u)
#define ProgramControl_PLUS__BTN        (3u)

#define ProgramControl_TOTAL_DIPLEXED_SLIDERS_COUNT        (0u)
#define ProgramControl_TOTAL_LINEAR_SLIDERS_COUNT          (0u)
#define ProgramControl_TOTAL_RADIAL_SLIDERS_COUNT          (0u)
#define ProgramControl_TOTAL_TOUCH_PADS_COUNT              (0u)
#define ProgramControl_TOTAL_BUTTONS_COUNT                 (4u)
#define ProgramControl_TOTAL_MATRIX_BUTTONS_COUNT          (0u)
#define ProgramControl_TOTAL_GENERICS_COUNT                (0u)

#define ProgramControl_POS_FILTERS_MASK                    (0u)
#define ProgramControl_LINEAR_SLIDERS_POS_FILTERS_MASK     (0u)
#define ProgramControl_RADIAL_SLIDERS_POS_FILTERS_MASK     (0u)
#define ProgramControl_TOUCH_PADS_POS_FILTERS_MASK         (0u)

#define ProgramControl_UNUSED_DEBOUNCE_COUNTER_INDEX       (4u)

#define ProgramControl_TOTAL_PROX_SENSORS_COUNT            (0u)

#define ProgramControl_END_OF_SLIDERS_INDEX                (0u)
#define ProgramControl_END_OF_TOUCH_PAD_INDEX              (0u)
#define ProgramControl_END_OF_BUTTONS_INDEX                (3u)
#define ProgramControl_END_OF_MATRIX_BUTTONS_INDEX         (3u)
#define ProgramControl_END_OF_WIDGETS_INDEX                (4u)



#define ProgramControl_TOTAL_SLIDERS_COUNT            ( ProgramControl_TOTAL_LINEAR_SLIDERS_COUNT + \
                                                          ProgramControl_TOTAL_RADIAL_SLIDERS_COUNT )
                                                          
#define ProgramControl_TOTAL_CENTROIDS_COUNT          ( ProgramControl_TOTAL_SLIDERS_COUNT + \
                                                         (ProgramControl_TOTAL_TOUCH_PADS_COUNT*2u) )

#define ProgramControl_TOTAL_WIDGET_COUNT             ( ProgramControl_TOTAL_LINEAR_SLIDERS_COUNT + \
                                                          ProgramControl_TOTAL_RADIAL_SLIDERS_COUNT + \
                                                          ProgramControl_TOTAL_TOUCH_PADS_COUNT + \
                                                          ProgramControl_TOTAL_BUTTONS_COUNT + \
                                                          ProgramControl_TOTAL_MATRIX_BUTTONS_COUNT )
                                                           
#define ProgramControl_ANY_POS_FILTER                 ( ProgramControl_MEDIAN_FILTER | \
                                                          ProgramControl_AVERAGING_FILTER | \
                                                          ProgramControl_IIR2_FILTER | \
                                                          ProgramControl_IIR4_FILTER | \
                                                          ProgramControl_JITTER_FILTER )
                                                         
#define ProgramControl_IS_DIPLEX_SLIDER               ( ProgramControl_TOTAL_DIPLEXED_SLIDERS_COUNT > 0u)

#define ProgramControl_IS_NON_DIPLEX_SLIDER           ( (ProgramControl_TOTAL_LINEAR_SLIDERS_COUNT - \
                                                           ProgramControl_TOTAL_DIPLEXED_SLIDERS_COUNT) > 0u)
#define ProgramControl_ADD_SLIDER_TYPE                ((ProgramControl_TOTAL_RADIAL_SLIDERS_COUNT > 0u) ? \
                                                        ((ProgramControl_TOTAL_TOUCH_PADS_COUNT > 0u) || \
                                                         (ProgramControl_TOTAL_LINEAR_SLIDERS_COUNT > 0u)) : 0u)

#define ProgramControl_TOTAL_PROX_SENSOR_COUNT		(ProgramControl_TOTAL_PROX_SENSORS_COUNT)

#define ProgramControl_WIDGETS_TBL_SIZE               ( ProgramControl_TOTAL_WIDGET_COUNT + \
                                                          ProgramControl_TOTAL_GENERICS_COUNT)
                                                          
#define ProgramControl_WIDGET_PARAM_TBL_SIZE		    (ProgramControl_TOTAL_BUTTONS_COUNT + \
                                                        ProgramControl_TOTAL_CENTROIDS_COUNT + \
                                                          ProgramControl_TOTAL_MATRIX_BUTTONS_COUNT * 2u)                                                          
												  
#define ProgramControl_RESOLUTIONS_TBL_SIZE       (ProgramControl_WIDGET_PARAM_TBL_SIZE + \
													 ProgramControl_TOTAL_GENERICS_COUNT)

#define ProgramControl_THRESHOLD_TBL_SIZE			(ProgramControl_WIDGET_PARAM_TBL_SIZE)
#define ProgramControl_DEBOUNCE_CNT_TBL_SIZE		(ProgramControl_WIDGET_PARAM_TBL_SIZE)


#define ProgramControl_NOT_WIDGET		                (0xFFFFFFFFu)
														  
/*Types of centroids */
#define ProgramControl_TYPE_RADIAL_SLIDER             (0x01u)
#define ProgramControl_TYPE_LINEAR_SLIDER             (0x02u)
#define ProgramControl_TYPE_GENERIC                   (0xFFu)

/* Defines if sensors or widgets are active */
#define ProgramControl_SENSOR_IS_ACTIVE               (0x01u)
#define ProgramControl_SENSOR_1_IS_ACTIVE     		(0x01u)
#define ProgramControl_SENSOR_2_IS_ACTIVE     		(0x02u)
#define ProgramControl_WIDGET_IS_ACTIVE               (0x01u)

/* Defines diplex type of Slider */
#define ProgramControl_IS_DIPLEX                      (0x80u)

/* Defines fingers positions on Slider  */
#define ProgramControl_POS_PREV                       (0u)
#define ProgramControl_POS                            (1u)
#define ProgramControl_POS_NEXT                       (2u)
#define ProgramControl_CENTROID_ROUND_VALUE           (0x7F00u)
#define ProgramControl_MAXIMUM_CENTROID               (0xFFu)

#define ProgramControl_NEGATIVE_NOISE_THRESHOLD       (20u)
#define ProgramControl_LOW_BASELINE_RESET             (5u)


/***************************************
*        Function Prototypes
***************************************/

void ProgramControl_InitializeSensorBaseline(uint32 sensor);
void ProgramControl_InitializeAllBaselines(void);
void ProgramControl_InitializeEnabledBaselines(void);
void ProgramControl_UpdateSensorBaseline(uint32 sensor);
void ProgramControl_UpdateEnabledBaselines(void);
uint16 ProgramControl_GetBaselineData(uint32 sensor);
void ProgramControl_SetBaselineData(uint32 sensor, uint16 data);
void ProgramControl_BaseInit(uint32 sensor);

#if (ProgramControl_IS_DIPLEX_SLIDER)
	uint8 ProgramControl_FindMaximum(uint8 offset, uint8 count, uint8 fingerThreshold, const uint8 *diplex);
#else 
	uint8 ProgramControl_FindMaximum(uint8 offset, uint8 count, uint8 fingerThreshold);
#endif /* (ProgramControl_IS_DIPLEX_SLIDER) */

uint8 ProgramControl_CalcCentroid(uint8 maximum, uint8 offset, \
                                    uint8 count, uint16 resolution, uint8 noiseThreshold);

uint8 ProgramControl_GetFingerThreshold(uint32 widget);
uint8 ProgramControl_GetNoiseThreshold(uint32 widget);
uint8 ProgramControl_GetFingerHysteresis(uint32 widget);
uint8 ProgramControl_GetNegativeNoiseThreshold(uint32 widget);

#if(ProgramControl_TUNING_METHOD != ProgramControl__TUNING_NONE)
	void ProgramControl_SetFingerThreshold(uint32 widget, uint8 value);
	void ProgramControl_SetNoiseThreshold(uint32 widget, uint8 value);
	void ProgramControl_SetFingerHysteresis(uint32 widget, uint8 value);
	void ProgramControl_SetNegativeNoiseThreshold(uint32 widget, uint8 value);
	void ProgramControl_SetDebounce(uint32 widget, uint8 value);
	void ProgramControl_SetLowBaselineReset(uint32 sensor, uint8 value);
#endif /* (ProgramControl_TUNING_METHOD != ProgramControl__TUNING_NONE) */

uint8 ProgramControl_GetDiffCountData(uint32 sensor);
void ProgramControl_SetDiffCountData(uint32 sensor, uint8 value);								
							
uint32 ProgramControl_CheckIsSensorActive(uint32 sensor);
uint32 ProgramControl_CheckIsWidgetActive(uint32 widget);
uint32 ProgramControl_CheckIsAnyWidgetActive(void);
void ProgramControl_EnableWidget(uint32 widget);
void ProgramControl_DisableWidget(uint32 widget);


#if (ProgramControl_TOTAL_MATRIX_BUTTONS_COUNT)
    uint32 ProgramControl_GetMatrixButtonPos(uint32 widget, uint8* pos);
#endif /* (ProgramControl_TOTAL_MATRIX_BUTTONS_COUNT) */

#if((ProgramControl_TOTAL_RADIAL_SLIDERS_COUNT > 0u) || (ProgramControl_TOTAL_LINEAR_SLIDERS_COUNT > 0u))
    uint16 ProgramControl_GetCentroidPos(uint32 widget);
#endif /* ((ProgramControl_TOTAL_RADIAL_SLIDERS_COUNT > 0u) || (ProgramControl_TOTAL_LINEAR_SLIDERS_COUNT > 0u)) */
#if((ProgramControl_TOTAL_RADIAL_SLIDERS_COUNT > 0u) || (ProgramControl_TOTAL_LINEAR_SLIDERS_COUNT > 0u))
    uint16 ProgramControl_GetRadialCentroidPos(uint32 widget);
#endif /* #if((ProgramControl_TOTAL_RADIAL_SLIDERS_COUNT > 0u) || (ProgramControl_TOTAL_LINEAR_SLIDERS_COUNT > 0u)) */
#if (ProgramControl_TOTAL_TOUCH_PADS_COUNT)
    uint32 ProgramControl_GetTouchCentroidPos(uint32 widget, uint16* pos);
#endif /* (ProgramControl_TOTAL_TOUCH_PADS_COUNT) */

uint32 ProgramControl_GetWidgetNumber(uint32 sensor);
uint8 ProgramControl_GetLowBaselineReset(uint32 sensor);
uint8 ProgramControl_GetDebounce(uint32 widget);

/***************************************
*        Obsolete Names
***************************************/
#define ProgramControl_SensorRaw				ProgramControl_sensorRaw
#define ProgramControl_SensorEnableMask		ProgramControl_sensorEnableMask
#define ProgramControl_SensorBaseline			ProgramControl_sensorBaseline
#define ProgramControl_SensorBaselineLow		ProgramControl_sensorBaselineLow
#define ProgramControl_SensorSignal			ProgramControl_sensorSignal
#define ProgramControl_SensorOnMask			ProgramControl_sensorOnMask
#define ProgramControl_LowBaselineResetCnt	ProgramControl_lowBaselineResetCnt

#endif /* CY_CAPSENSE_CSD_CSHL_ProgramControl_H */

/* [] END OF FILE */
