/*******************************************************************************
* File Name: ProgramControl_INT.c
* Version 2.0
*
* Description:
*  This file provides the source code of the  Interrupt Service Routine (ISR)
*  for the CapSense CSD component.
*
* Note:
*
********************************************************************************
* Copyright 2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "ProgramControl.h"

/*******************************************************************************
*  Place your includes, defines and code here 
********************************************************************************/
/* `#START ProgramControl_ISR_INTC` */

/* `#END` */

/* Extern functions declarations, Start and Compete scan */
extern void ProgramControl_PreScan(uint32 sensor);
extern void ProgramControl_PostScan(uint32 sensor);

extern uint8 ProgramControl_FindNextSensor(uint8 snsIndex);
 
/* Global variables and arrays */
extern volatile uint8 ProgramControl_csdStatusVar;
extern volatile uint8 ProgramControl_sensorIndex;

static uint8 ProgramControl_snsIndexTmp;

extern volatile uint8 ProgramControl_sensorEnableMask[];
extern uint8 ProgramControl_sensorEnableMaskBackup[];

/*******************************************************************************
* Function Name: ProgramControl_ISR
********************************************************************************
*
* Summary:
*  This ISR is executed when the measure window is closed. The measure window 
*  depends on the sensor scan resolution parameter. 
*  The ISR has two modes: 
*   1. Scans a single sensor and stores the measure result.
*   2. Stores the result of the current measure and starts the next scan till all 
*      the enabled sensors are scanned.
*  This interrupt handler is only used in one channel designs.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global Variables:
*  ProgramControl_csv - used to provide the status and mode of the scanning process.
*   Mode - a single scan or scan of all the enabled sensors.
*   Status - scan is in progress or ready for new scan.
*  ProgramControl_sensorIndex - used to store a sensor scanning sensor number.
*
* Reentrant:
*  No
*
*******************************************************************************/
CY_ISR(ProgramControl_ISR)
{	
	/*  Place your Interrupt code here. */
    /* `#START ProgramControl_ISR_ENTER` */

    /* `#END` */

	CyIntDisable(ProgramControl_ISR_NUMBER);
    
    ProgramControl_CSD_INTR_REG = 1u;

    ProgramControl_PostScan((uint32)ProgramControl_sensorIndex);
            
    if ((ProgramControl_csdStatusVar & ProgramControl_SW_CTRL_SINGLE_SCAN) != 0u)
    {
        ProgramControl_csdStatusVar &= (uint8)~ProgramControl_SW_STS_BUSY;
    }
    else
    {
        /* Proceed scanning */
        ProgramControl_sensorIndex = ProgramControl_FindNextSensor(ProgramControl_sensorIndex);
        
        /* Check end of scan */
        if(ProgramControl_sensorIndex < ProgramControl_TOTAL_SENSOR_COUNT)
        {
            ProgramControl_PreScan((uint32)ProgramControl_sensorIndex);
        }
        else
        {
            ProgramControl_csdStatusVar &= (uint8)~ProgramControl_SW_STS_BUSY;

			 /* Check if widget has been scanned */
			if((ProgramControl_csdStatusVar & ProgramControl_SW_CTRL_WIDGET_SCAN) != 0u)
			{
			    /* Restore sensorEnableMask array */
				for(ProgramControl_snsIndexTmp = 0u; 
				    ProgramControl_snsIndexTmp < ProgramControl_TOTAL_SENSOR_MASK; 
					ProgramControl_snsIndexTmp++)
				{
					/* Backup sensorEnableMask array */
					ProgramControl_sensorEnableMask[ProgramControl_snsIndexTmp] = ProgramControl_sensorEnableMaskBackup[ProgramControl_snsIndexTmp];
				}
			}
        } 
    }
    CyIntEnable(ProgramControl_ISR_NUMBER);
	
	/*  Place your Interrupt code here. */
    /* `#START ProgramControl_ISR_EXIT` */

    /* `#END` */
}

/* [] END OF FILE */
