/*******************************************************************************
* File Name: ProgramControl_PVT.h
* Version 2.10
*
* Description:
*  This file provides constants and structure declarations for the
*  CapSense CSD component.
*
* Note:
*
********************************************************************************
* Copyright 2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/


#if !defined(CY_CAPSENSE_CSD_PVT_ProgramControl_H)
#define CY_CAPSENSE_CSD_PVT_ProgramControl_H

#include "ProgramControl.h"

#if(0u != ProgramControl_CSHL_API_GENERATE)
	#include "ProgramControl_CSHL.h"
#endif /* (0u != ProgramControl_CSHL_API_GENERATE) */

#if(ProgramControl_TOTAL_TRACKPAD_GESTURES_COUNT > 0u)
	#include "ProgramControl_GESTURE.h"
#endif /* (ProgramControl_TOTAL_TRACKPAD_GESTURES_COUNT > 0u) */
	
typedef struct
{
	#if (ProgramControl_IS_COMPLEX_SCANSLOTS)
	uint8 sensor;
	#endif  /* ProgramControl_IS_COMPLEX_SCANSLOTS */
	uint8 pinNumber;
	uint8 portNumber;
	uint8 idacValue;
	uint16 senseClkDiv;
	uint16 sampleClkDiv;
	uint8 avgSamplesNum;
	uint16 calibrationCount;
	uint32 scanResolution;
}ProgramControl_CP_MEASURE_CONFIG;

typedef struct
{
    uint8 *idac1LevelsTbl;
    uint8 *idac2LevelsTbl;
    uint8 *sensetivityTbl;
    uint8 *chargeDivTbl;
    uint8 *modDivTbl;
    const uint8  *widgetNubmersTbl;
    uint32 *resolutionsTbl;
	uint8 const  *rawDataIndex;
	uint8 const *numberOfSensors;
    uint16 (*ptrGetRaw)(uint32 sensor);
	void (*ptrPreScan)(uint32 sensor);
	uint16 (*ptrReadSensorRaw)(uint32 sensor);
    uint32 (*ptrGetBitValue)(const uint8 table[], uint32 position);
	void (*ptrSetBitValue)(uint8 table[], uint32 position, uint32 value);
}ProgramControl_CONFIG_TYPE_POINTERS_P4_v2_10;

typedef struct
{
    uint8 totalScanslotsNum;
	uint8 totalWidgetsNum;
    uint8 totalSensorsNum;
	uint16 sensetivitySeed;
	uint16 hfclkFreq_MHz;
    ProgramControl_CONFIG_TYPE_POINTERS_P4_v2_10 const * pointers;
}ProgramControl_CONFIG_TYPE_P4_v2_10;

#define ProgramControl_AVG_SAMPLES_NUM		(1u)


/***************************************
*        Function Prototypes
***************************************/
void ProgramControl_PreScan(uint32 sensor);
void ProgramControl_PostScan(uint32 sensor);

__INLINE void ProgramControl_EnableSensor(uint32 sensor);
__INLINE void ProgramControl_DisableSensor(uint32 sensor);

#if (ProgramControl_IS_COMPLEX_SCANSLOTS)
    void ProgramControl_EnableScanSlot(uint32 slot);
    void ProgramControl_DisableScanSlot(uint32 slot);
#else
    #define ProgramControl_EnableScanSlot(slot)   ProgramControl_EnableSensor(slot)
    #define ProgramControl_DisableScanSlot(slot)  ProgramControl_DisableSensor(slot)
#endif  /* End ProgramControl_IS_COMPLEX_SCANSLOTS */

void ProgramControl_EnableShieldElectrode(uint32 pinNumber, uint32 portNumber);

uint32 ProgramControl_GetBitValue(const uint8 table[], uint32 position);
void ProgramControl_SetBitValue(uint8 table[], uint32 position, uint32 value);

/* Find next sensor for One Channel design */
uint8 ProgramControl_FindNextSensor(uint8 snsIndex);

void ProgramControl_SetPinDriveMode(uint32 driveMode, uint32 pinNumber, uint32 portNumber);
void ProgramControl_CalibrateSensor(uint32 sensor, uint32 rawLevel, uint8 idacLevelsTbl[]);
uint16  ProgramControl_GetSensorRaw(uint32 sensor);

void ProgramControl_DisableBaselineIDAC(void);
void ProgramControl_EnableBaselineIDAC(const ProgramControl_CONFIG_TYPE_P4_v2_10 *config);

uint32 ProgramControl_GetLowCp(ProgramControl_CP_MEASURE_CONFIG *config);
uint32 ProgramControl_GetHighCp(const ProgramControl_CP_MEASURE_CONFIG *config);
uint32 ProgramControl_CalibrateIDAC(ProgramControl_CP_MEASURE_CONFIG *config);
uint16 ProgramControl_ScanSensorCp(const ProgramControl_CP_MEASURE_CONFIG *config);

void ProgramControl_ConnectElectrode(uint32 pinNumber, uint32 portNumber);
void ProgramControl_DisconnectElectrode(uint32 pinNumber, uint32 portNumber);

void TunePrescalers_P4_v2_10(ProgramControl_CONFIG_TYPE_P4_v2_10 *config);
void TuneSensitivity_P4_v2_10(ProgramControl_CONFIG_TYPE_P4_v2_10 *config);
void MeasureNoiseEnvelope_P4_v2_10(ProgramControl_CONFIG_TYPE_P4_v2_10 *config, const uint8 sensorNumber, const uint16 *rawData);
void CalculateThresholds_P4_v2_10(ProgramControl_CONFIG_TYPE_P4_v2_10 *config, const uint8 sensorNumber, const uint16 *rawData, const uint8 widget, uint8 *fingerThres, uint8 *noiseThres);
void CalibrateSensors_P4_v2_10(ProgramControl_CONFIG_TYPE_P4_v2_10 *config, uint16 rawLevel);
void CalibrateOneDAC_P4_v2_10(ProgramControl_CONFIG_TYPE_P4_v2_10 *config, uint16 rawLevel, uint32 curSensor, uint8 *idacLevelsTbl);


#endif /* CY_CAPSENSE_CSD_PVT_ProgramControl_H */
