/*******************************************************************************
* File Name: ProgramControl_SMS.c
* Version 2.0
*
* Description:
*  This file provides the source code of wrapper between CapSense CSD component 
*  and Auto Tuning library.
*
* Note:
*
********************************************************************************
* Copyright 2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "ProgramControl_SMS.h"
#include "ProgramControl_PVT.h"

#include "cytypes.h"

#define ProgramControl_PRS_CORRECTION_DIVIDER (4u)
#define ProgramControl_MAX_RESOLUTION         (65535u)
#define ProgramControl_SENSITIVITY_DIVIDER    (10u)

#if (ProgramControl_TUNING_METHOD == ProgramControl__TUNING_AUTO)

#if (0u != ProgramControl_IS_M0S8PERI_BLOCK)
    /*  Dividers are not chained */ 
	#if(ProgramControl_PRS_OPTIONS != ProgramControl__PRS_NONE)
		#define ProgramControl_SENSETIVITY_FACTOR (1228u)
	#else
		#define ProgramControl_SENSETIVITY_FACTOR (2456u)
	#endif /* (ProgramControl_PRS_OPTIONS == ProgramControl__PRS_NONE) */
#else
    /*  Dividers are chained */
	#if(ProgramControl_PRS_OPTIONS != ProgramControl__PRS_NONE)
		#define ProgramControl_SENSETIVITY_FACTOR (1228u/ProgramControl_CALIBRATION_MD)
	#else
		#define ProgramControl_SENSETIVITY_FACTOR (2456u/ProgramControl_CALIBRATION_MD)
	#endif /* (ProgramControl_PRS_OPTIONS == ProgramControl__PRS_NONE) */
#endif /* (0u != ProgramControl_IS_M0S8PERI_BLOCK) */


#if(ProgramControl_PRS_OPTIONS != ProgramControl__PRS_NONE)
	extern uint8 ProgramControl_prescalersTuningDone;
#endif /* (ProgramControl_PRS_OPTIONS == ProgramControl__PRS_NONE) */


/*  Real Charge Divider values */
#if (0u != ProgramControl_IS_M0S8PERI_BLOCK)
    /*  Dividers are not chained */
	#if (CYDEV_BCLK__HFCLK__MHZ >= 12u)
		const uint8 prescalerTable[] = {
			1u,     1u,     1u,    2u,    2u,    2u,    2u,    4u,    4u,    4u,    4u,    4u,    4u,    4u,    4u,    4u
		};

	#elif (CYDEV_BCLK__HFCLK__MHZ >= 6u)
		const uint8 prescalerTable[] = {
			1u,     1u,     1u,    1u,    1u,    1u,    1u,    2u,    2u,    2u,    2u,    2u,    2u,    2u,    2u,    2u
		};
	#else
		const uint8 prescalerTable[] = {
			1u,     1u,     1u,    1u,    1u,    1u,    1u,    1u,    1u,    1u,    1u,    1u,    1u,    1u,    1u,    1u
		};
	#endif /* (CYDEV_BCLK__HFCLK__MHZ > 12u) */
#else
    /*  Dividers are chained */ 
	#if (CYDEV_BCLK__HFCLK__MHZ > 24u)
		const uint8 prescalerTable[] = {
			2u,     2u,     2u,    4u,    4u,    4u,    4u,    8u,    8u,    8u,    8u,    8u,    8u,    8u,    8u,    8u
		};

	#elif (CYDEV_BCLK__HFCLK__MHZ >12u)
		const uint8 prescalerTable[] = {
			1u,     1u,     1u,    2u,    2u,    2u,    2u,    4u,    4u,    4u,    4u,    4u,    4u,    4u,    4u,    4u
		};
	#else   /* (CYDEV_BCLK__HFCLK__MHZ > 12u) */
		const uint8 prescalerTable[] = {
			1u,     1u,     1u,    1u,    1u,    1u,    1u,    2u,    2u,    2u,    2u,    2u,    2u,    2u,    2u,    2u
		};
	#endif /* (CYDEV_BCLK__HFCLK__MHZ > 24u) */
#endif /* (0u != ProgramControl_IS_M0S8PERI_BLOCK) */


extern uint16 ProgramControl_sensorRaw[ProgramControl_TOTAL_SENSOR_COUNT];
extern uint8 ProgramControl_sensorSignal[ProgramControl_TOTAL_SENSOR_COUNT];

extern uint32 ProgramControl_widgetResolution[ProgramControl_RESOLUTIONS_TBL_SIZE];
extern const uint8 ProgramControl_widgetNumber[ProgramControl_TOTAL_SENSOR_COUNT];

extern const uint8 ProgramControl_rawDataIndex[ProgramControl_WIDGETS_TBL_SIZE];
extern const uint8 ProgramControl_numberOfSensors[ProgramControl_WIDGETS_TBL_SIZE];

extern uint8 ProgramControl_modulationIDAC[ProgramControl_TOTAL_SENSOR_COUNT];
extern uint8 ProgramControl_compensationIDAC[ProgramControl_TOTAL_SENSOR_COUNT];

extern uint8 ProgramControl_senseClkDividerVal[ProgramControl_TOTAL_SCANSLOT_COUNT];
extern uint8 ProgramControl_sampleClkDividerVal[ProgramControl_TOTAL_SCANSLOT_COUNT];

extern uint8 ProgramControl_fingerThreshold[ProgramControl_THRESHOLD_TBL_SIZE];
extern uint8 ProgramControl_noiseThreshold[ProgramControl_THRESHOLD_TBL_SIZE];
extern uint8 ProgramControl_hysteresis[ProgramControl_WIDGET_PARAM_TBL_SIZE];
extern uint8 ProgramControl_negativeNoiseThreshold[ProgramControl_THRESHOLD_TBL_SIZE];

uint8 noiseEnvelopeTbl[ProgramControl_TOTAL_SENSOR_COUNT];
uint8 runningDifferenceTbl[ProgramControl_TOTAL_SENSOR_COUNT];
uint8 signRegisterTbl[ProgramControl_TOTAL_SENSOR_COUNT];
uint16 sampleMinTbl[ProgramControl_TOTAL_SENSOR_COUNT];
uint16 sampleMaxTbl[ProgramControl_TOTAL_SENSOR_COUNT];
uint16 previousSampleTbl[ProgramControl_TOTAL_SENSOR_COUNT];
uint8 kValueTbl[ProgramControl_TOTAL_SENSOR_COUNT];   
uint8 scanSpeedTbl[((ProgramControl_TOTAL_SENSOR_COUNT - 1u) / 8u) + 1u];

uint8 SMS_LIB_SensorSensitivity[] = {
    2u, 2u, 2u, 2u, 
};

ProgramControl_CONFIG_TYPE_P4_v2_0 ProgramControl_config;
ProgramControl_CONFIG_TYPE_POINTERS_P4_v2_0 const ProgramControl_configPointers = {
    ProgramControl_modulationIDAC,
    ProgramControl_compensationIDAC,
     SMS_LIB_SensorSensitivity,
    ProgramControl_senseClkDividerVal,
    ProgramControl_sampleClkDividerVal,
    ProgramControl_widgetNumber,
    ProgramControl_widgetResolution,
	(const uint8  *)ProgramControl_rawDataIndex,
	(const uint8  *)ProgramControl_numberOfSensors,
    &ProgramControl_GetSensorRaw,
    &ProgramControl_PreScan,
    &ProgramControl_ReadSensorRaw,
    &ProgramControl_GetBitValue,
	&ProgramControl_SetBitValue
};


/*******************************************************************************
* Function Name: ProgramControl_AutoTune
********************************************************************************
*
* Summary:
*  Provides the tuning procedure for all sensors.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global Variables:
*   ProgramControl_config: the structure which contains configuration parameters
*   ProgramControl_senseClkDividerVal[]: used to store the Analog Switch 
*   dividers for each sensor.
*   ProgramControl_senseClkDividerVal[]: used to store the 
*    Analog Switch divider for all sensors.
*   ProgramControl_prescalersTuningDone - used to notify the Tuner GUI that 
*   the pre-scalers tuning  is done.
*
* Side Effects:
*  None
*
*******************************************************************************/
void ProgramControl_AutoTune(void)
{
	uint32 curSensor;
    uint32 widget;

	ProgramControl_config.totalScanslotsNum = ProgramControl_TOTAL_SCANSLOT_COUNT;
	ProgramControl_config.totalWidgetsNum = ProgramControl_END_OF_WIDGETS_INDEX;
	ProgramControl_config.totalSensorsNum = ProgramControl_TOTAL_SENSOR_COUNT;
	
	ProgramControl_config.hfclkFreq_MHz = CYDEV_BCLK__HFCLK__MHZ;
	ProgramControl_config.sensetivitySeed = ProgramControl_SENSETIVITY_FACTOR;
	
    ProgramControl_config.pointers = &ProgramControl_configPointers;       
    
	ProgramControl_SetAnalogSwitchesSrcDirect();
    
    for(widget = 0u; widget < ProgramControl_config.totalWidgetsNum; widget++)
    {
        ProgramControl_widgetResolution[widget] = ProgramControl_CALIBRATION_RESOLUTION;
    }
	

	for(curSensor = 0u; curSensor < ProgramControl_TOTAL_SCANSLOT_COUNT; curSensor++)
    {
		ProgramControl_senseClkDividerVal[curSensor] = ProgramControl_CALIBRATION_ASD;
		ProgramControl_sampleClkDividerVal[curSensor] = ProgramControl_CALIBRATION_MD;
	}
    
    ProgramControl_DisableBaselineIDAC();

    CalibrateSensors_P4_v2_0(&ProgramControl_config, ProgramControl_CAL_RAW_COUNT);
	ProgramControl_NormalizeWidgets(ProgramControl_END_OF_WIDGETS_INDEX, ProgramControl_modulationIDAC);
	
    TunePrescalers_P4_v2_0(&ProgramControl_config);
	
	#if(ProgramControl_PRS_OPTIONS != ProgramControl__PRS_NONE)
		ProgramControl_prescalersTuningDone = 1u;
	#endif /* (ProgramControl_PRS_OPTIONS == ProgramControl__PRS_NONE) */
       
    CalibrateSensors_P4_v2_0(&ProgramControl_config, ProgramControl_CAL_RAW_COUNT);
	ProgramControl_NormalizeWidgets(ProgramControl_END_OF_WIDGETS_INDEX, ProgramControl_modulationIDAC);
    TuneSensitivity_P4_v2_0(&ProgramControl_config);
	
	ProgramControl_EnableBaselineIDAC(&ProgramControl_config);
    
    for(curSensor = 0u; curSensor < ProgramControl_TOTAL_SCANSLOT_COUNT; curSensor++)
    {
        ProgramControl_UpdateThresholds(curSensor);
    }
}


/*******************************************************************************
* Function Name: ProgramControl_UpdateThresholds
********************************************************************************
*
* Summary:
*  The API updates the Finger Threshold, Hysteresis, Noise Threshold, and 
*  Negative Noise Threshold in the AutoTuning (Smartsense) Mode.
*
* Parameters:
*  sensor: sensor number.
*
* Return:
*  None
*
* Global Variables:
*  ProgramControl_widgetNumber[] - contains widget Number for given sensor.
*  0 through 7 (sensor 0 is bit 0, sensor 1 is bit 1).
*  For other sensors the array element equals to 255. 
*  ProgramControl_numberOfSensors[widget] - Number of sensors in the widget.
*   ProgramControl_fingerThreshold[] - contains the level of signal for each sensor
*   that determines if a finger present on the sensor.
*   ProgramControl_negativeNoiseThreshold[] - negative Noise Threshold
*   ProgramControl_hysteresis[] - the array with hysteresis values.
*
* Side Effects:
*  None
*
*******************************************************************************/
void ProgramControl_UpdateThresholds(uint32 sensor)
{
	uint8 fingerThreshold;
	uint32 widget;
	
	widget = ProgramControl_widgetNumber[sensor];

	if(0u != ProgramControl_FLEXIBLE_THRESHOLDS_EN)
	{
	    fingerThreshold = ProgramControl_fingerThreshold[widget];
        /* Update Threshold manually (flexible) */   
		ProgramControl_noiseThreshold[widget] = (uint8)(fingerThreshold >> 1u);
		ProgramControl_negativeNoiseThreshold[widget] = (uint8)(fingerThreshold >> 1u);
		ProgramControl_hysteresis[widget] = (uint8)(fingerThreshold >> 3u);
	}
	else
	{
		/* Calculate Finger Threshold and Noise Threshold with Smartsense (automatic) */ 	
		CalculateThresholds_P4_v2_0(&ProgramControl_config, (uint8)sensor, ProgramControl_sensorRaw, (uint8)widget, ProgramControl_fingerThreshold, ProgramControl_noiseThreshold);
		
	    fingerThreshold = ProgramControl_fingerThreshold[widget];
		
	    /* Update Threshold based on calculated with Smartsense (automatic) */
		ProgramControl_negativeNoiseThreshold[widget] = ProgramControl_noiseThreshold[widget];
        
		if(fingerThreshold < ProgramControl_THRESHOLD_1)
		{
			ProgramControl_hysteresis[widget] = (uint8)(fingerThreshold >> 3u);
		}
		else if(fingerThreshold <  ProgramControl_THRESHOLD_2)
		{
			ProgramControl_hysteresis[widget] = (uint8)(fingerThreshold >> 4u);
		}
		else if(fingerThreshold <  ProgramControl_THRESHOLD_3)
		{
			ProgramControl_hysteresis[widget] = (uint8)(fingerThreshold >> 5u);
		}
		else if(fingerThreshold <  ProgramControl_THRESHOLD_4)
		{
			ProgramControl_hysteresis[widget] = (uint8)(fingerThreshold >> 6u);
		}
		else
		{
			ProgramControl_hysteresis[widget] = 0u;
		}
	}
}


/*******************************************************************************
* Function Name: ProgramControl_NormalizeWidgets
********************************************************************************
*
* Summary:
*  This API aligns all the parameters of the widget to the maximum parameter.
*
* Parameters:
*  uint32 widgetsNum: Number of widgets.
*  uint8 *datsPrt: pointer ro array with widget parameters.	
*
* Return:
*  None
*
* Global Variables:
*  ProgramControl_numberOfSensors[] - Number of sensors in the widget.
*  ProgramControl_rawDataIndex[currentWidget] - Contains the  1st sensor
*  position in the widget.
*
* Side Effects:
*  None
*
*******************************************************************************/
void ProgramControl_NormalizeWidgets(uint32 widgetsNum, uint8 *dataPtr)
{
	uint32 currentWidget;
	uint32 currentSensor;
	uint32 lastSensor;
	uint32 sensorsPerWidget;
	uint32 maxPerWidget;

	for(currentWidget = 0u; currentWidget < widgetsNum; currentWidget++)
	{
		maxPerWidget = 0u;
		
		sensorsPerWidget = ProgramControl_numberOfSensors[currentWidget];
		currentSensor = ProgramControl_rawDataIndex[currentWidget];
		lastSensor = currentSensor + sensorsPerWidget;
		
		while(currentSensor < lastSensor)
		{
			if(maxPerWidget < dataPtr[currentSensor])
			{
				maxPerWidget = dataPtr[currentSensor];
			}
			currentSensor++;
		}
		
		currentSensor = ProgramControl_rawDataIndex[currentWidget];
		
		while(currentSensor < lastSensor)
		{
			dataPtr[currentSensor] = (uint8)maxPerWidget;
			currentSensor++;
		}
	}
}

/*******************************************************************************
* Function Name: ProgramControl_SetAnalogSwitchesSrcDirect
********************************************************************************
*
* Summary:
*  This API switches the charge clock source to prescaler. 
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global Variables:
*  None
*
* Side Effects:
*  None
*
*******************************************************************************/
void ProgramControl_SetAnalogSwitchesSrcDirect(void)
{
	ProgramControl_CSD_CFG_REG &= ~(ProgramControl_CSD_CFG_PRS_SELECT);
}


/*******************************************************************************
* Function Name: ProgramControl_DisableBaselineIDAC
********************************************************************************
*
* Summary:
*  The API disables the Compensation IDAC. 
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global Variables:
*  None
*
* Side Effects:
*  None
*
*******************************************************************************/
void ProgramControl_DisableBaselineIDAC(void)
{
	uint32 newRegValue;
    
    newRegValue = ProgramControl_CSD_IDAC_REG;
    
    newRegValue &= ~(ProgramControl_CSD_IDAC1_MODE_MASK | ProgramControl_CSD_IDAC2_MODE_MASK);
    newRegValue |= ProgramControl_CSD_IDAC1_MODE_VARIABLE;
    
	ProgramControl_CSD_IDAC_REG = newRegValue;
}


/*******************************************************************************
* Function Name: ProgramControl_EnableBaselineIDAC
********************************************************************************
*
* Summary:
*  The API enables the Compensation IDAC. 
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global Variables:
*  ProgramControl_compensationIDAC[] - used to store a 7-bit idac value for all the sensors.
*
* Side Effects:
*  None
*
*******************************************************************************/
void  ProgramControl_EnableBaselineIDAC(const ProgramControl_CONFIG_TYPE_P4_v2_0 *config)
{
    uint32 curSensor;
    uint32 newRegValue;

    for(curSensor = 0u; curSensor < config->totalScanslotsNum; curSensor++)
    {
		ProgramControl_compensationIDAC[curSensor] = ProgramControl_modulationIDAC[curSensor] / 2u;
	    ProgramControl_modulationIDAC[curSensor] = (ProgramControl_modulationIDAC[curSensor] + 1u) / 2u;
    }
	
	CyIntDisable(ProgramControl_ISR_NUMBER);
	
	newRegValue = ProgramControl_CSD_IDAC_REG;
    newRegValue &= ~(ProgramControl_CSD_IDAC1_MODE_MASK | ProgramControl_CSD_IDAC2_MODE_MASK);
    newRegValue |= (ProgramControl_CSD_IDAC1_MODE_VARIABLE | ProgramControl_CSD_IDAC2_MODE_FIXED);
    ProgramControl_CSD_IDAC_REG = newRegValue;
	
	CyIntEnable(ProgramControl_ISR_NUMBER);
}


/*******************************************************************************
* Function Name: ProgramControl_SetSensitivity
********************************************************************************
*
* Summary:
*  This API sets the sensitivity value for the sensor. The sensitivity 
*  value is used during the auto-tuning algorithm executed as part of the CapSense_Start API.
*  This API is called by the application layer prior to calling the CapSense_Start API. 
*  Calling this API after execution of CapSense_Start API has no effect. 
*
* Parameters: 
*  sensor  Sensor index 
*  data    Sensitivity of the sensor. Possible values are below
*  1 - 0.1pf sensitivity
*  2 - 0.2pf sensitivity
*  3 - 0.3pf sensitivity
*  4 - 0.4pf sensitivity
*  All other values, set sensitivity to 0.4pf
*
*  Return Value:
*   None
*
* Global Variables:
* SMS_LIB_SensorSensitivity[] - This 8-bits array contains Sensitivity in the LSB nibble
*                                and Noise Reset Counter value in the MSB nibble.      
*
* Side Effects: 
*  None
*
*******************************************************************************/
void ProgramControl_SetSensitivity(uint32 sensor, uint32 value)
{
	if(value > 4u)
	{
		value = 4u;
	}
	
    /* Clear SensorSensitivity value in LSB nibble */
	SMS_LIB_SensorSensitivity[sensor] &= (uint8)~ProgramControl_SENSITIVITY_MASK;
	/* Set SensorSensitivity value in LSB nibble */
	SMS_LIB_SensorSensitivity[sensor] |= (uint8)value;
}


/*******************************************************************************
* Function Name: ProgramControl_GetSensitivityCoefficient
********************************************************************************
*
* Summary:
*  This API returns the K coefficient for the appropriate sensor. 
*
* Parameters: 
*  sensor:  Sensor index 
*
*  Return Value:
*   K - value for the appropriate sensor.
*
* Global Variables:
*  kValueTbl[] - This 8-bits array contains the K value for each sensor.
*
* Side Effects: 
*  None
*
*******************************************************************************/
uint8 ProgramControl_GetSensitivityCoefficient(uint32 sensor)
{
	return (kValueTbl[sensor]);
}


/*******************************************************************************
* Function Name: ProgramControl_GetNoiseEnvelope
********************************************************************************
*
* Summary:
*  This function returns the noise value of a
*  component.
*
* Parameters:
*  sensor - Sensor number.
*
* Return:
*  The noise envelope value of the sensor
*  indicated by argument.
*
* Global Variables:
*  baNoiseEnvelope[] - array with Noise Envelope.
*
* Side Effects:
*  None
*
*******************************************************************************/
uint16 ProgramControl_GetNoiseEnvelope(uint32 sensor)
{
    return((uint16)((uint16)noiseEnvelopeTbl[sensor] << 1u) + 1u);
}


/*******************************************************************************
* Function Name: ProgramControl_GetNormalizedDiffCountData
********************************************************************************
*
* Summary:
*  This API returns normalized difference count data.
*
* Parameters:
*  sensor:  Sensor number.
*
* Return:
*  This API returns a normalized count value of the sensor indicated by the 
*  argument. 
*
* Global Variables:
*  ProgramControl_sensorSignal[] - array with difference counts for sensors
* 
* Side Effects:
*  None
*
*******************************************************************************/
uint16 ProgramControl_GetNormalizedDiffCountData(uint32 sensor)
{
	return (uint16)(((uint32)ProgramControl_sensorSignal[sensor] << 7u) / kValueTbl[sensor]);
}

#endif /* (ProgramControl_TUNING_METHOD == ProgramControl__TUNING_AUTO) */

/* [] END OF FILE */
