/*******************************************************************************
* File Name: ProgramControl_SMS.h
* Version 2.10
*
* Description:
*  This file provides the declarations of the wrapper between the CapSense CSD component 
*  and Auto Tuning library.
*
* Note:
*
********************************************************************************
* Copyright 2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/
#if !defined(CY_CAPSENSE_CSD_SMS_ProgramControl_H)
#define CY_CAPSENSE_CSD_SMS_ProgramControl_H

#include "ProgramControl.h"
#include "ProgramControl_PVT.h"

#if(0u != ProgramControl_CSHL_API_GENERATE)
	#include "ProgramControl_CSHL.h"
#endif /* (0u != ProgramControl_CSHL_API_GENERATE) */

#define ProgramControl_PRESCALERS_TBL_SIZE		(16u)

#define ProgramControl_CALIBRATION_FREQ_KHZ		(3000u)
#define ProgramControl_CALIBRATION_MD  		    (2u)

#define ProgramControl_MAX_RESOLUTION         (65535u)
#define ProgramControl_CALIBRATION_RESOLUTION	(0x0FFF0000u)

#define ProgramControl_PRS_CORRECTION_DIVIDER (4u)
#define ProgramControl_SENSITIVITY_DIVIDER    (10u)

#define ProgramControl_SENSITIVITY_MASK        	(0x0Fu)
#define ProgramControl_FLEXIBLE_THRESHOLDS_EN  	(0u)
#define ProgramControl_CAL_RAW_COUNT           	(3482u)

#define ProgramControl_THRESHOLD_1                (220u)
#define ProgramControl_THRESHOLD_2                (237u)
#define ProgramControl_THRESHOLD_3                (245u)
#define ProgramControl_THRESHOLD_4                (250u)


#if (0u != ProgramControl_IS_M0S8PERI_BLOCK)
	#define ProgramControl_CALIBRATION_ASD		(CYDEV_BCLK__HFCLK__KHZ /\
													 ProgramControl_CALIBRATION_FREQ_KHZ)
#else
	#define ProgramControl_MIN_IMO_FREQ_KHZ		(6000u)
	#if(CYDEV_BCLK__HFCLK__KHZ < ProgramControl_MIN_IMO_FREQ_KHZ)
		#define ProgramControl_CALIBRATION_ASD			(1u)
	#else
		#define ProgramControl_CALIBRATION_ASD	(CYDEV_BCLK__HFCLK__KHZ / ProgramControl_CALIBRATION_MD /\
												 	 ProgramControl_CALIBRATION_FREQ_KHZ)
	#endif /* (CYDEV_BCLK__HFCLK__KHZ < ProgramControl_MIN_IMO_FREQ_KHZ) */
#endif /* (0u != ProgramControl_IS_M0S8PERI_BLOCK) */

#if (0u != ProgramControl_IS_M0S8PERI_BLOCK)
    /*  Dividers are not chained */ 
	#if(ProgramControl_PRS_OPTIONS != ProgramControl__PRS_NONE)
		#define ProgramControl_SENSETIVITY_FACTOR (1228u)
	#else
		#define ProgramControl_SENSETIVITY_FACTOR (2456u)
	#endif /* (ProgramControl_PRS_OPTIONS == ProgramControl__PRS_NONE) */
#else
    /*  Dividers are chained */
	#if(ProgramControl_PRS_OPTIONS != ProgramControl__PRS_NONE)
		#define ProgramControl_SENSETIVITY_FACTOR (1228u/ProgramControl_CALIBRATION_MD)
	#else
		#define ProgramControl_SENSETIVITY_FACTOR (2456u/ProgramControl_CALIBRATION_MD)
	#endif /* (ProgramControl_PRS_OPTIONS == ProgramControl__PRS_NONE) */
#endif /* (0u != ProgramControl_IS_M0S8PERI_BLOCK) */


/***************************************
*        Function Prototypes
***************************************/
void ProgramControl_AutoTune(void);
void ProgramControl_UpdateThresholds(uint32 sensor);
void ProgramControl_SetSensitivity(uint32 sensor, uint32 value);
void ProgramControl_SetAnalogSwitchesSrcDirect(void);
uint16 ProgramControl_GetNoiseEnvelope(uint32 sensor);
uint8 ProgramControl_GetSensitivityCoefficient(uint32 sensor);
uint16 ProgramControl_GetNormalizedDiffCountData(uint32 sensor);


/***************************************
*     Vars with External Linkage
***************************************/

/*  Real Charge Divider values */
#if (0u != ProgramControl_IS_M0S8PERI_BLOCK)
    /*  Dividers are not chained */
	#if (CYDEV_BCLK__HFCLK__MHZ >= 12u)
		extern const uint8 prescalerTable[ProgramControl_PRESCALERS_TBL_SIZE];
	#elif (CYDEV_BCLK__HFCLK__MHZ >= 6u)
		extern const uint8 prescalerTable[ProgramControl_PRESCALERS_TBL_SIZE];
	#else
		extern const uint8 prescalerTable[ProgramControl_PRESCALERS_TBL_SIZE];
	#endif /* (CYDEV_BCLK__HFCLK__MHZ > 12u) */
#else
    /*  Dividers are chained */ 
	#if (CYDEV_BCLK__HFCLK__MHZ > 24u)
		extern const uint8 prescalerTable[ProgramControl_PRESCALERS_TBL_SIZE];
	#elif (CYDEV_BCLK__HFCLK__MHZ >12u)
		extern const uint8 prescalerTable[ProgramControl_PRESCALERS_TBL_SIZE];
	#else   /* (CYDEV_BCLK__HFCLK__MHZ > 12u) */
		extern const uint8 prescalerTable[ProgramControl_PRESCALERS_TBL_SIZE];
	#endif /* (CYDEV_BCLK__HFCLK__MHZ > 24u) */
#endif /* (0u != ProgramControl_IS_M0S8PERI_BLOCK) */


extern uint8 noiseEnvelopeTbl[ProgramControl_TOTAL_SENSOR_COUNT];
extern uint8 runningDifferenceTbl[ProgramControl_TOTAL_SENSOR_COUNT];
extern uint8 signRegisterTbl[ProgramControl_TOTAL_SENSOR_COUNT];
extern uint16 sampleMinTbl[ProgramControl_TOTAL_SENSOR_COUNT];
extern uint16 sampleMaxTbl[ProgramControl_TOTAL_SENSOR_COUNT];
extern uint16 previousSampleTbl[ProgramControl_TOTAL_SENSOR_COUNT];
extern uint8 kValueTbl[ProgramControl_TOTAL_SENSOR_COUNT];


#endif  /* (CY_CAPSENSE_CSD_SMS_ProgramControl_H) */

/* [] END OF FILE */
