/*******************************************************************************
* File Name: ProgramControl_SenseClk.h
* Version 2.20
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_CLOCK_ProgramControl_SenseClk_H)
#define CY_CLOCK_ProgramControl_SenseClk_H

#include <cytypes.h>
#include <cyfitter.h>


/***************************************
*        Function Prototypes
***************************************/
#if defined CYREG_PERI_DIV_CMD

void ProgramControl_SenseClk_StartEx(uint32 alignClkDiv);
#define ProgramControl_SenseClk_Start() \
    ProgramControl_SenseClk_StartEx(ProgramControl_SenseClk__PA_DIV_ID)

#else

void ProgramControl_SenseClk_Start(void);

#endif/* CYREG_PERI_DIV_CMD */

void ProgramControl_SenseClk_Stop(void);

void ProgramControl_SenseClk_SetFractionalDividerRegister(uint16 clkDivider, uint8 clkFractional);

uint16 ProgramControl_SenseClk_GetDividerRegister(void);
uint8  ProgramControl_SenseClk_GetFractionalDividerRegister(void);

#define ProgramControl_SenseClk_Enable()                         ProgramControl_SenseClk_Start()
#define ProgramControl_SenseClk_Disable()                        ProgramControl_SenseClk_Stop()
#define ProgramControl_SenseClk_SetDividerRegister(clkDivider, reset)  \
    ProgramControl_SenseClk_SetFractionalDividerRegister((clkDivider), 0u)
#define ProgramControl_SenseClk_SetDivider(clkDivider)           ProgramControl_SenseClk_SetDividerRegister((clkDivider), 1u)
#define ProgramControl_SenseClk_SetDividerValue(clkDivider)      ProgramControl_SenseClk_SetDividerRegister((clkDivider) - 1u, 1u)


/***************************************
*             Registers
***************************************/
#if defined CYREG_PERI_DIV_CMD

#define ProgramControl_SenseClk_DIV_ID     ProgramControl_SenseClk__DIV_ID

#define ProgramControl_SenseClk_CMD_REG    (*(reg32 *)CYREG_PERI_DIV_CMD)
#define ProgramControl_SenseClk_CTRL_REG   (*(reg32 *)ProgramControl_SenseClk__CTRL_REGISTER)
#define ProgramControl_SenseClk_DIV_REG    (*(reg32 *)ProgramControl_SenseClk__DIV_REGISTER)

#define ProgramControl_SenseClk_CMD_DIV_SHIFT          (0u)
#define ProgramControl_SenseClk_CMD_PA_DIV_SHIFT       (8u)
#define ProgramControl_SenseClk_CMD_DISABLE_SHIFT      (30u)
#define ProgramControl_SenseClk_CMD_ENABLE_SHIFT       (31u)

#define ProgramControl_SenseClk_CMD_DISABLE_MASK       ((uint32)((uint32)1u << ProgramControl_SenseClk_CMD_DISABLE_SHIFT))
#define ProgramControl_SenseClk_CMD_ENABLE_MASK        ((uint32)((uint32)1u << ProgramControl_SenseClk_CMD_ENABLE_SHIFT))

#define ProgramControl_SenseClk_DIV_FRAC_MASK  (0x000000F8u)
#define ProgramControl_SenseClk_DIV_FRAC_SHIFT (3u)
#define ProgramControl_SenseClk_DIV_INT_MASK   (0xFFFFFF00u)
#define ProgramControl_SenseClk_DIV_INT_SHIFT  (8u)

#else 

#define ProgramControl_SenseClk_DIV_REG        (*(reg32 *)ProgramControl_SenseClk__REGISTER)
#define ProgramControl_SenseClk_ENABLE_REG     ProgramControl_SenseClk_DIV_REG
#define ProgramControl_SenseClk_DIV_FRAC_MASK  ProgramControl_SenseClk__FRAC_MASK
#define ProgramControl_SenseClk_DIV_FRAC_SHIFT (16u)
#define ProgramControl_SenseClk_DIV_INT_MASK   ProgramControl_SenseClk__DIVIDER_MASK
#define ProgramControl_SenseClk_DIV_INT_SHIFT  (0u)

#endif/* CYREG_PERI_DIV_CMD */

#endif /* !defined(CY_CLOCK_ProgramControl_SenseClk_H) */

/* [] END OF FILE */
