/*******************************************************************************
* File Name: ProgramControl.c
* Version 2.10
*
* Description:
*  This file provides the source code for scanning APIs for the CapSense CSD 
*  component.
*
* Note:
*
********************************************************************************
* Copyright 2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "ProgramControl.h"
#include "ProgramControl_PVT.h"
#include "cypins.h"

#if(0u != ProgramControl_CSHL_API_GENERATE)
	#include "ProgramControl_CSHL.h"
#endif /* (0u != ProgramControl_CSHL_API_GENERATE) */

/* This definition is intended to prevent unexpected linker error. 
   For more details please see the IAR Technical Note 49981 */
#if defined(__ICCARM__)
	extern __INLINE void ProgramControl_EnableSensor(uint32 sensor);
	extern __INLINE void ProgramControl_DisableSensor(uint32 sensor);
#endif /* (__ICCARM__) */	

/* SmartSense functions */
#if (ProgramControl_TUNING_METHOD == ProgramControl__TUNING_AUTO)
    uint8 ProgramControl_lowLevelTuningDone = 0u;
	uint8 scanSpeedTbl[((ProgramControl_TOTAL_SENSOR_COUNT - 1u) / 8u) + 1u];
#endif /* (ProgramControl_TUNING_METHOD == ProgramControl__TUNING_AUTO) */

#if(ProgramControl_PRS_OPTIONS != ProgramControl__PRS_NONE)
	uint8 ProgramControl_prescalersTuningDone = 0u;
#endif /* (ProgramControl_PRS_OPTIONS == ProgramControl__PRS_NONE) */
            
/* Global software variables */
volatile uint8 ProgramControl_csdStatusVar = 0u;   /* CapSense CSD status, variable */
volatile uint8 ProgramControl_sensorIndex = 0u;    /* Index of scannig sensor */

/* Global array of Raw Counts */
uint16 ProgramControl_sensorRaw[ProgramControl_TOTAL_SENSOR_COUNT] = {0u};

/* Backup variables for trim registers*/
#if (ProgramControl_IDAC1_POLARITY == ProgramControl__IDAC_SINK)
	uint8 ProgramControl_csdTrim2;   
#else
    uint8 ProgramControl_csdTrim1;	
#endif /* (ProgramControl_IDAC1_POLARITY == ProgramControl__IDAC_SINK) */

/* Global array of un-scanned sensors state */
uint8 ProgramControl_unscannedSnsDriveMode[ProgramControl_TOTAL_SENSOR_COUNT];

/* Backup array for ProgramControl_sensorEnableMask */
uint8 ProgramControl_sensorEnableMaskBackup[(((ProgramControl_TOTAL_SENSOR_COUNT - 1u) / 8u) + 1u)];

/* Configured constants and arrays by Customizer */
uint8 ProgramControl_sensorEnableMask[(((ProgramControl_TOTAL_SENSOR_COUNT - 1u) / 8u) + 1u)] = {
0x1Fu, };

reg32 * ProgramControl_pcTable[] = {
    (reg32 *)ProgramControl_Sns__Backward__BTN__PC, 
    (reg32 *)ProgramControl_Sns__Forward__BTN__PC, 
    (reg32 *)ProgramControl_Sns__Minus__BTN__PC, 
    (reg32 *)ProgramControl_Sns__Plus__BTN__PC, 
    (reg32 *)ProgramControl_Sns__GuardSensor__GRD__PC, 
};

const uint8 ProgramControl_portTable[] = {
    ProgramControl_Sns__Backward__BTN__PORT, 
    ProgramControl_Sns__Forward__BTN__PORT, 
    ProgramControl_Sns__Minus__BTN__PORT, 
    ProgramControl_Sns__Plus__BTN__PORT, 
    ProgramControl_Sns__GuardSensor__GRD__PORT, 
};

const uint32 ProgramControl_maskTable[] = {
    ProgramControl_Sns__Backward__BTN__MASK, 
    ProgramControl_Sns__Forward__BTN__MASK, 
    ProgramControl_Sns__Minus__BTN__MASK, 
    ProgramControl_Sns__Plus__BTN__MASK, 
    ProgramControl_Sns__GuardSensor__GRD__MASK, 
};

const uint8 ProgramControl_pinShiftTbl[] = {
    (uint8) ProgramControl_Sns__Backward__BTN__SHIFT, 
    (uint8) ProgramControl_Sns__Forward__BTN__SHIFT, 
    (uint8) ProgramControl_Sns__Minus__BTN__SHIFT, 
    (uint8) ProgramControl_Sns__Plus__BTN__SHIFT, 
    (uint8) ProgramControl_Sns__GuardSensor__GRD__SHIFT, 
};

uint8 ProgramControl_modulationIDAC[ProgramControl_TOTAL_SENSOR_COUNT];
uint8 ProgramControl_compensationIDAC[ProgramControl_TOTAL_SENSOR_COUNT];

uint32 ProgramControl_widgetResolution[ProgramControl_RESOLUTIONS_TBL_SIZE] = {
    ProgramControl_RESOLUTION_12_BITS,
    ProgramControl_RESOLUTION_12_BITS,
    ProgramControl_RESOLUTION_12_BITS,
    ProgramControl_RESOLUTION_12_BITS,
    ProgramControl_RESOLUTION_12_BITS,
};

uint8 ProgramControl_senseClkDividerVal[ProgramControl_TOTAL_SCANSLOT_COUNT];
uint8 ProgramControl_sampleClkDividerVal[ProgramControl_TOTAL_SCANSLOT_COUNT];

const uint8 ProgramControl_widgetNumber[ProgramControl_TOTAL_SENSOR_COUNT] = {
    0u, /* Backward__BTN */
    1u, /* Forward__BTN */
    2u, /* Minus__BTN */
    3u, /* Plus__BTN */
    4u, /* GuardSensor__GRD */
};



reg32* const ProgramControl_prtSelTbl[] = {
	((reg32 *) CYREG_HSIOM_PORT_SEL0),
	((reg32 *) CYREG_HSIOM_PORT_SEL1),
	((reg32 *) CYREG_HSIOM_PORT_SEL2),
	((reg32 *) CYREG_HSIOM_PORT_SEL3),
#if (CY_PSOC4_4200BL)
	((reg32 *) CYREG_HSIOM_PORT_SEL4),
	((reg32 *) CYREG_HSIOM_PORT_SEL5)
#elif(0u == ProgramControl_M0S8CSD_BLOCK_VER)
	((reg32 *) CYREG_HSIOM_PORT_SEL4)
#endif /* (0u == ProgramControl_M0S8CSD_BLOCK_VER) */
};

reg32* const ProgramControl_prtCfgTbl[] = {
	((reg32 *) CYREG_PRT0_PC),
	((reg32 *) CYREG_PRT1_PC),
	((reg32 *) CYREG_PRT2_PC),
	((reg32 *) CYREG_PRT3_PC),
#if (CY_PSOC4_4200BL)
	((reg32 *) CYREG_PRT4_PC),
	((reg32 *) CYREG_PRT5_PC)
#elif(0u == ProgramControl_M0S8CSD_BLOCK_VER)
	((reg32 *) CYREG_PRT4_PC)	
#endif /* (0u == ProgramControl_M0S8CSD_BLOCK_VER) */	
};

reg32* const ProgramControl_prtDRTbl[] = {
	((reg32 *) CYREG_PRT0_DR),
	((reg32 *) CYREG_PRT1_DR),
	((reg32 *) CYREG_PRT2_DR),
	((reg32 *) CYREG_PRT3_DR),
#if (CY_PSOC4_4200BL)
	((reg32 *) CYREG_PRT4_DR),
	((reg32 *) CYREG_PRT5_DR),
#elif(0u == ProgramControl_M0S8CSD_BLOCK_VER)
	((reg32 *) CYREG_PRT4_DR),
#endif /* (0u == ProgramControl_M0S8CSD_BLOCK_VER) */	
};
    

/*******************************************************************************
* Function Name: ProgramControl_Init
********************************************************************************
*
* Summary:
*  API initializes default CapSense configuration provided by the customizer that defines 
*  the mode of component operations and resets all the sensors to an inactive state.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global Variables:
*  ProgramControl_immunityIndex - defines immunity level.
*
* Side Effects:
*  None
* 
*******************************************************************************/
void ProgramControl_Init(void)
{   
	uint32 curSensor;
	
	#if(ProgramControl_IS_SHIELD_ENABLE)
		
		#if((ProgramControl_CSH_TANK_PREGARGE_OPTION == ProgramControl__CAPPRIOBUF) || (0u != ProgramControl_CSH_TANK_ENABLE))
			uint32 newRegValue;
			
			newRegValue = ProgramControl_CTANK_CONNECTION_REG;
	        newRegValue &= ~(ProgramControl_CSD_CTANK_CONNECTION_MASK);
			newRegValue |= ProgramControl_CSD_CTANK_TO_AMUXBUS_B;
	        ProgramControl_CTANK_CONNECTION_REG = newRegValue;
			
			#if(ProgramControl_CSH_TANK_PREGARGE_OPTION == ProgramControl__CAPPRIOBUF)
				newRegValue = ProgramControl_CTANK_PORT_PC_REG;
		        newRegValue &= ~(ProgramControl_CSD_CTANK_PC_MASK);
				newRegValue |= ProgramControl_CTANK_PC_STRONG_MODE;
		        ProgramControl_CTANK_PORT_PC_REG = newRegValue;
				
				newRegValue = ProgramControl_CTANK_PORT_DR_REG;
		        newRegValue &= ~(ProgramControl_CTANK_DR_MASK);
				newRegValue |= ProgramControl_CTANK_DR_CONFIG;
		        ProgramControl_CTANK_PORT_DR_REG = newRegValue;
			#endif /* (ProgramControl_CSH_TANK_PREGARGE_OPTION == ProgramControl__CAPPRIOBUF) */
	        
		#endif /* ((ProgramControl_CSH_TANK_PREGARGE_OPTION == ProgramControl__CAPPRIOBUF) || (ProgramControl_CSH_TANK_ENABLE)) */
		
		ProgramControl_EnableShieldElectrode((uint32)ProgramControl_SHIELD_PIN_NUMBER, (uint32)ProgramControl_SHIELD_PORT_NUMBER);
		
	#endif /* (ProgramControl_IS_SHIELD_ENABLE) */
	
	for(curSensor = 0u; curSensor < ProgramControl_TOTAL_SENSOR_COUNT; curSensor++)
	{
		ProgramControl_unscannedSnsDriveMode[curSensor] = ProgramControl_CONNECT_INACTIVE_SNS;
	}
    
	ProgramControl_CsdHwBlockInit();
    ProgramControl_SetShieldDelay(ProgramControl_SHIELD_DELAY );
	
	/* Clear all sensors */
    ProgramControl_ClearSensors();
}

/*******************************************************************************
* Function Name: ProgramControl_CsdHwBlockInit
********************************************************************************
*
* Summary:
*  Initialises the hardware parameters of the CSD block 
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global Variables:
*  ProgramControl_csdTrim1 - Contains IDAC trim register value for Sourcing Mode.
*  ProgramControl_csdTrim2 - Contains IDAC trim register value for Sinking Mode.
*
* Side Effects:
*  None
* 
*******************************************************************************/
void ProgramControl_CsdHwBlockInit(void)
{
	uint32 newRegValue;
	
	    /* Set trim registers for CSD Mode */
    #if (ProgramControl_IDAC1_POLARITY == ProgramControl__IDAC_SINK)
		/* iDAC1 Sinking Mode */ 
		ProgramControl_csdTrim2 = (uint8)ProgramControl_CSD_TRIM2_REG;
		newRegValue = ProgramControl_csdTrim2;
		newRegValue &= ProgramControl_CSD_IDAC1_TRIM_MASK;
		newRegValue |= (uint32)((uint32)ProgramControl_SFLASH_CSD_TRIM2_REG & (uint32)ProgramControl_CSFLASH_TRIM_IDAC1_MASK); 
		
		#if (ProgramControl_IDAC_CNT == 2u)
		    /* iDAC2 Sinking Mode */ 
			newRegValue &= ProgramControl_CSD_IDAC2_TRIM_MASK;
			newRegValue |= (uint32)((uint32)ProgramControl_SFLASH_CSD_TRIM2_REG & (uint32)ProgramControl_CSFLASH_TRIM_IDAC2_MASK); 
		#endif /* (ProgramControl_IDAC_CNT == 2u) */
		ProgramControl_CSD_TRIM2_REG = newRegValue;
    #else   
		/* iDAC1 Sourcing Mode */ 
		ProgramControl_csdTrim1 = (uint8)ProgramControl_CSD_TRIM1_REG;
		newRegValue = ProgramControl_csdTrim1;
		newRegValue &= ProgramControl_CSD_IDAC1_TRIM_MASK;
		newRegValue |= (uint32)((uint32)ProgramControl_SFLASH_CSD_TRIM1_REG & (uint32)ProgramControl_CSFLASH_TRIM_IDAC1_MASK);
		#if (ProgramControl_IDAC_CNT == 2u)
		     /* iDAC2 Sourcing Mode */ 
			newRegValue &= ProgramControl_CSD_IDAC2_TRIM_MASK;
			newRegValue |= (uint32)((uint32)ProgramControl_SFLASH_CSD_TRIM1_REG & (uint32)ProgramControl_CSFLASH_TRIM_IDAC2_MASK);
		#endif		
		ProgramControl_CSD_TRIM1_REG = newRegValue;
    #endif /* (ProgramControl_IDAC1_POLARITY == ProgramControl__IDAC_SINK) */
	
	/* Configure CSD and IDAC */
	#if (ProgramControl_IDAC_CNT > 1u)
		ProgramControl_CSD_IDAC_REG = ProgramControl_DEFAULT_CSD_IDAC_CONFIG;
		ProgramControl_CSD_CFG_REG = ProgramControl_DEFAULT_CSD_CONFIG;
	#else
		ProgramControl_CSD_IDAC_REG &= ~(ProgramControl_CSD_IDAC1_MODE_MASK  | ProgramControl_CSD_IDAC1_DATA_MASK);
		ProgramControl_CSD_IDAC_REG |= ProgramControl_DEFAULT_CSD_IDAC_CONFIG;
		
		ProgramControl_CSD_CFG_REG &= ~(ProgramControl_CSD_CONFIG_MASK);
		ProgramControl_CSD_CFG_REG |= (ProgramControl_DEFAULT_CSD_CONFIG);
	#endif /* (ProgramControl_IDAC_CNT > 1u) */
	
	
	/* Connect Cmod to AMUX bus */ 
	newRegValue = ProgramControl_CMOD_CONNECTION_REG; 
    newRegValue &= ~(ProgramControl_CSD_CMOD_CONNECTION_MASK);
    newRegValue |= ProgramControl_CSD_CMOD_TO_AMUXBUS_A;
    ProgramControl_CMOD_CONNECTION_REG = newRegValue;
	
	/* Configure Dead Band PWM if it is enabled */
	#if(ProgramControl_CSD_4B_PWM_MODE != ProgramControl__PWM_OFF)
		ProgramControl_CSD_4B_PWM_REG = ProgramControl_DEFAULT_CSD_4B_PWM_CONFIG;
	#endif /* (ProgramControl_CSD_4B_PWM_MODE != ProgramControl__PWM_OFF) */

	/* Setup ISR */
	CyIntDisable(ProgramControl_ISR_NUMBER);
	#if !defined(CY_EXTERNAL_INTERRUPT_CONFIG)		
	    (void)CyIntSetVector(ProgramControl_ISR_NUMBER, &ProgramControl_ISR);
	    CyIntSetPriority(ProgramControl_ISR_NUMBER, ProgramControl_ISR_PRIORITY);
	#endif /* (CY_EXTERNAL_INTERRUPT_CONFIG) */
}


/*******************************************************************************
* Function Name: ProgramControl_Enable
********************************************************************************
*
* Summary:
*  Enables the CSD block and related resources to an active mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global Variables:
*  None.
*
* Side Effects:
*  None
* 
*******************************************************************************/
void ProgramControl_Enable(void)
{
    uint32 newRegValue;
    
    /* Enable Clocks */
	ProgramControl_SenseClk_Stop();
	ProgramControl_SampleClk_Stop();
	
	ProgramControl_SampleClk_SetDividerValue((uint16)ProgramControl_INITIAL_CLK_DIVIDER);
	ProgramControl_SenseClk_SetDividerValue((uint16)ProgramControl_INITIAL_CLK_DIVIDER);
	
	#if (0u == ProgramControl_IS_M0S8PERI_BLOCK)
		ProgramControl_SenseClk_Start();
		ProgramControl_SampleClk_Start();
	#else
		ProgramControl_SampleClk_Start();
		ProgramControl_SenseClk_StartEx(ProgramControl_SampleClk__DIV_ID);
	#endif /* (0u == ProgramControl_IS_M0S8PERI_BLOCK) */
	
	/* Enable the CSD block */
    newRegValue = ProgramControl_CSD_CFG_REG;
    newRegValue |= (ProgramControl_CSD_CFG_ENABLE | ProgramControl_CSD_CFG_SENSE_COMP_EN 
                                                   | ProgramControl_CSD_CFG_SENSE_EN);    
    ProgramControl_CSD_CFG_REG = newRegValue;

    /* Enable interrupt */
    CyIntEnable(ProgramControl_ISR_NUMBER);
}


/*******************************************************************************
* Function Name: ProgramControl_Start
********************************************************************************
*
* Summary:
*  This is the preferred method to begin the component operation. CapSense_Start() 
*  calls the CapSense_Init() function, and then calls the CapSense_Enable() 
*  function. Initializes the registers and starts the CSD method of the CapSense 
*  component. Resets all the sensors to an inactive state. Enables interrupts for 
*  sensors scanning. When the SmartSense tuning mode is selected, the tuning procedure
*  is applied for all the sensors. The CapSense_Start() routine must be called before 
*  any other API routines.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global Variables:
*   ProgramControl_initVar - used to check the initial configuration, 
*   modified on the first function call.
*  ProgramControl_lowLevelTuningDone - Used to notify the Tuner GUI that 
*   tuning of the scanning parameters is done. 
*
* Side Effects:
*  None
* 
*******************************************************************************/
void ProgramControl_Start(void)
{

	static uint8 ProgramControl_initVar = 0u;

	#if((0u != ProgramControl_AUTOCALIBRATION_ENABLE) && (ProgramControl_TUNING_METHOD != ProgramControl__TUNING_AUTO))
		uint32 curSensor;
		uint32 rawLevel;
		uint32 widget;
    #endif /* ((0u != ProgramControl_AUTOCALIBRATION_ENABLE) && (ProgramControl_TUNING_METHOD != ProgramControl__TUNING_AUTO)) */
	
    if (ProgramControl_initVar == 0u)
    {
        ProgramControl_Init();
        ProgramControl_initVar = 1u;
    }
    ProgramControl_Enable();
	
    /* AutoTunning start */
    #if(ProgramControl_TUNING_METHOD == ProgramControl__TUNING_AUTO)
		#if(0u != ProgramControl_CSHL_API_GENERATE)
	        ProgramControl_AutoTune();
	        ProgramControl_lowLevelTuningDone = 1u;
		#endif /* (0u != ProgramControl_CSHL_API_GENERATE) */
	#else
		#if(0u != ProgramControl_AUTOCALIBRATION_ENABLE)
			
			#if(ProgramControl_IDAC_CNT > 1u)
				ProgramControl_CSD_IDAC_REG &= ~(ProgramControl_CSD_IDAC2_MODE_MASK);	
			#endif /* (ProgramControl_IDAC_CNT > 1u) */
			
			for(curSensor = 0u; curSensor < ProgramControl_TOTAL_SCANSLOT_COUNT; curSensor++)
			{
				widget = ProgramControl_widgetNumber[curSensor];
				rawLevel = ProgramControl_widgetResolution[widget] >> ProgramControl_RESOLUTION_OFFSET;
				
				/* Calibration level should be equal to 85% from scanning resolution */
				rawLevel = (rawLevel * 85u) / 100u;
				
				ProgramControl_CalibrateSensor(curSensor, rawLevel, ProgramControl_modulationIDAC);
			}

			#if(0u != ProgramControl_TOTAL_CENTROIDS_COUNT) 
				ProgramControl_NormalizeWidgets(ProgramControl_END_OF_WIDGETS_INDEX, ProgramControl_modulationIDAC);
			#endif /* (0u != ProgramControl_TOTAL_CENTROIDS_COUNT)  */

			#if(ProgramControl_IDAC_CNT > 1u)
				for(curSensor = 0u; curSensor < ProgramControl_TOTAL_SCANSLOT_COUNT; curSensor++)
			    {
					ProgramControl_compensationIDAC[curSensor] = ProgramControl_modulationIDAC[curSensor] / 2u;
					ProgramControl_modulationIDAC[curSensor] = (ProgramControl_modulationIDAC[curSensor] + 1u) / 2u;
			    }
				ProgramControl_CSD_IDAC_REG |= ProgramControl_CSD_IDAC2_MODE_FIXED;
			#endif /* (ProgramControl_IDAC_CNT > 1u) */
			
        #endif /* (0u != ProgramControl_AUTOCALIBRATION_ENABLE) */ 
					
    #endif /* ((ProgramControl_TUNING_METHOD == ProgramControl__TUNING_AUTO) */	
	
	/* Initialize Advanced Centroid */
	#if(ProgramControl_TOTAL_TRACKPAD_GESTURES_COUNT > 0u)
		ProgramControl_AdvancedCentroidInit();
	#endif /* (ProgramControl_TOTAL_TRACKPAD_GESTURES_COUNT > 0u) */
	
	/* Connect sense comparator input to AMUXA */
	ProgramControl_CSD_CFG_REG |= ProgramControl_CSD_CFG_SENSE_INSEL;
}


/*******************************************************************************
* Function Name: ProgramControl_Stop
********************************************************************************
*
* Summary:
*  Stops the sensor scanning, disables component interrupts, and resets all the 
*  sensors to an inactive state. Disables the Active mode power template bits for
*  the subcomponents used within CapSense.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global Variables:
*  ProgramControl_csdTrim1 - Contains the IDAC trim register value for the Sourcing Mode.
*  ProgramControl_csdTrim2 - Contains the IDAC trim register value for vSinking Mode.
*
* Side Effects:
*  This function should be called after scans are completed.
*
*******************************************************************************/
void ProgramControl_Stop(void)
{
    /* Disable interrupt */
    CyIntDisable(ProgramControl_ISR_NUMBER);
	
	ProgramControl_CSD_CFG_REG &= ~(ProgramControl_CSD_CFG_SENSE_COMP_EN | ProgramControl_CSD_CFG_SENSE_EN);
	
	#if(ProgramControl_IDAC_CNT == 2u)
		ProgramControl_CSD_CFG_REG &= ~(ProgramControl_CSD_CFG_ENABLE);
	#endif /* (ProgramControl_IDAC_CNT == 2u) */

    /* Disable the Clocks */
    ProgramControl_SenseClk_Stop();
    ProgramControl_SampleClk_Stop();
}


/*******************************************************************************
* Function Name: ProgramControl_FindNextSensor
********************************************************************************
*
* Summary:
*  Finds the next sensor to scan. 
*
* Parameters:
*  snsIndex:  Current index of sensor.
*
* Return:
*  Returns the next sensor index to scan.
*
* Global Variables:
*  ProgramControl_sensorEnableMask[] - used to store bit masks of the enabled sensors.
*
* Side Effects:
*  This function affects the  current scanning and should not
*  be used outside the component.
*
*******************************************************************************/
uint8 ProgramControl_FindNextSensor(uint8 snsIndex)
{
    uint32 enableFlag;
    
    /* Check if sensor enabled */
    do
    {
        /* Proceed with next sensor */
        snsIndex++;
        if(snsIndex == ProgramControl_TOTAL_SENSOR_COUNT)
        {
            break;
        }
        enableFlag = ProgramControl_GetBitValue(ProgramControl_sensorEnableMask, (uint32)snsIndex);
    }    
    while(enableFlag == 0u);
    
    return ((uint8)snsIndex);
}


/*******************************************************************************
* Function Name: ProgramControl_ScanSensor
********************************************************************************
*
* Summary:
*  Sets the scan settings and starts scanning a sensor. After scanning is complete,
*  the ISR copies the measured sensor raw data to the global raw sensor array. 
*  Use of the ISR ensures this function is non-blocking. 
*  Each sensor has a unique number within the sensor array. 
*  This number is assigned by the CapSense customizer in sequence.
*
* Parameters:
*  sensor:  Sensor number.
*
* Return:
*  None
*
* Global Variables:
*  ProgramControl_csdStatusVar - used to provide the status and mode of the scanning process. 
*  Sets the busy status(scan in progress) and mode of scan as single scan.
*  ProgramControl_sensorIndex - used to store a sensor scanning sensor number.
*  Sets to the provided sensor argument.
*
* Side Effects:
*  None
* 
*******************************************************************************/
void ProgramControl_ScanSensor(uint32 sensor)
{
    /* Clears status/control variable and set sensorIndex */
    ProgramControl_csdStatusVar = 0u;
    ProgramControl_sensorIndex = (uint8)sensor;
    
    /* Start of sensor scan */
    ProgramControl_csdStatusVar = (ProgramControl_SW_STS_BUSY | ProgramControl_SW_CTRL_SINGLE_SCAN);
    ProgramControl_PreScan(sensor);
}


#if(0u != ProgramControl_CSHL_API_GENERATE)
/*******************************************************************************
* Function Name: ProgramControl_ScanWidget
********************************************************************************
*
* Summary:
*  Sets the scan settings and starts scanning a widget.
*
* Parameters:
*  uint32 widget: Widget number.
*
* Return:
*  None
*
* Global Variables:
*  ProgramControl_csdStatusVar - used to provide the status and mode of the scanning process. 
*  Sets the busy status(scan in progress) and clears the single scan mode.
*  ProgramControl_sensorIndex - used to store a sensor scanning sensor number.
*  Sets to 0xFF and provided to function ProgramControl_FindNextSensor or
*  ProgramControl_sensorEnableMask[] - used to store bit masks of the enabled sensors.
*  ProgramControl_sensorEnableMaskBackup[] - used to backup bit masks of the enabled
*   sensors.
*
* Side Effects:
*  None
* 
*******************************************************************************/
void ProgramControl_ScanWidget(uint32 widget)
{
    uint32 sensorsPerWidget;
    uint32 lastSensor;
    uint32 snsIndex;

	/* Get first sensor in widget */
	ProgramControl_sensorIndex = ProgramControl_rawDataIndex[widget];
	
	/* Get number of sensors in widget */
	sensorsPerWidget = ProgramControl_numberOfSensors[widget];
	
	/* Check if generic Sensor */
	if(sensorsPerWidget == 0u)
	{
		sensorsPerWidget = 1u;
	}
	
	/* Get last sensor in widget */
	lastSensor = (ProgramControl_rawDataIndex[widget] + sensorsPerWidget) - 1u;

	/* Backup sensorEnableMask array */
	for(snsIndex = 0u; snsIndex < ProgramControl_TOTAL_SENSOR_MASK; snsIndex++)
	{
		/* Backup sensorEnableMask array */
		ProgramControl_sensorEnableMaskBackup[snsIndex] = ProgramControl_sensorEnableMask[snsIndex];
	}

	/* Update sensorEnableMask to scan the sensors that belong to widget */
	for(snsIndex = 0u; snsIndex < ProgramControl_TOTAL_SENSOR_COUNT; snsIndex++)
	{
		/* Update sensorEnableMask array bits to scan the widget only */ 
	    if((snsIndex >= ProgramControl_sensorIndex) && (snsIndex <= lastSensor))
		{
		    /* Set sensor bit to scan */
			ProgramControl_SetBitValue(ProgramControl_sensorEnableMask, snsIndex, 1u);
		}
		else
		{
		    /* Reset sensor bit to do not scan */
		    ProgramControl_SetBitValue(ProgramControl_sensorEnableMask, snsIndex, 0u);
		}
	}

    /* Check end of scan condition */
    if(ProgramControl_sensorIndex < ProgramControl_TOTAL_SENSOR_COUNT)
    {
		/* Set widget busy bit in status/control variable*/ 
		ProgramControl_csdStatusVar = (ProgramControl_SW_STS_BUSY | ProgramControl_SW_CTRL_WIDGET_SCAN);
		/* Scan first sensor of widget*/ 
        ProgramControl_PreScan((uint32)ProgramControl_sensorIndex);
    }
}
#endif /* (0u != ProgramControl_CSHL_API_GENERATE) */


/*******************************************************************************
* Function Name: ProgramControl_ScanEnableWidgets
********************************************************************************
*
* Summary:
*  This is the preferred method to scan all of the enabled widgets. 
*  The API starts scanning a sensor within the enabled widgets. 
*  The ISR continues scanning the sensors until all the enabled widgets are scanned. 
*  Use of the ISR ensures this function is non-blocking.
*  All the widgets are enabled by default except proximity widgets. 
*  The proximity widgets must be manually enabled as their long scan time 
*  is incompatible with a fast response required of other widget types.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global Variables:
*  ProgramControl_csdStatusVar - used to provide the status and mode of the scanning process. 
*  Sets the busy status(scan in progress) and clears the single scan mode.
*  ProgramControl_sensorIndex - used to store a sensor scanning sensor number.
*  Sets to 0xFF and provided to function ProgramControl_FindNextSensor or
*
* Side Effects:
*  None
* 
*******************************************************************************/
void ProgramControl_ScanEnabledWidgets(void)
{
    /* Clears status/control variable and set sensorIndex */
    ProgramControl_csdStatusVar = 0u;
    ProgramControl_sensorIndex = 0xFFu;
    
    /* Find next sensor */
    ProgramControl_sensorIndex = (uint8)ProgramControl_FindNextSensor(ProgramControl_sensorIndex);

    /* Check end of scan condition */
    if(ProgramControl_sensorIndex < ProgramControl_TOTAL_SENSOR_COUNT)
    {
        ProgramControl_csdStatusVar |= ProgramControl_SW_STS_BUSY;
        ProgramControl_PreScan((uint32)ProgramControl_sensorIndex);
    }
}


/*******************************************************************************
* Function Name: ProgramControl_IsBusy
********************************************************************************
*
* Summary:
*  Returns the state of the CapSense component. 1 means that scanning in 
*  progress and 0 means that scanning is complete.
*
* Parameters:
*  None
*
* Return:
*  Returns the state of scanning. 1 - scanning in progress, 0 - scanning 
*  completed.
*
* Global Variables:
*  ProgramControl_csdStatusVar - used to provide the status and mode of the scanning process. 
*  Checks the busy status.
*
* Side Effects:
*  None
* 
*******************************************************************************/
uint32 ProgramControl_IsBusy(void)
{
    return ((uint32)((0u != (ProgramControl_csdStatusVar & ProgramControl_SW_STS_BUSY)) ? 1u : 0u));
}


/*******************************************************************************
* Function Name: ProgramControl_ReadSensorRaw
********************************************************************************
*
* Summary:
*  Returns sensor raw data from the global CapSense_sensorRaw[ ] array. 
*  Each scan sensor has a unique number within the sensor array. 
*  This number is assigned by the CapSense customizer in sequence. 
*  Raw data can be used to perform calculations outside of the CapSense 
*  provided framework.
*
* Parameters:
*  sensor:  Sensor number.
*
* Return:
*  Returns the current raw data value for a defined sensor number.
*
* Global Variables:
*  ProgramControl_sensorRaw[] - used to store sensors raw data.
*
* Side Effects: 
*  None
*
*******************************************************************************/
uint16 ProgramControl_ReadSensorRaw(uint32 sensor)
{
    return ProgramControl_sensorRaw[sensor];
}


/*******************************************************************************
* Function Name: ProgramControl_WriteSensorRaw
********************************************************************************
*
* Summary:
*  This API writes the raw count value passed as an argument to the sensor Raw count array.
*
* Parameters:
*  sensor:  Sensor number.
*  value: Raw count value.
*
* Global Variables:
*  ProgramControl_sensorRaw[] - used to store sensors raw data.
*
* Return:
*  None
*
* Side Effects: 
*  None
*
*******************************************************************************/
void ProgramControl_WriteSensorRaw(uint32 sensor, uint16 value)
{
	ProgramControl_sensorRaw[sensor] = value;
}


#if (ProgramControl_TUNING_METHOD != ProgramControl__TUNING_NONE)
	/*******************************************************************************
	* Function Name: ProgramControl_SetScanResolution
	********************************************************************************
	*
	* Summary:
	*  Sets a value of the sensor scan resolution for a widget. 
	*  The MIN resolution can be set 8-bit. The MAX Resolution can be set 16 bit.
	*  This function is not available for the tuning mode "None".
	*
	* Parameters:
	*  widget:     Widget index.
	*  resolution: Represents the resolution value. The following defines which are available in the
	*			   ProgramControl.h file should be used:
	*			   ProgramControl_RESOLUTION_6_BITS
	*			   ProgramControl_RESOLUTION_7_BITS
	*			   ProgramControl_RESOLUTION_8_BITS
	*			   ProgramControl_RESOLUTION_9_BITS
	*			   ProgramControl_RESOLUTION_10_BITS
	*			   ProgramControl_RESOLUTION_11_BITS
	*			   ProgramControl_RESOLUTION_12_BITS
	*			   ProgramControl_RESOLUTION_13_BITS
	*			   ProgramControl_RESOLUTION_14_BITS
	*			   ProgramControl_RESOLUTION_15_BITS
	*			   ProgramControl_RESOLUTION_16_BITS
	*
	* Return:
	*  None
	*
	* Global Variables:
	*  ProgramControl_widgetResolution[] - used to store scan resolution of each widget.
	*
	* Side Effects: 
	*  None
	*
	*******************************************************************************/
	void ProgramControl_SetScanResolution(uint32 widget, uint32 resolution)
	{ 
        ProgramControl_widgetResolution[widget] = resolution;
	}
#endif /* (ProgramControl_TUNING_METHOD != ProgramControl__TUNING_NONE) */


/*******************************************************************************
* Function Name: ProgramControl_GetScanResolution
********************************************************************************
*
* Summary:
*  Returns the resolution value for the appropriate sensor.
*  This function is not available for tuning mode "None".
*
* Parameters:
*  widget:     Widget index.
*
* Return:
*  resolution: Returns the resolution value for the appropriate sensor. 
*              The resolution values are defined in the ProgramControl.h file 
*              The defines are encountered below:
*			   ProgramControl_RESOLUTION_6_BITS
*			   ProgramControl_RESOLUTION_7_BITS
*			   ProgramControl_RESOLUTION_8_BITS
*			   ProgramControl_RESOLUTION_9_BITS
*			   ProgramControl_RESOLUTION_10_BITS
*			   ProgramControl_RESOLUTION_11_BITS
*			   ProgramControl_RESOLUTION_12_BITS
*			   ProgramControl_RESOLUTION_13_BITS
*			   ProgramControl_RESOLUTION_14_BITS
*			   ProgramControl_RESOLUTION_15_BITS
*			   ProgramControl_RESOLUTION_16_BITS
*
* Global Variables:
*  ProgramControl_widgetResolution[] - used to store scan resolution of every widget.
*
* Side Effects: 
*  None
*
*******************************************************************************/
uint32 ProgramControl_GetScanResolution(uint32 widget)
{
	return(ProgramControl_widgetResolution[widget]);
}


/*******************************************************************************
* Function Name: ProgramControl_ClearSensors
********************************************************************************
*
* Summary:
*  Resets all the sensors to the non-sampling state by sequentially disconnecting
*  all the sensors from Analog MUX Bus and putting them to an inactive state.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global Variables:
*  None
*
* Side Effects: 
*  None
*
*******************************************************************************/
void ProgramControl_ClearSensors(void)
{
	uint32 snsIndex;
	
    for (snsIndex = 0u; snsIndex < ProgramControl_TOTAL_SENSOR_COUNT; snsIndex++)
    {
        ProgramControl_DisableScanSlot(snsIndex);
    }
}


#if (ProgramControl_IS_COMPLEX_SCANSLOTS)
    /*******************************************************************************
    * Function Name: ProgramControl_EnableScanSlot
    ********************************************************************************
    *
    * Summary:
    *  Configures the selected slot to measure during the next measurement 
    *  cycle. The corresponding pin/pins are set to Analog High-Z mode and 
    *  connected to the Analog Mux Bus. This also enables the comparator function.
    *
    * Parameters:
    *  slot:  Slot number.
    *
    * Return:
    *  None
    *
    * Global Constants:
    *  ProgramControl_portTable[]  - used to store the port number that pin 
    *  belongs to for each sensor.
    *  ProgramControl_maskTable[]  - used to store the pin within the port for 
    *  each sensor.
    *  ProgramControl_indexTable[] - used to store indexes of complex sensors.
    *  The offset and position in this array are stored in a port and mask table for 
    *  complex sensors.
    *  Bit 7 (msb) is used to define the sensor type: single or complex.
    *
	* Side Effects: 
	*  None
	*
    *******************************************************************************/
    void ProgramControl_EnableScanSlot(uint32 slot)
    {
        uint8 j;
        uint8 snsNumber;
        const uint8 *index;
        /* Read sensor type: single or complex */
        uint8 snsType = ProgramControl_portTable[slot];

        /* Check if sensor is complex */
        if ((snsType & ProgramControl_COMPLEX_SS_FLAG) == 0u)
        {
            /* Enable sensor (single) */
            ProgramControl_EnableSensor(slot);
        }
        else
        {
            /* Enable complex sensor */
            snsType &= ~ProgramControl_COMPLEX_SS_FLAG;
            index = &ProgramControl_indexTable[snsType];
            snsNumber = ProgramControl_maskTable[slot];
                        
            for (j = 0u; j < snsNumber; j++)
            {
                ProgramControl_EnableSensor(index[j]);
            }
        }
    }
    
    
    /*******************************************************************************
    * Function Name: ProgramControl_DisableScanSlot
    ********************************************************************************
    *
    * Summary:
    *  Disables the selected slot. The corresponding pin/pins is/are disconnected 
    *  from the Analog Mux Bus and connected to GND, High_Z or Shield electrode.
    *
    * Parameters:
    *  slot:  Slot number.
    *
    * Return:
    *  None
    *
    * Global Variables:
    *  ProgramControl_portTable[]  - used to store the port number that pin 
    *  belongs to for each sensor.
    *  ProgramControl_maskTable[]  - used to store the pin within the port for 
    *  each sensor.
    *  ProgramControl_indexTable[] - used to store indexes of complex sensors.
    *  The offset and position in this array are stored in a port and mask table for 
    *  complex sensors.
    *  7bit(msb) is used to define the sensor type: single or complex.
    *
	* Side Effects: 
	*  None
	*
    *******************************************************************************/
    void ProgramControl_DisableScanSlot(uint32 slot)
    {
        uint8 j;
        uint8 snsNumber;
        const uint8 *index;

        /* Read sensor type: single or complex */
        uint8 snsType = ProgramControl_portTable[slot];
        
        /* Check if sensor is complex */
        if ((snsType & ProgramControl_COMPLEX_SS_FLAG) == 0u)
        {
            /* Disable sensor (single) */
            ProgramControl_DisableSensor(slot);
        }
        else
        {
            /* Disable complex sensor */
            snsType &= ~ProgramControl_COMPLEX_SS_FLAG;
            index = &ProgramControl_indexTable[snsType];
            snsNumber = ProgramControl_maskTable[slot];
                        
            for (j=0; j < snsNumber; j++)
            {
                ProgramControl_DisableSensor(index[j]);
            }
        } 
    }
#endif  /* ProgramControl_IS_COMPLEX_SCANSLOTS */


/*******************************************************************************
* Function Name: ProgramControl_EnableSensor
********************************************************************************
*
* Summary:
*  Configures the selected sensor to measure during the next measurement cycle.
*  The corresponding pins are set to Analog High-Z mode and connected to the
*  Analog Mux Bus. This also enables the comparator function.
*
* Parameters:
*  sensor:  Sensor number.
*
* Return:
*  None
*
* Global Variables:
*  ProgramControl_portTable[] - used to store the port number that pin 
*  belongs to for each sensor.
*  ProgramControl_pinShiftTbl[] - used to store position of pin that 
*  configured as sensor in port. 
*  ProgramControl_prtSelTbl[] - Contains pointers to the HSIOM 
*  registers for each port. 
*  ProgramControl_PrtCfgTb[] - Contains pointers to the port config 
*  registers for each port.
*
* Side Effects: 
*  None
*
*******************************************************************************/
__INLINE void ProgramControl_EnableSensor(uint32 sensor)
{
	uint8  pinModeShift;
    uint8  pinHSIOMShift;
	uint8 interruptState;
	uint32 newRegisterValue;
    uint32 port;
	
	port = (uint32) ProgramControl_portTable[sensor];
    pinModeShift = ProgramControl_pinShiftTbl[sensor]  * ProgramControl_PC_PIN_CFG_SIZE;
    pinHSIOMShift = ProgramControl_pinShiftTbl[sensor] * ProgramControl_HSIOM_PIN_CFG_SIZE;

	interruptState = CyEnterCriticalSection();
	
	newRegisterValue = *ProgramControl_prtSelTbl[port];
	newRegisterValue &= ~(ProgramControl_CSD_HSIOM_MASK << pinHSIOMShift);
	newRegisterValue |= (uint32)((uint32)ProgramControl_CSD_SENSE_PORT_MODE << pinHSIOMShift);
   
    *ProgramControl_prtCfgTbl[port] &= (uint32)~((uint32)ProgramControl_CSD_PIN_MODE_MASK << pinModeShift);
    *ProgramControl_prtSelTbl[port] = newRegisterValue;
	
	CyExitCriticalSection(interruptState);
}


/*******************************************************************************
* Function Name: ProgramControl_DisableSensor
********************************************************************************
*
* Summary:
*  Disables the selected sensor. The corresponding pin is disconnected from the
*  Analog Mux Bus and connected to GND, High_Z or Shield electrode.
*
* Parameters:
*  sensor:  Sensor number
*
* Return:
*  None
*
* Global Variables:
*  ProgramControl_portTable[] - used to store the port number that pin 
*  belongs to for each sensor.
*  ProgramControl_pinShiftTbl[] - used to store position of pin that 
*  configured as a sensor in the port. 
*  ProgramControl_prtSelTbl[] - Contains pointers to the HSIOM 
*  registers for each port. 
*  ProgramControl_PrtCfgTb[] - Contains pointers to the port config 
*  registers for each port.
*
* Side Effects: 
*  None
*
*******************************************************************************/
__INLINE void ProgramControl_DisableSensor(uint32 sensor)
{
    uint8 interruptState;
	uint32 newRegisterValue;
	
    uint32 port = (uint32) ProgramControl_portTable[sensor];
    uint8  pinHSIOMShift = ProgramControl_pinShiftTbl[sensor] * ProgramControl_HSIOM_PIN_CFG_SIZE;
    uint8  pinModeShift = ProgramControl_pinShiftTbl[sensor]  * ProgramControl_PC_PIN_CFG_SIZE;

	uint32 inactiveConnect = ProgramControl_SNS_HIZANALOG_CONNECT;
	uint32 sensorState = ProgramControl_unscannedSnsDriveMode[sensor];

    *ProgramControl_prtSelTbl[port] &= ~(ProgramControl_CSD_HSIOM_MASK << pinHSIOMShift);

	#if(ProgramControl_IS_SHIELD_ENABLE != 0)
	if(sensorState != (uint32)ProgramControl__SHIELD)
	{
	#else
	    /* Connected to Ground if shield is disabled */
	    if(sensorState == (uint32)ProgramControl__SHIELD)
		{
			sensorState = (uint32)ProgramControl__GROUND;
		}
	#endif /* (ProgramControl_IS_SHIELD_ENABLE) */
	    if(sensorState != (uint32)ProgramControl__HIZ_ANALOG)
		{   
		    /* Connected to Ground */
		    inactiveConnect = (uint32)ProgramControl_SNS_GROUND_CONNECT;
		}
		
        interruptState = CyEnterCriticalSection();

        /* Set drive mode */
    	newRegisterValue = *ProgramControl_prtCfgTbl[port];
    	newRegisterValue &= ~(ProgramControl_CSD_PIN_MODE_MASK << pinModeShift);
    	newRegisterValue |=  (uint32)(inactiveConnect << pinModeShift);
        *ProgramControl_prtCfgTbl[port] =  newRegisterValue;
        
        CyExitCriticalSection(interruptState);

    	*ProgramControl_prtDRTbl[port]  &=  (uint32)~(uint32)((uint32)1u << ProgramControl_pinShiftTbl[sensor]); 
	#if(ProgramControl_IS_SHIELD_ENABLE != 0)
	}
	else
	{
		/* Connect to Shield */
		*ProgramControl_prtSelTbl[port] |= (ProgramControl_CSD_SHIELD_PORT_MODE << pinHSIOMShift);
	}
	#endif /* (ProgramControl_IS_SHIELD_ENABLE) */
}


/*******************************************************************************
* Function Name: ProgramControl_SetDriveModeAllPins
********************************************************************************
*
* Summary:
* This API sets the drive mode of port pins used by the CapSense
* component (sensors, guard, shield, shield tank and Cmod) to drive the 
* mode specified by the argument.
*
* Parameters:
*  driveMode:  Drive mode definition.
*
* Return:
*  None
*
* Global Variables:
*  ProgramControl_portTable[] - used to store the port number that pin 
*  belongs to for each sensor.
*  ProgramControl_pinShiftTbl[] - used to store position of pin that 
*  configured as a sensor in the port. 
*
* Side Effects: 
*  This API shall be called only after CapSense component is stopped.
*
*******************************************************************************/
void ProgramControl_SetDriveModeAllPins(uint32 driveMode)
{
	uint8 curSensor;
	#if (ProgramControl_IS_COMPLEX_SCANSLOTS)
		uint8 snsNumber;
		uint8 snsType;
	#endif  /* ProgramControl_IS_COMPLEX_SCANSLOTS */
	uint32 prtNumberTmp;
	uint32 pinNumberTmp;

	for(curSensor = 0u; curSensor < ProgramControl_TOTAL_SENSOR_COUNT; curSensor++)
	{	
		#if (ProgramControl_IS_COMPLEX_SCANSLOTS)
			/* Read sensor type: single or complex */
			snsType = ProgramControl_portTable[curSensor];
		
			/* Check if sensor is complex */
			if ((snsType & ProgramControl_COMPLEX_SS_FLAG) == 0u)
			{
				/* The sensor is not complex */
				snsNumber = curSensor;
			}
			else
			{
				/* Get dedicated sensor ID of the complex sensor */
				snsType &= ~ProgramControl_COMPLEX_SS_FLAG;
				snsNumber = ProgramControl_indexTable[snsType];
			}

			prtNumberTmp = ProgramControl_portTable[snsNumber];
			pinNumberTmp = ProgramControl_pinShiftTbl[snsNumber];
		#else
			prtNumberTmp = ProgramControl_portTable[curSensor];
			pinNumberTmp = ProgramControl_pinShiftTbl[curSensor];
		#endif  /* ProgramControl_IS_COMPLEX_SCANSLOTS */
	
		ProgramControl_SetPinDriveMode(driveMode, pinNumberTmp, prtNumberTmp);
	}
	
	ProgramControl_SetPinDriveMode(driveMode, (uint32)ProgramControl_CMOD_PIN_NUMBER, (uint32)ProgramControl_CMOD_PRT_NUMBER);
	
	#if(0u != ProgramControl_CSH_TANK_ENABLE)
		ProgramControl_SetPinDriveMode(driveMode, (uint32)ProgramControl_CTANK_PIN_NUMBER, (uint32)ProgramControl_CTANK_PRT_NUMBER);
	#endif /* (0u != ProgramControl_CSH_TANK_ENABLE) */	
	
	#if(0u != ProgramControl_IS_SHIELD_ENABLE)
		ProgramControl_SetPinDriveMode(driveMode, (uint32)ProgramControl_SHIELD_PIN_NUMBER, (uint32)ProgramControl_SHIELD_PORT_NUMBER);
	#endif /* (0u != ProgramControl_IS_SHIELD_ENABLE) */	
}


/*******************************************************************************
* Function Name: ProgramControl_RestoreDriveModeAllPins
********************************************************************************
*
* Summary:
*  This API restores the drive for all the CapSense port pins to the original
*  state.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global Variables:
*  ProgramControl_prtSelTbl[] - Contains pointers to the HSIOM 
*  registers for each port. 
*
* Side Effects: 
*  This API is called only after the CapSense component is stopped.
*
*******************************************************************************/
void ProgramControl_RestoreDriveModeAllPins(void)
{
	uint32 newRegisterValue;
	
	ProgramControl_SetDriveModeAllPins(CY_SYS_PINS_DM_ALG_HIZ);
	
	newRegisterValue = ProgramControl_CMOD_CONNECTION_REG; 
    newRegisterValue &= ~(ProgramControl_CSD_CMOD_CONNECTION_MASK);
    newRegisterValue |= ProgramControl_CSD_CMOD_TO_AMUXBUS_A;
    ProgramControl_CMOD_CONNECTION_REG = newRegisterValue;
	
	#if(0u != ProgramControl_CSH_TANK_ENABLE)
		newRegisterValue = ProgramControl_CTANK_CONNECTION_REG;
        newRegisterValue &= ~(ProgramControl_CSD_CTANK_CONNECTION_MASK);
		newRegisterValue |= ProgramControl_CSD_CTANK_TO_AMUXBUS_B;
        ProgramControl_CTANK_CONNECTION_REG = newRegisterValue;
	#endif/* (0u != ProgramControl_CSH_TANK_ENABLE) */
	
	#if(0u != ProgramControl_IS_SHIELD_ENABLE)
		newRegisterValue = *ProgramControl_prtSelTbl[ProgramControl_SHIELD_PORT_NUMBER];
        newRegisterValue &= ~(ProgramControl_CSD_HSIOM_MASK << ((uint32)ProgramControl_SHIELD_PIN_NUMBER * ProgramControl_HSIOM_PIN_CFG_SIZE));
        newRegisterValue |= (ProgramControl_CSD_SHIELD_PORT_MODE << ((uint32)ProgramControl_SHIELD_PIN_NUMBER * ProgramControl_HSIOM_PIN_CFG_SIZE));
        *ProgramControl_prtSelTbl[ProgramControl_SHIELD_PORT_NUMBER] = newRegisterValue;
	#endif /* (0u != ProgramControl_IS_SHIELD_ENABLE) */	
}


/*******************************************************************************
* Function Name: ProgramControl_SetPinDriveMode
********************************************************************************
*
* Summary:
* This API sets the drive mode for the appropriate port/pin.
*
* Parameters:
*  driveMode:  Drive mode definition.
*  portNumber: contains port number (0, 1, 2).
*  pinNumber: contains pin number (0, 1, 2, ... , 7).
*
* Return:
*  None
*
* Global Variables:
*  ProgramControl_prtSelTbl[] - Contains pointers to the HSIOM 
*  registers for each port. 
*  ProgramControl_prtCfgTb[] - Contains pointers to the port config 
*  registers for each port.
*
* Side Effects: 
*  This API is called only after CapSense component is stopped.
*
*******************************************************************************/
void ProgramControl_SetPinDriveMode(uint32 driveMode, uint32 pinNumber, uint32 portNumber)
{	
	uint32  pinModeShift;
	uint32 newRegisterValue;
	
	pinModeShift  = pinNumber * ProgramControl_PC_PIN_CFG_SIZE;
	
	newRegisterValue = *ProgramControl_prtCfgTbl[portNumber];
	newRegisterValue &= ~(ProgramControl_CSD_PIN_MODE_MASK << pinModeShift);
	newRegisterValue |=  (uint32)((uint32)driveMode << pinModeShift);
    *ProgramControl_prtCfgTbl[portNumber] =  newRegisterValue;
}


/*******************************************************************************
* Function Name: ProgramControl_PreScan
********************************************************************************
*
* Summary:
*  Sets required settings, enables a sensor, removes Vref from AMUX and starts the 
*  scanning process of the sensor.
*
* Parameters:
*  sensor:  Sensor number.
*
* Return:
*  None
*
* Global Variables:
* ProgramControl_widgetNumber[] - This array contains numbers of widgets for each sensor.
* ProgramControl_widgetResolution[] - Contains the widget resolution.
*
* Side Effects: 
*  None
*
*******************************************************************************/
void ProgramControl_PreScan(uint32 sensor)
{
    uint8 widget;
    uint8 interruptState;
	uint32 newRegValue;
	uint32 counterResolution;
	
	#if(ProgramControl_PRS_OPTIONS == ProgramControl__PRS_AUTO)
		uint8 senseClkDivMath;
		uint8 sampleClkDivMath;
	#endif /* (ProgramControl_PRS_OPTIONS == ProgramControl__PRS_AUTO) */	
	
	#if ((ProgramControl_TUNING_METHOD == ProgramControl__TUNING_AUTO) &&\
		 (0 != ProgramControl_IS_OVERSAMPLING_EN))
		uint32 oversamplingFactor;
	#endif /* ((ProgramControl_TUNING_METHOD == ProgramControl__TUNING_AUTO) &&\
	           (0 != ProgramControl_IS_OVERSAMPLING_EN)) */

    /* Define widget sensor belongs to */
    widget = ProgramControl_widgetNumber[sensor];

	/* Recalculate Counter Resolution to MSB 16 bits */
	counterResolution = ProgramControl_widgetResolution[widget];
	
	#if ((ProgramControl_TUNING_METHOD == ProgramControl__TUNING_AUTO) &&\
		 (0 != ProgramControl_IS_OVERSAMPLING_EN))
	    oversamplingFactor = ProgramControl_GetBitValue(scanSpeedTbl, sensor);

		if(counterResolution < ProgramControl_RESOLUTION_16_BITS)
		{
			counterResolution <<= oversamplingFactor;
			counterResolution |= (uint32)(ProgramControl_RESOLUTION_8_BITS);
		}
	#endif /* ((ProgramControl_TUNING_METHOD == ProgramControl__TUNING_AUTO) &&\
	           (0 != ProgramControl_IS_OVERSAMPLING_EN)) */
	
	#if (0u != ProgramControl_IS_M0S8PERI_BLOCK)
		ProgramControl_SenseClk_Stop();
		ProgramControl_SampleClk_Stop();
	#endif /* (0u != ProgramControl_IS_M0S8PERI_BLOCK) */

	#if (0u != ProgramControl_MULTIPLE_FREQUENCY_SET)
		ProgramControl_SampleClk_SetDividerValue((uint16)ProgramControl_sampleClkDividerVal[sensor]);
		ProgramControl_SenseClk_SetDividerValue((uint16)ProgramControl_senseClkDividerVal[sensor]);
	#else
		ProgramControl_SampleClk_SetDividerValue((uint16)ProgramControl_sampleClkDividerVal);
		ProgramControl_SenseClk_SetDividerValue((uint16)ProgramControl_senseClkDividerVal);
	#endif /* (0u != ProgramControl_MULTIPLE_FREQUENCY_SET) */

	#if (0u != ProgramControl_IS_M0S8PERI_BLOCK)
		ProgramControl_SampleClk_Start();
		ProgramControl_SenseClk_StartEx(ProgramControl_SampleClk__DIV_ID);
		
		#if(ProgramControl_PRS_OPTIONS == ProgramControl__PRS_NONE)
			CyIntDisable(ProgramControl_ISR_NUMBER);
			ProgramControl_CSD_CNT_REG = ProgramControl_ONE_CYCLE;
			while(0u != (ProgramControl_CSD_CNT_REG & ProgramControl_RESOLUTION_16_BITS))
			{
			/* Wait until scanning is complete */ 
			}
			ProgramControl_CSD_INTR_REG = 1u;
			CyIntClearPending(ProgramControl_ISR_NUMBER);
			CyIntEnable(ProgramControl_ISR_NUMBER); 
		#endif /* ProgramControl_PRS_OPTIONS == ProgramControl__PRS_NONE */
	#endif /* (0u != ProgramControl_IS_M0S8PERI_BLOCK) */

#if(ProgramControl_PRS_OPTIONS != ProgramControl__PRS_NONE)

	#if(ProgramControl_TUNING_METHOD == ProgramControl__TUNING_AUTO)
		if(ProgramControl_prescalersTuningDone != 0u)
		{
	#endif /* (ProgramControl_TUNING_METHOD == ProgramControl__TUNING_AUTO) */
			
			CyIntDisable(ProgramControl_ISR_NUMBER);
			
			newRegValue = ProgramControl_CSD_CFG_REG;
			newRegValue |= ProgramControl_CSD_CFG_PRS_SELECT;
			
			#if(ProgramControl_PRS_OPTIONS == ProgramControl__PRS_AUTO)
				
				newRegValue &= ~(ProgramControl_PRS_MODE_MASK);
				
				#if (0u != ProgramControl_MULTIPLE_FREQUENCY_SET)
					senseClkDivMath = ProgramControl_senseClkDividerVal[sensor];
					sampleClkDivMath = ProgramControl_sampleClkDividerVal[sensor];
				#else
					senseClkDivMath = ProgramControl_senseClkDividerVal;
					sampleClkDivMath = ProgramControl_sampleClkDividerVal;
				#endif /* ( ProgramControl_MULTIPLE_FREQUENCY_SET) */
				
				#if(0u == ProgramControl_IS_M0S8PERI_BLOCK)
					senseClkDivMath *= sampleClkDivMath;
				#endif /* (0u == ProgramControl_IS_M0S8PERI_BLOCK) */	
				
				if((senseClkDivMath * ProgramControl_RESOLUTION_12_BITS) <
				   (sampleClkDivMath * ProgramControl_widgetResolution[widget]))
				{
					newRegValue |= ProgramControl_CSD_PRS_12_BIT;
				}
			#endif /* (ProgramControl_PRS_OPTIONS == ProgramControl__PRS_AUTO) */
			
			ProgramControl_CSD_CFG_REG = newRegValue;
			
			CyIntEnable(ProgramControl_ISR_NUMBER);
			
	#if(ProgramControl_TUNING_METHOD == ProgramControl__TUNING_AUTO)	
		}
	#endif /* (ProgramControl_PRS_OPTIONS != ProgramControl__PRS_NONE) */

#endif /* (ProgramControl_PRS_OPTIONS == ProgramControl__PRS_NONE) */
	
	/* Set Idac Value */
	CyIntDisable(ProgramControl_ISR_NUMBER);
    newRegValue = ProgramControl_CSD_IDAC_REG;
 
#if (ProgramControl_IDAC_CNT == 1u)    
	newRegValue &= ~(ProgramControl_CSD_IDAC1_DATA_MASK);
	newRegValue |= ProgramControl_modulationIDAC[sensor];
#else
	newRegValue &= ~(ProgramControl_CSD_IDAC1_DATA_MASK | ProgramControl_CSD_IDAC2_DATA_MASK);
	newRegValue |= (ProgramControl_modulationIDAC[sensor] | 
							(uint32)((uint32)ProgramControl_compensationIDAC[sensor] <<
							ProgramControl_CSD_IDAC2_DATA_OFFSET));                               
#endif /* (ProgramControl_IDAC_CNT == 1u) */
	
	ProgramControl_CSD_IDAC_REG = newRegValue;

#if(ProgramControl_CMOD_PREGARGE_OPTION == ProgramControl__CAPPRIOBUF)
	newRegValue = ProgramControl_CMOD_CONNECTION_REG;
	newRegValue &= ~(ProgramControl_CSD_CMOD_CONNECTION_MASK);
	newRegValue |= ProgramControl_CSD_CMOD_TO_AMUXBUS_A;
	ProgramControl_CMOD_CONNECTION_REG = newRegValue;
	
	newRegValue = ProgramControl_CMOD_PORT_PC_REG;
	newRegValue &= ~(ProgramControl_CSD_CMOD_PC_MASK);
	newRegValue |= ProgramControl_CMOD_PC_HIGH_Z_MODE;
	ProgramControl_CMOD_PORT_PC_REG = newRegValue;
#endif /* (ProgramControl_CMOD_PREGARGE_OPTION == ProgramControl__CAPPRIOBUF) */

    /* Disconnect Vref Buffer from AMUX */
	newRegValue = ProgramControl_CSD_CFG_REG;
	newRegValue &= ~(ProgramControl_PRECHARGE_CONFIG_MASK);
	newRegValue |= ProgramControl_CTANK_PRECHARGE_CONFIG;
	
	CyIntEnable(ProgramControl_ISR_NUMBER);
	
    /* Enable Sensor */
    ProgramControl_EnableScanSlot(sensor);
    
	interruptState = CyEnterCriticalSection();
	ProgramControl_CSD_CFG_REG = newRegValue;
	
	/* `#START ProgramControl_PreSettlingDelay_Debug` */

	/* `#END` */
	
	CyDelayCycles(ProgramControl_GLITCH_ELIMINATION_CYCLES);
	
	/* `#START ProgramControl_PreScan_Debug` */

	/* `#END` */
	
    ProgramControl_CSD_CNT_REG = counterResolution;
    CyExitCriticalSection(interruptState);
}


/*******************************************************************************
* Function Name: ProgramControl_PostScan
********************************************************************************
*
* Summary:
*  Stores the results of measurement in the ProgramControl_sensorRaw[] array,
*  sets the scanning sensor in the non-sampling state, turns off Idac(Current Source IDAC),
*  disconnects the IDAC(Sink mode), and applies Vref on AMUX.
*
* Parameters:
*  sensor:  Sensor number.
*
* Return:
*  None
*
* Global Variables:
*  ProgramControl_sensorRaw[] - used to store sensors raw data.
*
* Side Effects: 
*  None
*
*******************************************************************************/
void ProgramControl_PostScan(uint32 sensor)
{	
	uint32 newRegValue;
#if ((ProgramControl_TUNING_METHOD == ProgramControl__TUNING_AUTO) &&\
	 (0 != ProgramControl_IS_OVERSAMPLING_EN))
    uint32 oversamplingFactor;
    uint32 widget;
#endif /* ((ProgramControl_TUNING_METHOD == ProgramControl__TUNING_AUTO) &&\
		   (0 != ProgramControl_IS_OVERSAMPLING_EN)) */	

	/* `#START ProgramControl_PostScan_Debug` */

	/* `#END` */


    /* Read SlotResult from Raw Counter */
    ProgramControl_sensorRaw[sensor]  = (uint16)ProgramControl_CSD_CNT_REG;
	
#if ((ProgramControl_TUNING_METHOD == ProgramControl__TUNING_AUTO) &&\
	 (0 != ProgramControl_IS_OVERSAMPLING_EN))
	widget = ProgramControl_widgetNumber[sensor];
	if(ProgramControl_widgetResolution[widget] < ProgramControl_RESOLUTION_16_BITS)
	{
		oversamplingFactor = ProgramControl_GetBitValue(scanSpeedTbl, sensor);
		ProgramControl_sensorRaw[sensor] >>= oversamplingFactor;
	}
#endif /* ((ProgramControl_TUNING_METHOD == ProgramControl__TUNING_AUTO) &&\
		   (0 != ProgramControl_IS_OVERSAMPLING_EN)) */

    /* Disable Sensor */
    ProgramControl_DisableScanSlot(sensor);

	CyIntDisable(ProgramControl_ISR_NUMBER);
	
#if(ProgramControl_CMOD_PREGARGE_OPTION == ProgramControl__CAPPRIOBUF)
	newRegValue = ProgramControl_CMOD_CONNECTION_REG;
	newRegValue &= ~(ProgramControl_CSD_CMOD_CONNECTION_MASK);
	newRegValue |= ProgramControl_CSD_CMOD_TO_AMUXBUS_B;
	ProgramControl_CMOD_CONNECTION_REG = newRegValue;
	
	newRegValue = ProgramControl_CMOD_PORT_PC_REG;
	newRegValue &= ~(ProgramControl_CSD_CMOD_PC_MASK);
	newRegValue |= ProgramControl_CMOD_PC_STRONG_MODE;
	ProgramControl_CMOD_PORT_PC_REG = newRegValue;
		
	newRegValue = ProgramControl_CMOD_PORT_DR_REG;
    newRegValue &= ~(ProgramControl_CMOD_DR_MASK);
	newRegValue |= ProgramControl_CMOD_DR_CONFIG;
    ProgramControl_CMOD_PORT_DR_REG = newRegValue;    
#endif /* (ProgramControl_CMOD_PREGARGE_OPTION == ProgramControl__CAPPRIOBUF) */
	
	/* Connect Vref Buffer to AMUX bus  */
	newRegValue = ProgramControl_CSD_CFG_REG;
	newRegValue &= ~(ProgramControl_PRECHARGE_CONFIG_MASK);
	newRegValue |= ProgramControl_CMOD_PRECHARGE_CONFIG;
	ProgramControl_CSD_CFG_REG = newRegValue;

	/* Set Idac Value = 0 */
#if (ProgramControl_IDAC_CNT == 1u)   
	ProgramControl_CSD_IDAC_REG &= ~(ProgramControl_CSD_IDAC1_DATA_MASK);
#else
	ProgramControl_CSD_IDAC_REG &= ~(ProgramControl_CSD_IDAC1_DATA_MASK | ProgramControl_CSD_IDAC2_DATA_MASK);                               
#endif /* (ProgramControl_IDAC_CNT == 1u) */

	CyIntEnable(ProgramControl_ISR_NUMBER);
}


/*******************************************************************************
* Function Name: ProgramControl_EnableShieldElectrode
********************************************************************************
*
* Summary:
*  This API enables or disables the shield electrode on a specified port pin.
*
* Parameters:
*  portNumber: contains the shield electrode port number (0, 1, 2).
*  pinNumber: contains the shield electrode pin number (0, 1, 2, ... , 7).
*
* Return:
*  None
*
* Global Variables:
*  ProgramControl_prtCfgTbl[] - Contains pointers to the port config registers for each port.
*  ProgramControl_prtSelTbl[] - Contains pointers to the HSIOM registers for each port.
*
* Side Effects: 
*  None
*
*******************************************************************************/
void ProgramControl_EnableShieldElectrode(uint32 pinNumber, uint32 portNumber)
{
	uint32 newRegValue;
	
	*ProgramControl_prtCfgTbl[portNumber] &= ~(ProgramControl_CSD_PIN_MODE_MASK << (pinNumber * ProgramControl_PC_PIN_CFG_SIZE));
	newRegValue = *ProgramControl_prtSelTbl[portNumber];
    newRegValue &= ~(ProgramControl_CSD_HSIOM_MASK << (pinNumber * ProgramControl_HSIOM_PIN_CFG_SIZE));
    newRegValue |= (ProgramControl_CSD_SHIELD_PORT_MODE << (pinNumber * ProgramControl_HSIOM_PIN_CFG_SIZE));
    *ProgramControl_prtSelTbl[portNumber] = newRegValue;
}


/*******************************************************************************
* Function Name: ProgramControl_SetShieldDelay
********************************************************************************
*
* Summary:
*  This API sets a shield delay.
*
* Parameters:
*  delay:  shield delay value:
*                               0 - no delay
*                               1 - 1 cycle delay
*                               2 - 2 cycles delay
*
* Return:
*  None
*
* Global Variables:
*  None
*
* Side Effects: 
*  None
*
*******************************************************************************/
void ProgramControl_SetShieldDelay(uint32 delay)
{
    uint32 newRegValue;
    
    delay &= 0x03u;
    
    newRegValue = ProgramControl_CSD_CFG_REG;
    newRegValue &= (uint32)(~(uint32)ProgramControl_SHIELD_DELAY);    
    newRegValue |= (delay << ProgramControl_CSD_CFG_SHIELD_DELAY_POS);    
    ProgramControl_CSD_CFG_REG = newRegValue;
}


/*******************************************************************************
* Function Name: ProgramControl_ReadCurrentScanningSensor
********************************************************************************
*
* Summary:
*  This API returns scanning sensor number when sensor scan is in progress. 
*  When sensor scan is completed the API returns 
*  $INSTANCE_NAME`_NOT_SENSOR (0xFFFFFFFF) (when no sensor is scanned).
*
* Parameters:
*	None.
*
* Return:
*  Returns Sensor number if sensor is being scanned and 
*  $INSTANCE_NAME`_NOT_SENSOR (0xFFFFFFFF) if scanning is complete.
*
* Global Variables:
*  ProgramControl_sensorIndex - the sensor number is being scanned.
*
* Side Effects: 
*  None
*
*******************************************************************************/
uint32 ProgramControl_ReadCurrentScanningSensor(void)
{
    return ((uint32)(( 0u != (ProgramControl_csdStatusVar & ProgramControl_SW_STS_BUSY)) ? 
                     ProgramControl_sensorIndex : ProgramControl_NOT_SENSOR));
}


/*******************************************************************************
* Function Name: ProgramControl_GetBitValue
********************************************************************************
*
* Summary:
*  The API returns a bit status of the bit in the table array which contains the masks.
* 
* Parameters:
*  table[] - array with bit masks.
*  position - position of bit in the table[] array.
*
* Return:
*  0 - bit is not set; 1 - bit is set.
*
* Global Variables:
*  None
*
* Side Effects:
*  None
*
*******************************************************************************/
uint32 ProgramControl_GetBitValue(const uint8 table[], uint32 position)
{
    uint32 offset;
	uint8 enMask;
	
	/* position is divided by 8 to calculate the element of the 
	   table[] array that contains the enable bit 
	   for an appropriate sensor.
	*/
	offset = (position >> 3u);
	
	/* The enMask calculation for the appropriate sensor. Operation (position & 0x07u) 
	   intends to calculate the enable bit offset for the 8-bit element of the 
	   table[] array.
	*/
	enMask = 0x01u << (position & 0x07u);
    
    return ((0u !=(table[offset] & enMask)) ? 1Lu : 0Lu);
}


/*******************************************************************************
* Function Name: ProgramControl_SetBitValue
********************************************************************************
*
* Summary:
*  The API sets a bit status of the bit in the table array which contains masks.
* 
* Parameters:
*  table[] - array with bit masks.
*  position - position of bit in the table[] array.
*  value: 0 - bit is not set; 1 - bit is set.
*
* Return:
*  None
*
* Global Variables:
*  None
*
* Side Effects:
*  None
*
*******************************************************************************/
void ProgramControl_SetBitValue(uint8 table[], uint32 position, uint32 value)
{
    uint32 offset;
	uint8 enMask;
	
	/* position is divided by 8 to calculate the element of the 
	   table[] array that contains the enable bit 
	   for an appropriate sensor.
	*/
	offset = (position >> 3u);
	
	/* The enMask calculation for the appropriate sensor. Operation (position & 0x07u) 
	   intends to calculate the enable bit offset for the 8-bit element of the 
	   table[] array.
	*/
	enMask = 0x01u << (position & 0x07u);
	
	if(0u != value)
	{
		table[offset] |= enMask;
	}
	else
	{
		table[offset] &= (uint8)~(enMask);
	}
}



/*******************************************************************************
* Function Name: ProgramControl_GetSenseClkDivider
********************************************************************************
*
* Summary:
*  This API returns a value of the sense clock divider for the  sensor.
*
* Parameters:
*  sensor: sensor index. The index value can be 
*  from 0 to (ProgramControl_TOTAL_SENSOR_COUNT-1).
*
* Return:
*  This API returns the sense clock divider of the sensor. 
*
* Global Variables:
*  ProgramControl_senseClkDividerVal[] - stores the sense clock divider values.
* 
* Side Effects:
*  None
*
*******************************************************************************/
uint32 ProgramControl_GetSenseClkDivider(uint32 sensor)
{
	#if(0u != ProgramControl_MULTIPLE_FREQUENCY_SET)
		return((uint32)ProgramControl_senseClkDividerVal[sensor]);
	#else
		return((uint32)ProgramControl_senseClkDividerVal);
	#endif /* (0u != ProgramControl_MULTIPLE_FREQUENCY_SET) */
}

#if (ProgramControl_TUNING_METHOD != ProgramControl__TUNING_NONE)
	/*******************************************************************************
	* Function Name: ProgramControl_SetSenseClkDivider
	********************************************************************************
	*
	* Summary:
	*  This API sets a value of the sense clock divider for the  sensor. 
	*
	* Parameters:
	*  sensor:  Sensor index.
	*  senseClk: represents the sense clock value.
	*
	* Return:
	*  None.
	*
	* Global Variables:
	*  ProgramControl_senseClkDividerVal[] - stores the sense clock divider values.
	* 
	* Side Effects:
	*  None
	*
	*******************************************************************************/
	void ProgramControl_SetSenseClkDivider(uint32 sensor, uint32 senseClk)
	{
		#if(0u != ProgramControl_MULTIPLE_FREQUENCY_SET)
			ProgramControl_senseClkDividerVal[sensor] = (uint8)senseClk;
		#else
			ProgramControl_senseClkDividerVal = (uint8)senseClk;
		#endif /* (0u != ProgramControl_MULTIPLE_FREQUENCY_SET) */
	}
#endif /* (ProgramControl_TUNING_METHOD != ProgramControl__TUNING_NONE) */


/*******************************************************************************
* Function Name: ProgramControl_GetModulatorClkDivider
********************************************************************************
*
* Summary:
*  This API returns a value of the modulator sample clock divider for the  sensor.
*
* Parameters:
*  sensor: sensor index. The value of index can be 
*  from 0 to (ProgramControl_TOTAL_SENSOR_COUNT-1).
*
* Return:
*  This API returns the modulator sample clock divider for the  sensor.
*
* Global Variables:
*  ProgramControl_sampleClkDividerVal[] - stores the modulator sample divider values.
* 
* Side Effects:
*  None
*
*******************************************************************************/
uint32 ProgramControl_GetModulatorClkDivider(uint32 sensor)
{
	#if(0u != ProgramControl_MULTIPLE_FREQUENCY_SET)
		return((uint32)ProgramControl_sampleClkDividerVal[sensor]);
	#else
		return((uint32)ProgramControl_sampleClkDividerVal);
	#endif /* (0u != ProgramControl_MULTIPLE_FREQUENCY_SET) */
}

#if (ProgramControl_TUNING_METHOD != ProgramControl__TUNING_NONE)
	/*******************************************************************************
	* Function Name: ProgramControl_SetModulatorClkDivider
	********************************************************************************
	*
	* Summary:
	*  This API sets a value of the modulator sample clock divider for the  sensor.
	*
	* Parameters:
	*  sensor:  Sensor index.
	*  modulatorClk: represents the modulator sample clock value.
	*
	* Return:
	*  None.
	*
	* Global Variables:
	*  ProgramControl_sampleClkDividerVal[] - stores the modulator sample divider values.
	* 
	* Side Effects:
	*  None
	*
	*******************************************************************************/
	void ProgramControl_SetModulatorClkDivider(uint32 sensor, uint32 modulatorClk)
	{
		#if(0u != ProgramControl_MULTIPLE_FREQUENCY_SET)
			ProgramControl_sampleClkDividerVal[sensor] = (uint8)modulatorClk;
		#else
			ProgramControl_sampleClkDividerVal = (uint8)modulatorClk;
		#endif /* (0u != ProgramControl_MULTIPLE_FREQUENCY_SET) */
	}
#endif /* (ProgramControl_TUNING_METHOD != ProgramControl__TUNING_NONE) */

/*******************************************************************************
* Function Name: ProgramControl_GetModulationIDAC
********************************************************************************
*
* Summary:
*  This API returns a value of the modulation IDAC for the  sensor.
*
* Parameters:
*  sensor: sensor index. The index value can be 
*  from 0 to (ProgramControl_TOTAL_SENSOR_COUNT-1).
*
* Return:
*  This API returns the modulation IDAC of the sensor. 
*
* Global Variables:
*  ProgramControl_modulationIDAC[] - stores modulation IDAC values.
* 
* Side Effects:
*  None
*
*******************************************************************************/
uint32 ProgramControl_GetModulationIDAC(uint32 sensor)
{
		return((uint32)ProgramControl_modulationIDAC[sensor]);
}

#if (ProgramControl_TUNING_METHOD != ProgramControl__TUNING_NONE)
	/*******************************************************************************
	* Function Name: ProgramControl_SetModulationIDAC
	********************************************************************************
	*
	* Summary:
	*  This API sets a value of the modulation IDAC for the  sensor.
	*
	* Parameters:
	*  sensor:  Sensor index.
	*  compIdacValue: represents the modulation IDAC data register value.
	*
	* Return:
	*  None.
	*
	* Global Variables:
	*  ProgramControl_modulationIDAC[] - array with modulation IDAC values
	* 
	* Side Effects:
	*  None
	*
	*******************************************************************************/
	void ProgramControl_SetModulationIDAC(uint32 sensor, uint32 modIdacValue)
	{
		ProgramControl_modulationIDAC[sensor] = (uint8)modIdacValue;
	}
#endif /* (ProgramControl_TUNING_METHOD != ProgramControl__TUNING_NONE) */


#if(ProgramControl_IDAC_CNT > 1u)
	/*******************************************************************************
	* Function Name: ProgramControl_GetCompensationIDAC
	********************************************************************************
	*
	* Summary:
	*  This API returns a value of the compensation IDAC for the  sensor.
	*
	* Parameters:
	*  sensor: sensor index. The index value can be 
	*  from 0 to (ProgramControl_TOTAL_SENSOR_COUNT-1).
	*
	* Return:
	*  This API returns the compensation IDAC of the sensor. 
	*
	* Global Variables:
	*  ProgramControl_compensationIDAC[] - stores the compensation IDAC values.
	* 
	* Side Effects:
	*  None
	*
	*******************************************************************************/
	uint32 ProgramControl_GetCompensationIDAC(uint32 sensor)
	{
		return((uint32)ProgramControl_compensationIDAC[sensor]);
	}
#endif /* (ProgramControl_IDAC_CNT > 1u) */


#if((ProgramControl_TUNING_METHOD != ProgramControl__TUNING_NONE) && (ProgramControl_IDAC_CNT > 1u))
	/*******************************************************************************
	* Function Name: ProgramControl_SetCompensationIDAC
	********************************************************************************
	*
	* Summary:
	*  This API sets a value of compensation IDAC for the  sensor.
	*
	* Parameters:
	*  sensor:  Sensor index.
	*  compIdacValue: represents the compensation IDAC data register value.
	*
	* Return:
	*  None.
	*
	* Global Variables:
	*  ProgramControl_compensationIDAC[] - an array with compensation IDAC values
	* 
	* Side Effects:
	*  None
	*
	*******************************************************************************/
	void ProgramControl_SetCompensationIDAC(uint32 sensor, uint32 compIdacValue)
	{
		ProgramControl_compensationIDAC[sensor] = (uint8)compIdacValue;
	}
#endif /* ((ProgramControl_TUNING_METHOD != ProgramControl__TUNING_NONE) && (ProgramControl_IDAC_CNT > 1u)) */

/*******************************************************************************
* Function Name: ProgramControl_GetIDACRange
********************************************************************************
*
* Summary:
*  This API returns a value that indicates the IDAC range used by the 
*  component to scan sensors. The IDAC range is common for all the sensors.
*
* Parameters:
*  None
*
* Return:
*  This API Returns a value that indicates the IDAC range:
*      0 - IDAC range set to 4x
*      1 - IDAC range set to 8x
*
* Global Variables:
*  None
* 
* Side Effects:
*  None
*
*******************************************************************************/
uint32 ProgramControl_GetIDACRange(void)
{
	return((0u != (ProgramControl_CSD_IDAC_REG & ProgramControl_CSD_IDAC1_RANGE_8X)) ? 1uL : 0uL);
}

#if (ProgramControl_TUNING_METHOD != ProgramControl__TUNING_NONE)
	/*******************************************************************************
	* Function Name: ProgramControl_SetIDACRange
	********************************************************************************
	*
	* Summary:
	*  This API sets the IDAC range to the 4x (1.2uA/bit) or 8x (2.4uA/bit) mode.
    *  The IDAC range is common for all the sensors and common for the modulation and 
	*  compensation IDACs.
	*
	* Parameters:
	*  iDacRange:  represents value for IDAC range 
	*  0 -  IDAC range set to 4x (1.2uA/bit)
	*  1 or >1 - IDAC range set to 8x (2.4uA/bit)
	*
	* Return:
	*  None.
	*
	* Global Variables:
	*  None
	* 
	* Side Effects:
	*  None
	*
	*******************************************************************************/
	void ProgramControl_SetIDACRange(uint32 iDacRange)
	{
	    if(iDacRange != 0u)
		{
		    /*  IDAC range = 8x (2.4uA/bit) */ 
		    ProgramControl_CSD_IDAC_REG |= (ProgramControl_CSD_IDAC1_RANGE_8X |\
											  ProgramControl_CSD_IDAC2_RANGE_8X);
		}
		else
		{
		    /*  IDAC range = 4x (1.2uA/bit) */ 
		    /*  IDAC range = 8x (2.4uA/bit) */ 
		    ProgramControl_CSD_IDAC_REG &= ~(ProgramControl_CSD_IDAC1_RANGE_8X |\
											   ProgramControl_CSD_IDAC2_RANGE_8X);
		}
	}
#endif /* (ProgramControl_TUNING_METHOD != ProgramControl__TUNING_NONE) */


#if((0u != ProgramControl_AUTOCALIBRATION_ENABLE) || (ProgramControl_TUNING_METHOD == ProgramControl__TUNING_AUTO))
	/*******************************************************************************
	* Function Name: ProgramControl_GetSensorRaw
	********************************************************************************
	*
	* Summary:
	*  The API updates and gets uprated raw data from the sensor.
	*
	* Parameters:
	*  sensor - Sensor number.
	*
	* Return:
	*  Returns the current raw data value for a defined sensor number.
	*
	* Global Variables:
	*  None
	*
	* Side Effects:
	*  None
	*
	*******************************************************************************/
	uint16  ProgramControl_GetSensorRaw(uint32 sensor)
	{
		uint32 curSample;
		uint32 avgVal = 0u;
		
		for(curSample = 0u; curSample < ProgramControl_AVG_SAMPLES_NUM; curSample++)
		{
	    
			ProgramControl_ScanSensor((uint32)sensor);
		    while(ProgramControl_IsBusy() == 1u)
			{
				/* Wait while sensor is busy */
			}
			avgVal += ProgramControl_ReadSensorRaw((uint32)sensor);
		}
	    
	    return((uint16)(avgVal / ProgramControl_AVG_SAMPLES_NUM));
	}
#endif /* ((0u != ProgramControl_AUTOCALIBRATION_ENABLE) && (ProgramControl_TUNING_METHOD == ProgramControl__TUNING_AUTO)) */


#if((0u != ProgramControl_AUTOCALIBRATION_ENABLE) && (ProgramControl_TUNING_METHOD != ProgramControl__TUNING_AUTO))
	/*******************************************************************************
	* Function Name: ProgramControl_CalibrateSensor
	********************************************************************************
	*
	* Summary:
	*  Computes the one sensor IDAC value, which provides the raw signal on
	*  a specified level, with a specified prescaler, speed, and resolution.
	*
	* Parameters:
	*  sensor - Sensor Number.
	*
	*  rawLevel -  Raw data level which should be reached during the calibration
	*              procedure.
	*
	*  idacLevelsTbl - Pointer to the modulatorIdac data register configuration table.            
	*
	* Return:       
	*  None
	*
	*******************************************************************************/
	void ProgramControl_CalibrateSensor(uint32 sensor, uint32 rawLevel, uint8 idacLevelsTbl[])
	{
		uint8 mask;
		uint16 rawData;
		
		rawData = 0u;
		
		mask = 0x80u;
		/* Init IDAC for null Channel */
		idacLevelsTbl[sensor] = 0x00u;
		
		do
		{
		    /* Set bit for null Channel */
			idacLevelsTbl[sensor] |= mask;

	        /* Scan null Channel and get Rawdata */
			rawData = ProgramControl_GetSensorRaw(sensor);
			
			/* Decrease IDAC until Rawdata reaches rawLevel */ 
			if(rawData < rawLevel)
			{
			    /* Reset bit for null Channel  */ 
				idacLevelsTbl[sensor] &= (uint8)~mask;
			}
			
			mask >>= 1u;
		}
		while(mask > 0u);
		
	}
#endif /* ((0u != ProgramControl_AUTOCALIBRATION_ENABLE) && (ProgramControl_TUNING_METHOD != ProgramControl__TUNING_AUTO)) */


/*******************************************************************************
* Function Name: ProgramControl_SetUnscannedSensorState
********************************************************************************
*
* Summary:
*  This API sets a state for un-scanned sensors. 
*  It is possible to set the state to Ground, High-Z, or the shield electrode. 
*  The un-scanned sensor can be connected to a shield electrode only if the shield is 
*  enabled. If the shield is disabled and this API is called with the parameter which
*  indicates the shield state, the un-scanned sensor will be connected to Ground.
*
* Parameters:
*  sensor - Sensor Number.
*  sensorState: This parameter indicates un-scanned sensor state:
*
*     ProgramControl__GROUND 0
*     ProgramControl__HIZ_ANALOG 1
*     ProgramControl__SHIELD 2
*
* Return:
*  None.
*
* Global Variables:
*  ProgramControl_unscannedSnsDriveMode[] - used to store the state for
*  un-scanned sensors.
* 
* Side Effects:
*  None
*
*******************************************************************************/
void ProgramControl_SetUnscannedSensorState(uint32 sensor, uint32 sensorState)
{
    ProgramControl_unscannedSnsDriveMode[sensor] = (uint8)sensorState;	
}

#if(0u != ProgramControl_TOTAL_CENTROIDS_COUNT) 
/*******************************************************************************
* Function Name: ProgramControl_NormalizeWidgets
********************************************************************************
*
* Summary:
*  This API aligns all the parameters of the widget to the maximum parameter.
*
* Parameters:
*  uint32 widgetsNum: Number of widgets.
*  uint8 *dataPrt: pointer to array with widget parameters.	
*
* Return:
*  None
*
* Global Variables:
*  ProgramControl_numberOfSensors[] - Number of sensors in the widget.
*  ProgramControl_rawDataIndex[currentWidget] - Contains the  1st sensor
*  position in the widget.
*
* Side Effects:
*  None
*
*******************************************************************************/
void ProgramControl_NormalizeWidgets(uint32 widgetsNum, uint8 *dataPtr)
{
	uint32 currentWidget;
	uint32 currentSensor;
	uint32 lastSensor;
	uint32 sensorsPerWidget;
	uint32 maxPerWidget;

	for(currentWidget = 0u; currentWidget < widgetsNum; currentWidget++)
	{
		maxPerWidget = 0u;
		
		sensorsPerWidget = ProgramControl_numberOfSensors[currentWidget];
		currentSensor = ProgramControl_rawDataIndex[currentWidget];
		lastSensor = currentSensor + sensorsPerWidget;
		
		while(currentSensor < lastSensor)
		{
			if(maxPerWidget < dataPtr[currentSensor])
			{
				maxPerWidget = dataPtr[currentSensor];
			}
			currentSensor++;
		}
		
		currentSensor = ProgramControl_rawDataIndex[currentWidget];
		
		while(currentSensor < lastSensor)
		{
			dataPtr[currentSensor] = (uint8)maxPerWidget;
			currentSensor++;
		}
	}
}
#endif /* (0u != ProgramControl_TOTAL_CENTROIDS_COUNT) */

/* [] END OF FILE */
