/*******************************************************************************
* File Name: ProgramControl_PM.c
* Version 2.10
*
* Description:
*  This file provides Sleep APIs for CapSense CSD Component.
*
* Note:
*
********************************************************************************
* Copyright 2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "ProgramControl.h"

static ProgramControl_BACKUP_STRUCT ProgramControl_backup =
{   
    0x00u, /* enableState; */
};


/*******************************************************************************
* Function Name: ProgramControl_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the customer configuration of CapSense.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global Variables:
*  ProgramControl_backup - used to save the component state before entering the  sleep 
*  mode and none-retention registers.
*
* Side Effects:
*  None
*
*******************************************************************************/
void ProgramControl_SaveConfig(void)
{
	if ((ProgramControl_CSD_CFG_REG & ProgramControl_CSD_CFG_ENABLE) != 0u)
	{
		ProgramControl_backup.enableState = 1u;
	}
}


/*******************************************************************************
* Function Name: ProgramControl_Sleep
********************************************************************************
*
* Summary:
*  Disables the Active mode power.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global Variables:
*  ProgramControl_backup - used to save the component state before entering the sleep 
*  mode.
*
*******************************************************************************/
void ProgramControl_Sleep(void)
{
	ProgramControl_SaveConfig();
		
	/* Disable interrupt */
	CyIntDisable(ProgramControl_ISR_NUMBER);
	
	ProgramControl_CSD_CFG_REG &= ~(ProgramControl_CSD_CFG_SENSE_COMP_EN | ProgramControl_CSD_CFG_SENSE_EN);
	
	#if(ProgramControl_IDAC_CNT == 2u)
		ProgramControl_CSD_CFG_REG &= ~(ProgramControl_CSD_CFG_ENABLE);
	#endif /* (ProgramControl_IDAC_CNT == 2u) */
	
	/* Disable Clocks */
    ProgramControl_SenseClk_Stop();
    ProgramControl_SampleClk_Stop();
}


/*******************************************************************************
* Function Name: ProgramControl_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the CapSense configuration.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Side Effects:
*  Must be called only after ProgramControl_SaveConfig() routine. Otherwise 
*  the component configuration will be overwritten with its initial setting.  
*
* Global Variables:
*  ProgramControl_backup - used to save the component state before entering the sleep 
*  mode and none-retention registers.
*
*******************************************************************************/
void ProgramControl_RestoreConfig(void)
{

}
 
 
/*******************************************************************************
* Function Name: ProgramControl_Wakeup
********************************************************************************
*
* Summary:
*  Restores the CapSense configuration and non-retention register values. 
*  Restores the enabled state of the component by setting the Active mode power template 
*  bits for a number of components used within CapSense.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global Variables:
*  ProgramControl_backup - used to save the component state before entering the sleep 
*  mode and none-retention registers.
*
*******************************************************************************/
void ProgramControl_Wakeup(void)
{
	/* Enable the Clocks */
    ProgramControl_SenseClk_Start();
    ProgramControl_SampleClk_Start();
    
	/* Restore CapSense Enable state */
    if (ProgramControl_backup.enableState != 0u)
    {
        ProgramControl_Enable();
    }
}


/* [] END OF FILE */
