/* ========================================
 *
 * Copyright Aquamaster Fountains and Aerators
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/
#include <project.h>

// Flash data
static const uint8 CYCODE flashData[3] = {0};
uint8 flashArrayBuffer[3] = {0};

// Define booleans
#define FALSE 0
#define TRUE !FALSE

// Stores button states
uint8 minusButton = FALSE;
uint8 plusButton = FALSE;
uint8 backwardButton = FALSE;
uint8 forwardButton = FALSE;

// Stores program number and sequence speed
uint8 programNumber = 0;
uint8 programSpeed = 1; 

uint8 programChanged = TRUE;
uint8 programPosition = 0;
uint8 positions = 3;

// 10ms delay
uint8 delayTime = 10;
int programTimer = 0;
float setTypeTimer = 0;

// Stores programs
uint8 current[10];
uint8 program03POS[] = {1};
uint8 program13POS[] = {2,6,5,7,3,4};
uint8 program23POS[] = {2,4,8,4,2,5,7,8,7,5};
uint8 program33POS[] = {7,8,6,8,4,8};
uint8 program43POS[] = {5,8,2,8,3,8};
uint8 program53POS[] = {5,3,2,5,3,2};
uint8 program63POS[] = {8};

uint8 program04POS[] = {1};
uint8 program14POS[] = {10,9,13,5,7,3,4,2};
uint8 program24POS[] = {16,6,16,11};
uint8 program34POS[] = {12,10,14,13,15,7,4};
uint8 program44POS[] = {14,10,16,7,15,11,16,6};
uint8 program54POS[] = {16,12,16,14,16,15,16,8};
uint8 program64POS[] = {16};


// Update program number and speed in flash
void UpdateFlash()
{
    // Populate flash array
    flashArrayBuffer[0] = programNumber;
    flashArrayBuffer[1] = programSpeed;
    flashArrayBuffer[2] = positions;
    
    // Write Flash
    cystatus status;
    status = Em_EEPROM_Write(&flashArrayBuffer[0], &flashData[0], 3u);

}

// Updates output LED
void ProgramLED(uint8 lastNumber)
{
    // Turn on correct LED
    if(programNumber == 1){LED1_Write(1);}
    if(programNumber == 2){LED2_Write(1);}
    if(programNumber == 3){LED3_Write(1);}
    if(programNumber == 4){LED4_Write(1);}
    if(programNumber == 5){LED5_Write(1);}
    if(programNumber == 6){LED6_Write(1);}
    
    // Turn off last LED
    if(lastNumber == 1){LED1_Write(0);}
    if(lastNumber == 2){LED2_Write(0);}
    if(lastNumber == 3){LED3_Write(0);}
    if(lastNumber == 4){LED4_Write(0);}
    if(lastNumber == 5){LED5_Write(0);}
    if(lastNumber == 6){LED6_Write(0);}

}

// Update output LED
void SpeedLED()
{
    // Turn off last LED
    if(programSpeed < 2){LED2_Write(0);}
    if(programSpeed < 3){LED3_Write(0);}
    if(programSpeed < 4){LED4_Write(0);}
    if(programSpeed < 5){LED5_Write(0);}
    if(programSpeed < 6){LED6_Write(0);}
    
    // Turn on correct LEDs
    if(programSpeed >= 1){LED1_Write(1);}
    if(programSpeed >= 2){LED2_Write(1);}
    if(programSpeed >= 3){LED3_Write(1);}
    if(programSpeed >= 4){LED4_Write(1);}
    if(programSpeed >= 5){LED5_Write(1);}
    if(programSpeed >= 6){LED6_Write(1);}
    
    // Wait 2 seconds
    CyDelay(1000);
    
    // Turn off all LEDs
    LED1_Write(0);
    LED2_Write(0);
    LED3_Write(0);
    LED4_Write(0);
    LED5_Write(0);
    LED6_Write(0);
    
    // Turn on correct LED
    if(programNumber == 1){LED1_Write(1);}
    if(programNumber == 2){LED2_Write(1);}
    if(programNumber == 3){LED3_Write(1);}
    if(programNumber == 4){LED4_Write(1);}
    if(programNumber == 5){LED5_Write(1);}
    if(programNumber == 6){LED6_Write(1);}   
}

// Turns on correct set type leds
void SetLED()
{
    int i = 0;
    
    // Turn off all LEDs
    LED1_Write(0);
    LED2_Write(0);
    LED3_Write(0);
    LED4_Write(0);
    LED5_Write(0);
    LED6_Write(0);
    
    // Turn on correct LEDs
    if(positions == 3)
    {
        for(i = 0; i < 5; i++)
        {
            LED3_Write(1);
            CyDelay(250);
            LED3_Write(0);
            CyDelay(250);
        }
    }
    else if(positions == 4)
    {
        for(i = 0; i < 5; i++)
        {
            LED4_Write(1);
            CyDelay(250);
            LED4_Write(0);
            CyDelay(250);
        }
    }
    
    // Wait 1 seconds
    CyDelay(1000);
    
    // Turn off all LEDs
    LED1_Write(0);
    LED2_Write(0);
    LED3_Write(0);
    LED4_Write(0);
    LED5_Write(0);
    LED6_Write(0);
    
    // Turn on correct LED
    if(programNumber == 1){LED1_Write(1);}
    if(programNumber == 2){LED2_Write(1);}
    if(programNumber == 3){LED3_Write(1);}
    if(programNumber == 4){LED4_Write(1);}
    if(programNumber == 5){LED5_Write(1);}
    if(programNumber == 6){LED6_Write(1);}   
}

// Changes program number if button is pressed
void ProgramChange()
{
        // Check for forward button
        if(ProgramControl_CheckIsWidgetActive(ProgramControl_FORWARD__BTN))
        {
            // Make sure backward is not also pressed, and that forward was 'unpressed'
            if(!ProgramControl_CheckIsWidgetActive(ProgramControl_BACKWARD__BTN) && !forwardButton)
            {
                // Reset set type timer
                setTypeTimer = 0;
                
                if(programNumber < 6)
                {
                    // Increment number
                    programNumber++;
                    
                    // Turn on correct LED
                    ProgramLED(programNumber - 1);
                    
                    // Update flash memory
                    UpdateFlash();
                }
            }
            // Check to see if both buttons are pressed
            else if(ProgramControl_CheckIsWidgetActive(ProgramControl_BACKWARD__BTN))
            {
                // Increment set type timer
                setTypeTimer += (delayTime / 1000.0);
                
                // If both buttons pressed longer than 3 seconds, indicate set type
                if(setTypeTimer > 3)
                {
                    // Switch positions in set
                    if(positions == 3){positions = 4;}
                    else if(positions == 4){positions = 3;}
                    
                    // Display correct set LEDs
                    SetLED();
                    
                    // Reset set type timer
                    setTypeTimer = 0;
                    
                    // Update flash memory
                    UpdateFlash();
                }
            }
            
            // Record that button was pressed
            forwardButton = TRUE;
            
            // Program was changed
            programChanged = TRUE;
        }
        else
        {
            // Record that button was 'unpressed'
            forwardButton = FALSE;
        }
        
        // Check for backward button
        if(ProgramControl_CheckIsWidgetActive(ProgramControl_BACKWARD__BTN))
        {
            // Make sure forward is not also pressed and that backward was 'unpressed'
            if(!ProgramControl_CheckIsWidgetActive(ProgramControl_FORWARD__BTN) && !backwardButton)
            {
                // Reset set type timer
                setTypeTimer = 0;
                
                if(programNumber > 0)
                {
                    // Decrement number
                    programNumber--;
                    
                    // Turn on correct LED
                    ProgramLED(programNumber + 1);
                    
                    // Update flash memory
                    UpdateFlash();
                }
            }
            
             // Record that button was pressed
            backwardButton = TRUE;
            
            // Program was changed
            programChanged = TRUE;
        }
        else
        {
            // Record that button was 'unpressed'
            backwardButton = FALSE;
        }
        
        // If neither button is pressed, reset set type timer
        if(!ProgramControl_CheckIsWidgetActive(ProgramControl_FORWARD__BTN) && !ProgramControl_CheckIsWidgetActive(ProgramControl_BACKWARD__BTN))
        {
            // Reset set type timer
            setTypeTimer = 0;
        }
        
}

// Changes Speed
void SpeedChange()
{
    // Check for plus button
    if(ProgramControl_CheckIsWidgetActive(ProgramControl_PLUS__BTN))
    {
        // Make sure minus is not also pressed, and that plus was 'unpressed'
        if(!ProgramControl_CheckIsWidgetActive(ProgramControl_MINUS__BTN) && !plusButton)
        {         
            if(programSpeed < 6)
            {
                // Increment number
                programSpeed++;
                
                // Turn on correct LED
                SpeedLED();
                
                // Update flash memory
                UpdateFlash();
            }
            else if(programSpeed == 6)
            {
                // Turn on correct LED
                SpeedLED();
            }
        }
        
        
        // Record that button was pressed
        plusButton = TRUE;
    }
    else
    {
        // Record that button was 'unpressed'
        plusButton = FALSE;
    }
    
    // Check for minus button
    if(ProgramControl_CheckIsWidgetActive(ProgramControl_MINUS__BTN))
    {
        // Make sure plus is not also pressed, and that minus was 'unpressed'
        if(!ProgramControl_CheckIsWidgetActive(ProgramControl_PLUS__BTN) && !minusButton)
        {         
            if(programSpeed > 1)
            {
                // Decrement number
                programSpeed--;
                
                // Turn on correct LED
                SpeedLED();
                
                // Update flash memory
                UpdateFlash();
            }
            else if(programSpeed == 1)
            {
                // Turn on correct LED
                SpeedLED();
            }
        }
        
        // Record that button was pressed
        minusButton = TRUE;
    }
    else
    {
        // Record that button was 'unpressed'
        minusButton = FALSE;
    }
}

// Initializes program array
void ProgramInit()
{
    // Counting variable
    int i;
    
    // Check to see if position is beyond array
    if(positions == 3)
    {
        if(programNumber == 0){for(i = 0; i<10; i++)current[i] = program03POS[i];}
        if(programNumber == 1){for(i = 0; i<10; i++)current[i] = program13POS[i];}
        if(programNumber == 2){for(i = 0; i<10; i++)current[i] = program23POS[i];}
        if(programNumber == 3){for(i = 0; i<10; i++)current[i] = program33POS[i];}
        if(programNumber == 4){for(i = 0; i<10; i++)current[i] = program43POS[i];}
        if(programNumber == 5){for(i = 0; i<10; i++)current[i] = program53POS[i];}
        if(programNumber == 6){for(i = 0; i<10; i++)current[i] = program63POS[i];}
    }
    if(positions == 4)
    {
        if(programNumber == 0){for(i = 0; i<10; i++)current[i] = program04POS[i];}
        if(programNumber == 1){for(i = 0; i<10; i++)current[i] = program14POS[i];}
        if(programNumber == 2){for(i = 0; i<10; i++)current[i] = program24POS[i];}
        if(programNumber == 3){for(i = 0; i<10; i++)current[i] = program34POS[i];}
        if(programNumber == 4){for(i = 0; i<10; i++)current[i] = program44POS[i];}
        if(programNumber == 5){for(i = 0; i<10; i++)current[i] = program54POS[i];}
        if(programNumber == 6){for(i = 0; i<10; i++)current[i] = program64POS[i];}
    }
}

// Cycles output
void ProgramCycle()
{
    int sequence = 0;
    
    // Get correct sequence data
    sequence = current[programPosition]; 
    
    // test will be 0 if the program position is outside of the array, if so, reset
    if(!sequence)
    {
        programPosition = 0;  
        sequence = current[programPosition];        
    }
             
    // Advance program position
    programPosition++; 
    
    // Turn on relays for correct sequence
    if(sequence == 1){Relay1_Write(0); Relay2_Write(0); Relay3_Write(0); Relay4_Write(0);}
    if(sequence == 2){Relay1_Write(1); Relay2_Write(0); Relay3_Write(0); Relay4_Write(0);}
    if(sequence == 3){Relay1_Write(0); Relay2_Write(1); Relay3_Write(0); Relay4_Write(0);}
    if(sequence == 4){Relay1_Write(1); Relay2_Write(1); Relay3_Write(0); Relay4_Write(0);}
    if(sequence == 5){Relay1_Write(0); Relay2_Write(0); Relay3_Write(1); Relay4_Write(0);}
    if(sequence == 6){Relay1_Write(1); Relay2_Write(0); Relay3_Write(1); Relay4_Write(0);}
    if(sequence == 7){Relay1_Write(0); Relay2_Write(1); Relay3_Write(1); Relay4_Write(0);}
    if(sequence == 8){Relay1_Write(1); Relay2_Write(1); Relay3_Write(1); Relay4_Write(0);}
    if(sequence == 9){Relay1_Write(0); Relay2_Write(0); Relay3_Write(0); Relay4_Write(1);}
    if(sequence == 10){Relay1_Write(1); Relay2_Write(0); Relay3_Write(0); Relay4_Write(1);}
    if(sequence == 11){Relay1_Write(0); Relay2_Write(1); Relay3_Write(0); Relay4_Write(1);}
    if(sequence == 12){Relay1_Write(1); Relay2_Write(1); Relay3_Write(0); Relay4_Write(1);}
    if(sequence == 13){Relay1_Write(0); Relay2_Write(0); Relay3_Write(1); Relay4_Write(1);}
    if(sequence == 14){Relay1_Write(1); Relay2_Write(0); Relay3_Write(1); Relay4_Write(1);}
    if(sequence == 15){Relay1_Write(0); Relay2_Write(1); Relay3_Write(1); Relay4_Write(1);}
    if(sequence == 16){Relay1_Write(1); Relay2_Write(1); Relay3_Write(1); Relay4_Write(1);}
    
}

// Handles main program functions
int main()
{         
    // Timing variables
    float realDelay = 0;
    float compareValue = 0;
    
    // Start EEPROM
    Em_EEPROM_Start();
    
    // Populate speed and program number
    programNumber = flashData[0];
    programSpeed = flashData[1];
    positions = flashData[2];
        
    // Update LED based on program
    ProgramLED(0);
    
    // Enable global interrupts
    CyGlobalIntEnable;
    
    // Start components
    // Start CapSense
    ProgramControl_Start();
    
    // Initialize capsense baselines by scanning sensors
    ProgramControl_InitializeAllBaselines();
    
    for(;;)
    {
        // Update Baselines
        ProgramControl_UpdateEnabledBaselines();
        
        // Scan all sensors
        ProgramControl_ScanEnabledWidgets();
        
        // Wait for scanning
        while(ProgramControl_IsBusy());
        
        // Update program if a button was pressed
        ProgramChange();
        
        // Update speed if a button was pressed
        SpeedChange();
        
        // Check to see if program was changed - if so restart, if not continue
        if(programChanged)
        {
            // Reset program change
            programChanged = FALSE;
            
            // Set up new program
            ProgramInit();
            
            // Reset program position
            programPosition = 0;
        }

        // Check program timer to see if the delay has elapsed
        realDelay = delayTime / 1000.0;
        compareValue = programTimer * realDelay;
        if(compareValue >= programSpeed)
        {
            // Run program cycle
            ProgramCycle();   
            
            // Reset delay
            programTimer = 0;
        }
               
        // Delay 10ms
        CyDelay(delayTime);
        // Add a cycle to timer
        programTimer++;
      
    }
}



/* [] END OF FILE */
